@@ -1,21 +1,17 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-#ifdef OLD_HEADER_FILENAME
-#include <iostream.h>
-#else
+#include <cstdlib>
 #include <iostream>
-#endif
 #include <string>
 
 #include "H5Include.h"
@@ -30,12 +26,12 @@
 #include "H5DxferProp.h"
 #include "H5LcreatProp.h"
 #include "H5LaccProp.h"
+#include "H5DaccProp.h"
 #include "H5Location.h"
 #include "H5Object.h"
 #include "H5DataType.h"
 #include "H5AtomType.h"
 #include "H5PredType.h"
-#include "H5private.h"
 #include "H5AbstractDs.h"
 #include "H5DataSet.h"
 #include "H5Attribute.h"
@@ -49,7 +45,9 @@ using std::endl;
 ///\brief       Default constructor: Creates a stub datatype
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-DataType::DataType() : H5Object(), id(H5I_INVALID_HID), encoded_buf(NULL), buf_size(0) {}
+DataType::DataType() : H5Object(), id(H5I_INVALID_HID), encoded_buf(NULL), buf_size(0)
+{
+}
 
 //--------------------------------------------------------------------------
 // Function:    DataType overloaded constructor
@@ -79,10 +77,8 @@ DataType::DataType(const hid_t existing_id) : H5Object(), id(existing_id), encod
 //--------------------------------------------------------------------------
 DataType::DataType(const H5T_class_t type_class, size_t size) : H5Object(), encoded_buf(NULL), buf_size(0)
 {
-    // Call C routine to create the new datatype
     id = H5Tcreate(type_class, size);
-    if (id < 0)
-    {
+    if (id < 0) {
         throw DataTypeIException("DataType constructor", "H5Tcreate failed");
     }
 }
@@ -98,7 +94,8 @@ DataType::DataType(const H5T_class_t type_class, size_t size) : H5Object(), enco
 ///\exception   H5::ReferenceException
 // Programmer   Binh-Minh Ribler - Oct, 2006
 //--------------------------------------------------------------------------
-DataType::DataType(const H5Location& loc, const void* ref, H5R_type_t ref_type, const PropList& plist) : H5Object(), encoded_buf(NULL), buf_size(0)
+DataType::DataType(const H5Location &loc, const void *ref, H5R_type_t ref_type, const PropList &plist)
+    : H5Object(), encoded_buf(NULL), buf_size(0)
 {
     id = H5Location::p_dereference(loc.getId(), ref, ref_type, plist, "constructor - by dereference");
 }
@@ -117,18 +114,19 @@ DataType::DataType(const H5Location& loc, const void* ref, H5R_type_t ref_type,
 //        Jul, 2008
 //              Added for application convenience.
 //--------------------------------------------------------------------------
- /* DataType::DataType(const Attribute& attr, const void* ref, H5R_type_t ref_type, const PropList& plist) : H5Object(), id(H5I_INVALID_HID), encoded_buf(NULL), buf_size(0)
+/* DataType::DataType(const Attribute& attr, const void* ref, H5R_type_t ref_type, const PropList& plist) :
+H5Object(), id(H5I_INVALID_HID), encoded_buf(NULL), buf_size(0)
 {
-    id = H5Location::p_dereference(attr.getId(), ref, ref_type, plist, "constructor - by dereference");
+   id = H5Location::p_dereference(attr.getId(), ref, ref_type, plist, "constructor - by dereference");
 }
- */ 
+*/
 
 //--------------------------------------------------------------------------
 // Function:    DataType copy constructor
 ///\brief       Copy constructor: same HDF5 object as \a original
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-DataType::DataType(const DataType& original) : H5Object(), id(original.id), encoded_buf(NULL), buf_size(0)
+DataType::DataType(const DataType &original) : H5Object(), id(original.id), encoded_buf(NULL), buf_size(0)
 {
     incRefCount(); // increment number of references to this id
 }
@@ -146,9 +144,8 @@ DataType::DataType(const DataType& original) : H5Object(), id(original.id), enco
 //              unnecessarily and will produce undefined behavior.
 //              -BMR, Apr 2015
 //--------------------------------------------------------------------------
-DataType::DataType(const PredType& pred_type) : H5Object(), encoded_buf(NULL), buf_size(0)
+DataType::DataType(const PredType &pred_type) : H5Object(), encoded_buf(NULL), buf_size(0)
 {
-    // Call C routine to copy the datatype
     id = H5Tcopy(pred_type.getId());
     if (id < 0)
         throw DataTypeIException("DataType constructor", "H5Tcopy failed");
@@ -168,7 +165,7 @@ DataType::DataType(const PredType& pred_type) : H5Object(), encoded_buf(NULL), b
 //              improve usability.
 //              -BMR, Dec 2016
 //--------------------------------------------------------------------------
-DataType::DataType(const H5Location& loc, const char *dtype_name) : H5Object(), encoded_buf(NULL), buf_size(0)
+DataType::DataType(const H5Location &loc, const char *dtype_name) : H5Object(), encoded_buf(NULL), buf_size(0)
 {
     id = p_opentype(loc, dtype_name);
 }
@@ -187,7 +184,8 @@ DataType::DataType(const H5Location& loc, const char *dtype_name) : H5Object(),
 //              improve usability.
 //              -BMR, Dec 2016
 //--------------------------------------------------------------------------
-DataType::DataType(const H5Location& loc, const H5std_string& dtype_name) : H5Object(), encoded_buf(NULL), buf_size(0)
+DataType::DataType(const H5Location &loc, const H5std_string &dtype_name)
+    : H5Object(), encoded_buf(NULL), buf_size(0)
 {
     id = p_opentype(loc, dtype_name.c_str());
 }
@@ -204,13 +202,14 @@ DataType::DataType(const H5Location& loc, const H5std_string& dtype_name) : H5Ob
 //              - Replaced decRefCount with close() to let the C library
 //              handle the reference counting - BMR, Jun 1, 2006
 //--------------------------------------------------------------------------
-void DataType::copy(const DataType& like_type)
+void
+DataType::copy(const DataType &like_type)
 {
     // close the current data type before copying like_type to this object
     try {
         close();
     }
-    catch (Exception& close_error) {
+    catch (Exception &close_error) {
         throw DataTypeIException(inMemFunc("copy"), close_error.getDetailMsg());
     }
 
@@ -229,13 +228,14 @@ void DataType::copy(const DataType& like_type)
 ///\par Description
 ///             The resulted dataset will be transient and modifiable.
 //--------------------------------------------------------------------------
-void DataType::copy(const DataSet& dset)
+void
+DataType::copy(const DataSet &dset)
 {
     // close the current data type before copying dset's datatype to this object
     try {
         close();
     }
-    catch (Exception& close_error) {
+    catch (Exception &close_error) {
         throw DataTypeIException(inMemFunc("copy"), close_error.getDetailMsg());
     }
 
@@ -253,11 +253,11 @@ void DataType::copy(const DataSet& dset)
 ///\exception   H5::DataTypeIException
 // Programmer   Binh-Minh Ribler - Aug 2017
 //--------------------------------------------------------------------------
-hid_t DataType::p_decode() const
+hid_t
+DataType::p_decode() const
 {
     // Make sure that the buffer can be decoded
-    if (encoded_buf == NULL)
-    {
+    if (encoded_buf == NULL) {
         throw DataTypeIException("DataType::p_decode", "No encoded buffer");
     }
 
@@ -265,13 +265,11 @@ hid_t DataType::p_decode() const
     hid_t encoded_dtype_id = H5Tdecode(encoded_buf);
 
     // If H5Tdecode fails, raise exception
-    if (encoded_dtype_id < 0)
-    {
+    if (encoded_dtype_id < 0) {
         throw DataTypeIException("DataType::p_decode", "H5Tdecode failed");
     }
-    else
-    {
-        return(encoded_dtype_id);
+    else {
+        return (encoded_dtype_id);
     }
 }
 #endif // DOXYGEN_SHOULD_SKIP_THIS
@@ -280,10 +278,12 @@ hid_t DataType::p_decode() const
 // Function:    DataType::decode
 ///\brief       Returns a DataType instance by decoding the binary object
 ///             description of this datatype.
+///
 ///\exception   H5::DataTypeIException
 // Programmer   Binh-Minh Ribler - Aug 2017
 //--------------------------------------------------------------------------
-DataType* DataType::decode() const
+DataType *
+DataType::decode() const
 {
     hid_t encoded_dtype_id = H5I_INVALID_HID;
     try {
@@ -294,36 +294,35 @@ DataType* DataType::decode() const
     }
     DataType *encoded_dtype = new DataType;
     encoded_dtype->p_setId(encoded_dtype_id);
-    return(encoded_dtype);
+    return (encoded_dtype);
 }
 
 //--------------------------------------------------------------------------
 // Function:    DataType::encode
 ///\brief       Creates a binary object description of this datatype.
+///
 ///\exception   H5::DataTypeIException
 // Programmer   Binh-Minh Ribler - Aug 2017
 //--------------------------------------------------------------------------
-void DataType::encode()
+void
+DataType::encode()
 {
     // Call H5Tencode passing in null to determine the size of the buffer
     herr_t ret_value = H5Tencode(id, NULL, &buf_size);
-    if (ret_value < 0)
-    {
+    if (ret_value < 0) {
         throw DataTypeIException("DataType::encode", "Failed to get buf_size");
     }
 
     // Allocate buffer and call C function again to encode
-    if (buf_size > 0)
-    {
-        encoded_buf = (unsigned char *)HDcalloc((size_t)1, buf_size);
+    if (buf_size > 0) {
+        encoded_buf = (unsigned char *)calloc((size_t)1, buf_size);
+
         ret_value = H5Tencode(id, encoded_buf, &buf_size);
-        if (ret_value < 0)
-        {
+        if (ret_value < 0) {
             throw DataTypeIException("DataType::encode", "H5Tencode failed");
         }
     }
-    else
-    {
+    else {
         throw DataTypeIException("DataType::encode", "Failed to allocate buffer for encoding");
     }
 }
@@ -332,15 +331,14 @@ void DataType::encode()
 // Function:    DataType::hasBinaryDesc
 ///\brief       Determines whether this datatype has a binary object
 ///             description.
+///
 ///\exception   H5::DataTypeIException
 // Programmer   Binh-Minh Ribler - Aug 2017
 //--------------------------------------------------------------------------
-bool DataType::hasBinaryDesc() const
+bool
+DataType::hasBinaryDesc() const
 {
-    if (encoded_buf != NULL)
-        return true;
-    else
-        return false;
+    return encoded_buf != NULL;
 }
 
 //--------------------------------------------------------------------------
@@ -362,13 +360,13 @@ bool DataType::hasBinaryDesc() const
 //              transient datatype.
 //              BMR - Mar, 2015
 //--------------------------------------------------------------------------
-DataType& DataType::operator=(const DataType& rhs)
+DataType &
+DataType::operator=(const DataType &rhs)
 {
-    if (this != &rhs)
-    {
+    if (this != &rhs) {
         setId(rhs.id);
     }
-    return(*this);
+    return (*this);
 }
 
 //--------------------------------------------------------------------------
@@ -380,7 +378,8 @@ DataType& DataType::operator=(const DataType& rhs)
 ///\exception   H5::DataTypeIException
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-bool DataType::operator==(const DataType& compared_type) const
+bool
+DataType::operator==(const DataType &compared_type) const
 {
     // Call C routine H5Tequal to determines whether two datatype
     // identifiers refer to the same datatype
@@ -389,12 +388,26 @@ bool DataType::operator==(const DataType& compared_type) const
         return true;
     else if (ret_value == 0)
         return false;
-    else
-    {
+    else {
         throw DataTypeIException(inMemFunc("operator=="), "H5Tequal returns negative value");
     }
 }
 
+//--------------------------------------------------------------------------
+// Function:    DataType::operator!=
+///\brief       Compares this DataType against the given one to determines
+///             whether the two objects refer to different actual datatypes.
+///\param       compared_type - IN: Reference to the datatype to compare
+///\return      true if the datatypes are not equal, and false, otherwise.
+///\exception   H5::DataTypeIException
+// July, 2018
+//--------------------------------------------------------------------------
+bool
+DataType::operator!=(const DataType &compared_type) const
+{
+    return !operator==(compared_type);
+}
+
 //--------------------------------------------------------------------------
 // Function:    DataType::p_commit (private)
 //\brief        Commits a transient datatype to a file, creating a new
@@ -409,7 +422,8 @@ bool DataType::operator==(const DataType& compared_type) const
 //              to be commonly used by several overloads of DataType::commit.
 //              BMR - Jan, 2007
 //--------------------------------------------------------------------------
-void DataType::p_commit(hid_t loc_id, const char* name)
+void
+DataType::p_commit(hid_t loc_id, const char *name)
 {
     // Call C routine to commit the transient datatype
     herr_t ret_value = H5Tcommit2(loc_id, name, id, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
@@ -426,7 +440,8 @@ void DataType::p_commit(hid_t loc_id, const char* name)
 ///\exception   H5::DataTypeIException
 // Programmer   Binh-Minh Ribler - Jan, 2007
 //--------------------------------------------------------------------------
-void DataType::commit(const H5Location& loc, const char* name)
+void
+DataType::commit(const H5Location &loc, const char *name)
 {
     p_commit(loc.getId(), name);
 }
@@ -445,7 +460,7 @@ void DataType::commit(const H5Location& loc, const char* name)
 //              Removed from documentation. -BMR, 2016/03/07 1.8.17 and 1.10.0
 //              Removed from code. -BMR, 2016/08/11 1.8.18 and 1.10.1
 //--------------------------------------------------------------------------
-//void DataType::commit(H5Location& loc, const char* name)
+// void DataType::commit(H5Location& loc, const char* name)
 //{
 //   p_commit(loc.getId(), name);
 //}
@@ -457,7 +472,8 @@ void DataType::commit(const H5Location& loc, const char* name)
 ///             argument \a name.
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void DataType::commit(const H5Location& loc, const H5std_string& name)
+void
+DataType::commit(const H5Location &loc, const H5std_string &name)
 {
     p_commit(loc.getId(), name.c_str());
 }
@@ -476,7 +492,7 @@ void DataType::commit(const H5Location& loc, const H5std_string& name)
 //              Removed from documentation. -BMR, 2016/03/07 1.8.17 and 1.10.0
 //              Removed from code. -BMR, 2016/08/11 1.8.18 and 1.10.1
 //--------------------------------------------------------------------------
-//void DataType::commit(H5Location& loc, const H5std_string& name)
+// void DataType::commit(H5Location& loc, const H5std_string& name)
 //{
 //   p_commit(loc.getId(), name.c_str());
 //}
@@ -490,7 +506,8 @@ void DataType::commit(const H5Location& loc, const H5std_string& name)
 ///\exception   H5::DataTypeIException
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-bool DataType::committed() const
+bool
+DataType::committed() const
 {
     // Call C function to determine if a datatype is a named one
     htri_t is_committed = H5Tcommitted(id);
@@ -498,8 +515,7 @@ bool DataType::committed() const
         return true;
     else if (is_committed == 0)
         return false;
-    else
-    {
+    else {
         throw DataTypeIException(inMemFunc("committed"), "H5Tcommitted return negative value");
     }
 }
@@ -514,15 +530,15 @@ bool DataType::committed() const
 ///\exception   H5::DataTypeIException
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-H5T_conv_t DataType::find(const DataType& dest, H5T_cdata_t **pcdata) const
+H5T_conv_t
+DataType::find(const DataType &dest, H5T_cdata_t **pcdata) const
 {
     // Call C routine to find the conversion function
     H5T_conv_t func = H5Tfind(id, dest.getId(), pcdata);
-    if (func == NULL)
-    {
+    if (func == NULL) {
         throw DataTypeIException(inMemFunc("find"), "H5Tfind returns a NULL function");
     }
-    return(func);
+    return (func);
 }
 
 //--------------------------------------------------------------------------
@@ -532,23 +548,24 @@ H5T_conv_t DataType::find(const DataType& dest, H5T_cdata_t **pcdata) const
 ///\param       nelmts     - IN: Size of array \a buf
 ///\param       buf        - IN/OUT: Array containing pre- and post-conversion
 ///                            values
-///\param       background - IN: Optional backgroud buffer
+///\param       background - IN: Optional background buffer
 ///\param       plist - IN: Property list - default to PropList::DEFAULT
 ///\return      Pointer to a suitable conversion function
 ///\exception   H5::DataTypeIException
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void DataType::convert(const DataType& dest, size_t nelmts, void *buf, void *background, const PropList& plist) const
+void
+DataType::convert(const DataType &dest, size_t nelmts, void *buf, void *background,
+                  const PropList &plist) const
 {
     // Get identifiers for C API
-    hid_t dest_id = dest.getId();
+    hid_t dest_id  = dest.getId();
     hid_t plist_id = plist.getId();
 
     // Call C routine H5Tconvert to convert the data
     herr_t ret_value;
     ret_value = H5Tconvert(id, dest_id, nelmts, buf, background, plist_id);
-    if (ret_value < 0)
-    {
+    if (ret_value < 0) {
         throw DataTypeIException(inMemFunc("convert"), "H5Tconvert failed");
     }
 }
@@ -558,7 +575,7 @@ void DataType::convert(const DataType& dest, size_t nelmts, void *buf, void *bac
 ///\brief       Locks a datatype, making it read-only and non-destructible.
 ///
 ///\exception   H5::DataTypeIException
-///\par Descrition
+///\par Description
 ///             This is normally done by the library for predefined data
 ///             types so the application doesn't inadvertently change or
 ///             delete a predefined type.
@@ -567,12 +584,12 @@ void DataType::convert(const DataType& dest, size_t nelmts, void *buf, void *bac
 ///             the entire library is closed.
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void DataType::lock() const
+void
+DataType::lock() const
 {
     // Call C routine to lock the datatype
     herr_t ret_value = H5Tlock(id);
-    if (ret_value < 0)
-    {
+    if (ret_value < 0) {
         throw DataTypeIException(inMemFunc("lock"), "H5Tlock failed");
     }
 }
@@ -584,16 +601,16 @@ void DataType::lock() const
 ///\exception   H5::DataTypeIException
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-H5T_class_t DataType::getClass() const
+H5T_class_t
+DataType::getClass() const
 {
     H5T_class_t type_class = H5Tget_class(id);
 
     // Return datatype class identifier if successful
-    if (type_class == H5T_NO_CLASS)
-    {
+    if (type_class == H5T_NO_CLASS) {
         throw DataTypeIException(inMemFunc("getClass"), "H5Tget_class returns H5T_NO_CLASS");
     }
-    return(type_class);
+    return (type_class);
 }
 
 //--------------------------------------------------------------------------
@@ -603,15 +620,16 @@ H5T_class_t DataType::getClass() const
 ///\exception   H5::DataTypeIException
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-size_t DataType::getSize() const
+size_t
+DataType::getSize() const
 {
     // Call C routine to get the datatype size
     size_t type_size = H5Tget_size(id);
-    if (type_size <= 0)    // valid data types are never zero size
+    if (type_size <= 0) // valid data types are never zero size
     {
         throw DataTypeIException(inMemFunc("getSize"), "H5Tget_size returns invalid datatype size");
     }
-    return(type_size);
+    return (type_size);
 }
 
 //--------------------------------------------------------------------------
@@ -621,7 +639,8 @@ size_t DataType::getSize() const
 ///\exception   H5::DataTypeIException
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-DataType DataType::getSuper() const
+DataType
+DataType::getSuper() const
 {
     // Call C routine to get the base datatype from which the specified
     // datatype is derived.
@@ -629,14 +648,12 @@ DataType DataType::getSuper() const
 
     // If H5Tget_super returns a valid datatype id, create and return
     // the base type, otherwise, raise exception
-    if (base_type_id > 0)
-    {
+    if (base_type_id > 0) {
         DataType base_type;
         base_type.p_setId(base_type_id);
-        return(base_type);
+        return (base_type);
     }
-    else
-    {
+    else {
         throw DataTypeIException(inMemFunc("getSuper"), "H5Tget_super failed");
     }
 }
@@ -657,14 +674,14 @@ DataType DataType::getSuper() const
 ///             the HDF5 C Reference Manual.
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void DataType::registerFunc(H5T_pers_t pers, const char* name, const DataType& dest, H5T_conv_t func) const
+void
+DataType::registerFunc(H5T_pers_t pers, const char *name, const DataType &dest, H5T_conv_t func) const
 {
-    hid_t dest_id = dest.getId();  // get id of the destination datatype
+    hid_t dest_id = dest.getId(); // get id of the destination datatype
 
     // Call C routine H5Tregister to register the conversion function
     herr_t ret_value = H5Tregister(pers, name, id, dest_id, func);
-    if (ret_value < 0)
-    {
+    if (ret_value < 0) {
         throw DataTypeIException(inMemFunc("registerFunc"), "H5Tregister failed");
     }
 }
@@ -676,7 +693,8 @@ void DataType::registerFunc(H5T_pers_t pers, const char* name, const DataType& d
 ///             argument \a name.
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void DataType::registerFunc(H5T_pers_t pers, const H5std_string& name, const DataType& dest, H5T_conv_t func) const
+void
+DataType::registerFunc(H5T_pers_t pers, const H5std_string &name, const DataType &dest, H5T_conv_t func) const
 {
     registerFunc(pers, name.c_str(), dest, func);
 }
@@ -694,14 +712,14 @@ void DataType::registerFunc(H5T_pers_t pers, const H5std_string& name, const Dat
 ///\exception   H5::DataTypeIException
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void DataType::unregister(H5T_pers_t pers, const char* name, const DataType& dest, H5T_conv_t func) const
+void
+DataType::unregister(H5T_pers_t pers, const char *name, const DataType &dest, H5T_conv_t func) const
 {
-    hid_t dest_id = dest.getId();  // get id of the dest datatype for C API
+    hid_t dest_id = dest.getId(); // get id of the dest datatype for C API
 
     // Call C routine H5Tunregister to remove the conversion function
     herr_t ret_value = H5Tunregister(pers, name, id, dest_id, func);
-    if (ret_value < 0)
-    {
+    if (ret_value < 0) {
         throw DataTypeIException(inMemFunc("unregister"), "H5Tunregister failed");
     }
 }
@@ -713,7 +731,8 @@ void DataType::unregister(H5T_pers_t pers, const char* name, const DataType& des
 ///             argument \a name.
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void DataType::unregister(H5T_pers_t pers, const H5std_string& name, const DataType& dest, H5T_conv_t func) const
+void
+DataType::unregister(H5T_pers_t pers, const H5std_string &name, const DataType &dest, H5T_conv_t func) const
 {
     unregister(pers, name.c_str(), dest, func);
 }
@@ -726,12 +745,12 @@ void DataType::unregister(H5T_pers_t pers, const H5std_string& name, const DataT
 ///\exception   H5::DataTypeIException
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void DataType::setTag(const char* tag) const
+void
+DataType::setTag(const char *tag) const
 {
     // Call C routine H5Tset_tag to tag an opaque datatype.
     herr_t ret_value = H5Tset_tag(id, tag);
-    if (ret_value < 0)
-    {
+    if (ret_value < 0) {
         throw DataTypeIException(inMemFunc("setTag"), "H5Tset_tag failed");
     }
 }
@@ -743,7 +762,8 @@ void DataType::setTag(const char* tag) const
 ///             argument \a name.
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void DataType::setTag(const H5std_string& tag) const
+void
+DataType::setTag(const H5std_string &tag) const
 {
     setTag(tag.c_str());
 }
@@ -755,20 +775,19 @@ void DataType::setTag(const H5std_string& tag) const
 ///\exception   H5::DataTypeIException
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-H5std_string DataType::getTag() const
+H5std_string
+DataType::getTag() const
 {
-    char* tag_Cstr = H5Tget_tag(id);
+    char *tag_Cstr = H5Tget_tag(id);
 
     // if the tag C-string returned is not NULL, convert it to C++ string
     // and return it, otherwise, raise an exception
-    if (tag_Cstr != NULL)
-    {
+    if (tag_Cstr != NULL) {
         H5std_string tag = H5std_string(tag_Cstr); // C string to string object
-        H5free_memory(tag_Cstr); // free the C string
-        return (tag); // return the tag
+        H5free_memory(tag_Cstr);                   // free the C string
+        return (tag);                              // return the tag
     }
-    else
-    {
+    else {
         throw DataTypeIException(inMemFunc("getTag"), "H5Tget_tag returns NULL for tag");
     }
 }
@@ -782,17 +801,16 @@ H5std_string DataType::getTag() const
 ///\exception   H5::DataTypeIException
 // Programmer   Binh-Minh Ribler - May, 2004
 //--------------------------------------------------------------------------
-bool DataType::detectClass(H5T_class_t cls) const
+bool
+DataType::detectClass(H5T_class_t cls) const
 {
     htri_t ret_value = H5Tdetect_class(id, cls);
     if (ret_value > 0)
         return true;
     else if (ret_value == 0)
         return false;
-    else
-    {
-        throw DataTypeIException(inMemFunc("detectClass"),
-            "H5Tdetect_class returns negative value");
+    else {
+        throw DataTypeIException(inMemFunc("detectClass"), "H5Tdetect_class returns negative value");
     }
 }
 
@@ -804,17 +822,16 @@ bool DataType::detectClass(H5T_class_t cls) const
 ///\exception   H5::DataTypeIException
 // Programmer   Binh-Minh Ribler - August, 2017
 //--------------------------------------------------------------------------
-bool DataType::detectClass(const PredType& pred_type, H5T_class_t cls)
+bool
+DataType::detectClass(const PredType &pred_type, H5T_class_t cls)
 {
     htri_t ret_value = H5Tdetect_class(pred_type.getId(), cls);
     if (ret_value > 0)
         return true;
     else if (ret_value == 0)
         return false;
-    else
-    {
-        throw DataTypeIException("detectClass on PredType",
-            "H5Tdetect_class returns negative value");
+    else {
+        throw DataTypeIException("detectClass on PredType", "H5Tdetect_class returns negative value");
     }
 }
 
@@ -826,17 +843,16 @@ bool DataType::detectClass(const PredType& pred_type, H5T_class_t cls)
 ///\exception   H5::DataTypeIException
 // Programmer   Binh-Minh Ribler - May, 2004
 //--------------------------------------------------------------------------
-bool DataType::isVariableStr() const
+bool
+DataType::isVariableStr() const
 {
     htri_t is_varlen_str = H5Tis_variable_str(id);
     if (is_varlen_str == 1)
         return true;
     else if (is_varlen_str == 0)
         return false;
-    else
-    {
-        throw DataTypeIException(inMemFunc("isVariableStr"),
-            "H5Tis_variable_str returns negative value");
+    else {
+        throw DataTypeIException(inMemFunc("isVariableStr"), "H5Tis_variable_str returns negative value");
     }
 }
 
@@ -851,18 +867,17 @@ bool DataType::isVariableStr() const
 //              Currently, there is no datatype creation property list class
 //              in the C++ API because there is no associated functionality.
 //--------------------------------------------------------------------------
-PropList DataType::getCreatePlist() const
+PropList
+DataType::getCreatePlist() const
 {
     hid_t create_plist_id = H5Tget_create_plist(id);
-    if (create_plist_id < 0)
-    {
-        throw DataTypeIException(inMemFunc("getCreatePlist"),
-            "H5Tget_create_plist returns negative value");
+    if (create_plist_id < 0) {
+        throw DataTypeIException(inMemFunc("getCreatePlist"), "H5Tget_create_plist returns negative value");
     }
     // create and return the DSetCreatPropList object
     PropList create_plist;
     f_PropList_setId(&create_plist, create_plist_id);
-    return(create_plist);
+    return (create_plist);
 }
 
 //--------------------------------------------------------------------------
@@ -877,9 +892,10 @@ PropList DataType::getCreatePlist() const
 //              IdComponent::getId now becomes pure virtual function.
 // Programmer   Binh-Minh Ribler - May, 2008
 //--------------------------------------------------------------------------
-hid_t DataType::getId() const
+hid_t
+DataType::getId() const
 {
-    return(id);
+    return (id);
 }
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
@@ -894,13 +910,14 @@ hid_t DataType::getId() const
 //              This function was introduced in 1.10.1 to be used by the new
 //              XxxType constructors that open a datatype. -BMR, Dec 2016
 //--------------------------------------------------------------------------
-hid_t DataType::p_opentype(const H5Location& loc, const char *dtype_name) const
+hid_t
+DataType::p_opentype(const H5Location &loc, const char *dtype_name) const
 {
     // Call C function to open the named datatype at this location
     hid_t ret_value = H5Topen2(loc.getId(), dtype_name, H5P_DEFAULT);
     if (ret_value < 0)
         throw DataTypeIException(inMemFunc("constructor"), "H5Topen2 failed");
-    return(ret_value);
+    return (ret_value);
 }
 
 //--------------------------------------------------------------------------
@@ -910,18 +927,19 @@ hid_t DataType::p_opentype(const H5Location& loc, const char *dtype_name) const
 ///\exception   H5::IdComponentException when the attempt to close the HDF5
 ///             object fails
 // Description:
-//              The underlaying reference counting in the C library ensures
+//              The underlying reference counting in the C library ensures
 //              that the current valid id of this object is properly closed.
 //              Then the object's id is reset to the new id.
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void DataType::p_setId(const hid_t new_id)
+void
+DataType::p_setId(const hid_t new_id)
 {
     // handling references to this old id
     try {
         close();
     }
-    catch (Exception& close_error) {
+    catch (Exception &close_error) {
         throw DataTypeIException(inMemFunc("p_setId"), close_error.getDetailMsg());
     }
     // reset object's id to the given id
@@ -936,22 +954,20 @@ void DataType::p_setId(const hid_t new_id)
 ///\exception   H5::DataTypeIException
 // Programmer   Binh-Minh Ribler - Mar 9, 2005
 //--------------------------------------------------------------------------
-void DataType::close()
+void
+DataType::close()
 {
-    if (p_valid_id(id))
-    {
+    if (p_valid_id(id)) {
         herr_t ret_value = H5Tclose(id);
-        if (ret_value < 0)
-        {
+        if (ret_value < 0) {
             throw DataTypeIException(inMemFunc("close"), "H5Tclose failed");
         }
         // Reset the id
         id = H5I_INVALID_HID;
 
         // Free and reset buffer of encoded object description if it's been used
-        if (encoded_buf != NULL)
-        {
-            HDfree(encoded_buf);
+        if (encoded_buf != NULL) {
+            free(encoded_buf);
             buf_size = 0;
         }
     }
@@ -967,7 +983,7 @@ void DataType::close()
 //              - Replaced decRefCount with close() to let the C library
 //                handle the reference counting - BMR, Jun 1, 2006
 //              - Added the use of H5CPP_EXITED to terminate the HDF5 library
-//                and elimiate previous memory leaks.  See comments in the
+//                and eliminate previous memory leaks.  See comments in the
 //                header file "H5PredType.h" for details. - BMR, Mar 30, 2012
 //              - Major re-implementation of the global constants was done
 //                to avoid relying on the order of the creation and deletion
@@ -977,13 +993,12 @@ void DataType::close()
 //--------------------------------------------------------------------------
 DataType::~DataType()
 {
-    try
-    {
+    try {
         close();
     }
-    catch (Exception& close_error) {
+    catch (Exception &close_error) {
         cerr << inMemFunc("~DataType - ") << close_error.getDetailMsg() << endl;
     }
 }
 
-} // end namespace
+} // namespace H5
