@@ -1,7 +1,6 @@
 // C++ informative line for the emacs editor: -*- C++ -*-
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -47,7 +46,7 @@ class H5_DLLCPP DataType : public H5Object {
     //        PropList& plist = PropList::DEFAULT);
 
     // Closes this datatype.
-    virtual void close();
+    virtual void close() H5_OVERRIDE;
 
     // Copies an existing datatype to this datatype object.
     void copy(const DataType &like_type);
@@ -133,7 +132,7 @@ class H5_DLLCPP DataType : public H5Object {
 
     ///\brief Returns this class name.
     virtual H5std_string
-    fromClass() const
+    fromClass() const H5_OVERRIDE
     {
         return ("DataType");
     }
@@ -148,10 +147,10 @@ class H5_DLLCPP DataType : public H5Object {
     bool hasBinaryDesc() const;
 
     // Gets the datatype id.
-    virtual hid_t getId() const;
+    virtual hid_t getId() const H5_OVERRIDE;
 
     // Destructor: properly terminates access to this datatype.
-    virtual ~DataType();
+    virtual ~DataType() H5_OVERRIDE;
 
   protected:
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
@@ -162,7 +161,7 @@ class H5_DLLCPP DataType : public H5Object {
     hid_t p_decode() const;
 
     // Sets the datatype id.
-    virtual void p_setId(const hid_t new_id);
+    virtual void p_setId(const hid_t new_id) H5_OVERRIDE;
 
     // Opens a datatype and returns the id.
     hid_t p_opentype(const H5Location &loc, const char *dtype_name) const;
