@@ -1,20 +1,19 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-#include <string>
 #include <cstdlib>
+#include <string>
 
-#include "H5CppDoc.h"   // included only for Doxygen to generate part of RM
+#include "H5CppDoc.h" // included only for Doxygen to generate part of RM
 #include "H5Include.h"
 #include "H5Exception.h"
 #include "H5IdComponent.h"
@@ -26,6 +25,7 @@
 #include "H5DcreatProp.h"
 #include "H5LcreatProp.h"
 #include "H5LaccProp.h"
+#include "H5DaccProp.h"
 #include "H5Location.h"
 #include "H5Object.h"
 #include "H5DataType.h"
@@ -43,11 +43,11 @@ namespace H5 {
 ///\exception   H5::LibraryIException
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void H5Library::open()
+void
+H5Library::open()
 {
     herr_t ret_value = H5open();
-    if (ret_value < 0)
-    {
+    if (ret_value < 0) {
         throw LibraryIException("H5Library::open", "H5open failed");
     }
 }
@@ -59,11 +59,11 @@ void H5Library::open()
 ///\exception   H5::LibraryIException
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void H5Library::close()
+void
+H5Library::close()
 {
     herr_t ret_value = H5close();
-    if (ret_value < 0)
-    {
+    if (ret_value < 0) {
         throw LibraryIException("H5Library::close", "H5close failed");
     }
 }
@@ -78,9 +78,10 @@ void H5Library::close()
 //              Removed the check for failure returned from H5dont_atexit.
 //              will be fixed to not fail (HDFFV-9540)
 //--------------------------------------------------------------------------
-void H5Library::dontAtExit()
+void
+H5Library::dontAtExit()
 {
-   (void)H5dont_atexit();
+    (void)H5dont_atexit();
 }
 
 //--------------------------------------------------------------------------
@@ -92,11 +93,11 @@ void H5Library::dontAtExit()
 ///\exception   H5::LibraryIException
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void H5Library::getLibVersion(unsigned& majnum, unsigned& minnum, unsigned& relnum)
+void
+H5Library::getLibVersion(unsigned &majnum, unsigned &minnum, unsigned &relnum)
 {
     herr_t ret_value = H5get_libversion(&majnum, &minnum, &relnum);
-    if (ret_value < 0)
-    {
+    if (ret_value < 0) {
         throw LibraryIException("H5Library::getLibVersion", "H5get_libversion failed");
     }
 }
@@ -114,11 +115,11 @@ void H5Library::getLibVersion(unsigned& majnum, unsigned& minnum, unsigned& reln
 ///             the H5check_version API in the HDF5 C Reference Manual.
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void H5Library::checkVersion(unsigned majnum, unsigned minnum, unsigned relnum)
+void
+H5Library::checkVersion(unsigned majnum, unsigned minnum, unsigned relnum)
 {
     herr_t ret_value = H5check_version(majnum, minnum, relnum);
-    if (ret_value < 0)
-    {
+    if (ret_value < 0) {
         throw LibraryIException("H5Library::checkVersion", "H5check_version failed");
     }
 }
@@ -143,11 +144,11 @@ void H5Library::checkVersion(unsigned majnum, unsigned minnum, unsigned relnum)
 ///             lists when the application ends.
 // Programmer   Binh-Minh Ribler - May, 2004
 //--------------------------------------------------------------------------
-void H5Library::garbageCollect()
+void
+H5Library::garbageCollect()
 {
     herr_t ret_value = H5garbage_collect();
-    if (ret_value < 0)
-    {
+    if (ret_value < 0) {
         throw LibraryIException("H5Library::garbageCollect", "H5garbage_collect failed");
     }
 }
@@ -167,54 +168,67 @@ void H5Library::garbageCollect()
 //
 // Programmer   Binh-Minh Ribler - September, 2015
 //--------------------------------------------------------------------------
-void H5Library::initH5cpp()
+void
+H5Library::initH5cpp()
 {
     // Register terminating functions with atexit(); they will be invoked in
     // the reversed order
     int ret_value = 0;
-    ret_value = std::atexit(termH5cpp);
+    ret_value     = std::atexit(termH5cpp);
     if (ret_value != 0)
-        throw LibraryIException("H5Library::initH5cpp", "Registrating termH5cpp failed");
+        throw LibraryIException("H5Library::initH5cpp", "Registering termH5cpp failed");
 
     ret_value = std::atexit(PredType::deleteConstants);
     if (ret_value != 0)
-        throw LibraryIException("H5Library::initH5cpp", "Registrating PredType::deleteConstants failed");
+        throw LibraryIException("H5Library::initH5cpp", "Registering PredType::deleteConstants failed");
 
     ret_value = std::atexit(PropList::deleteConstants);
     if (ret_value != 0)
-        throw LibraryIException("H5Library::initH5cpp", "Registrating PropList::deleteConstants failed");
+        throw LibraryIException("H5Library::initH5cpp", "Registering PropList::deleteConstants failed");
+
+    ret_value = std::atexit(DSetAccPropList::deleteConstants);
+    if (ret_value != 0)
+        throw LibraryIException("H5Library::initH5cpp",
+                                "Registering DSetAccPropList::deleteConstants failed");
 
     ret_value = std::atexit(LinkAccPropList::deleteConstants);
     if (ret_value != 0)
-        throw LibraryIException("H5Library::initH5cpp", "Registrating LinkAccPropList::deleteConstants failed");
+        throw LibraryIException("H5Library::initH5cpp",
+                                "Registering LinkAccPropList::deleteConstants failed");
 
     ret_value = std::atexit(LinkCreatPropList::deleteConstants);
     if (ret_value != 0)
-        throw LibraryIException("H5Library::initH5cpp", "Registrating LinkCreatPropList::deleteConstants failed");
+        throw LibraryIException("H5Library::initH5cpp",
+                                "Registering LinkCreatPropList::deleteConstants failed");
 
     ret_value = std::atexit(FileAccPropList::deleteConstants);
     if (ret_value != 0)
-        throw LibraryIException("H5Library::initH5cpp", "Registrating FileAccPropList::deleteConstants failed");
+        throw LibraryIException("H5Library::initH5cpp",
+                                "Registering FileAccPropList::deleteConstants failed");
 
     ret_value = std::atexit(FileCreatPropList::deleteConstants);
     if (ret_value != 0)
-        throw LibraryIException("H5Library::initH5cpp", "Registrating FileCreatPropList::deleteConstants failed");
+        throw LibraryIException("H5Library::initH5cpp",
+                                "Registering FileCreatPropList::deleteConstants failed");
 
     ret_value = std::atexit(DSetMemXferPropList::deleteConstants);
     if (ret_value != 0)
-        throw LibraryIException("H5Library::initH5cpp", "Registrating DSetMemXferPropList::deleteConstants failed");
+        throw LibraryIException("H5Library::initH5cpp",
+                                "Registering DSetMemXferPropList::deleteConstants failed");
 
     ret_value = std::atexit(DSetCreatPropList::deleteConstants);
     if (ret_value != 0)
-        throw LibraryIException("H5Library::initH5cpp", "Registrating DSetCreatPropList::deleteConstants failed");
+        throw LibraryIException("H5Library::initH5cpp",
+                                "Registering DSetCreatPropList::deleteConstants failed");
 
     ret_value = std::atexit(ObjCreatPropList::deleteConstants);
     if (ret_value != 0)
-        throw LibraryIException("H5Library::initH5cpp", "Registrating ObjCreatPropList::deleteConstants failed");
+        throw LibraryIException("H5Library::initH5cpp",
+                                "Registering ObjCreatPropList::deleteConstants failed");
 
     ret_value = std::atexit(DataSpace::deleteConstants);
     if (ret_value != 0)
-        throw LibraryIException("H5Library::initH5cpp", "Registrating DataSpace::deleteConstants failed");
+        throw LibraryIException("H5Library::initH5cpp", "Registering DataSpace::deleteConstants failed");
 }
 
 //--------------------------------------------------------------------------
@@ -224,7 +238,8 @@ void H5Library::initH5cpp()
 ///             If the C library fails to terminate, exit with a failure.
 // Programmer   Binh-Minh Ribler - September, 2015
 //--------------------------------------------------------------------------
-void H5Library::termH5cpp()
+void
+H5Library::termH5cpp()
 {
     // Close the C library
     herr_t ret_value = H5close();
@@ -248,13 +263,13 @@ void H5Library::termH5cpp()
 ///             the H5set_free_list_limits API in the HDF5 C Reference Manual.
 // Programmer   Binh-Minh Ribler - May, 2004
 //--------------------------------------------------------------------------
-void H5Library::setFreeListLimits(int reg_global_lim, int reg_list_lim,
-        int arr_global_lim, int arr_list_lim, int blk_global_lim,
-        int blk_list_lim)
+void
+H5Library::setFreeListLimits(int reg_global_lim, int reg_list_lim, int arr_global_lim, int arr_list_lim,
+                             int blk_global_lim, int blk_list_lim)
 {
-    herr_t ret_value = H5set_free_list_limits(reg_global_lim, reg_list_lim, arr_global_lim, arr_list_lim, blk_global_lim, blk_list_lim);
-    if (ret_value < 0)
-    {
+    herr_t ret_value = H5set_free_list_limits(reg_global_lim, reg_list_lim, arr_global_lim, arr_list_lim,
+                                              blk_global_lim, blk_list_lim);
+    if (ret_value < 0) {
         throw LibraryIException("H5Library::setFreeListLimits", "H5set_free_list_limits failed");
     }
 }
@@ -265,14 +280,18 @@ void H5Library::setFreeListLimits(int reg_global_lim, int reg_list_lim,
 ///\brief       Default constructor: Creates a stub H5Library object
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-H5Library::H5Library(){}
+H5Library::H5Library()
+{
+}
 
 //--------------------------------------------------------------------------
 // Function:    H5Library destructor
 ///\brief       Noop destructor
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-H5Library::~H5Library(){}
+H5Library::~H5Library()
+{
+}
 #endif // DOXYGEN_SHOULD_SKIP_THIS
 
-} // end namespace
+} // namespace H5
