@@ -1,12 +1,11 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -22,6 +21,7 @@
 #include "H5DxferProp.h"
 #include "H5LcreatProp.h"
 #include "H5LaccProp.h"
+#include "H5DaccProp.h"
 #include "H5Location.h"
 #include "H5Object.h"
 #include "H5DataType.h"
@@ -39,7 +39,9 @@ namespace H5 {
 ///\brief       Default constructor: Creates a stub string datatype
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-StrType::StrType() : AtomType() {}
+StrType::StrType() : AtomType()
+{
+}
 
 //--------------------------------------------------------------------------
 // Function:    StrType overloaded constructor
@@ -48,7 +50,7 @@ StrType::StrType() : AtomType() {}
 ///\exception   H5::DataTypeIException
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-StrType::StrType(const PredType& pred_type) : AtomType()
+StrType::StrType(const PredType &pred_type) : AtomType()
 {
     // use DataType::copy to make a copy of this predefined type
     copy(pred_type);
@@ -77,7 +79,7 @@ StrType::StrType(const PredType& pred_type) : AtomType()
 //              Planned for removal. -BMR, 2005/12/02
 //              Removed from documentation. -BMR, 2016/03/07
 //--------------------------------------------------------------------------
-StrType::StrType(const PredType& pred_type, const size_t& size) : AtomType()
+StrType::StrType(const PredType &pred_type, const size_t &size) : AtomType()
 {
     // use DataType::copy to make a copy of the string predefined type
     // then set its length
@@ -101,8 +103,11 @@ StrType::StrType(const PredType& pred_type, const size_t& size) : AtomType()
 //              This constructor replaced the previous one.
 // Programmer   Binh-Minh Ribler - Nov 28, 2005
 //--------------------------------------------------------------------------
-StrType::StrType(const int dummy, const size_t& size) : AtomType()
+StrType::StrType(const int dummy, const size_t &size) : AtomType()
 {
+    // Unused
+    (void)dummy;
+
     // use DataType::copy to make a copy of the string predefined type
     // then set its length
     copy(PredType::C_S1);
@@ -116,14 +121,18 @@ StrType::StrType(const int dummy, const size_t& size) : AtomType()
 ///\exception   H5::DataTypeIException
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-StrType::StrType(const hid_t existing_id) : AtomType( existing_id ) {}
+StrType::StrType(const hid_t existing_id) : AtomType(existing_id)
+{
+}
 
 //--------------------------------------------------------------------------
 // Function:    StrType copy constructor
 ///\brief       Copy constructor: same HDF5 object as \a original
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-StrType::StrType(const StrType& original) : AtomType ( original ) {}
+StrType::StrType(const StrType &original) : AtomType(original)
+{
+}
 
 //--------------------------------------------------------------------------
 // Function:    StrType overloaded constructor
@@ -132,13 +141,12 @@ StrType::StrType(const StrType& original) : AtomType ( original ) {}
 ///\exception   H5::DataTypeIException
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-StrType::StrType(const DataSet& dataset) : AtomType ()
+StrType::StrType(const DataSet &dataset) : AtomType()
 {
     // Calls C function H5Dget_type to get the id of the datatype
     id = H5Dget_type(dataset.getId());
 
-    if (id < 0)
-    {
+    if (id < 0) {
         throw DataSetIException("StrType constructor", "H5Dget_type failed");
     }
 }
@@ -157,7 +165,7 @@ StrType::StrType(const DataSet& dataset) : AtomType ()
 //              improve usability.
 //              -BMR, Dec 2016
 //--------------------------------------------------------------------------
-StrType::StrType(const H5Location& loc, const char *dtype_name) : AtomType()
+StrType::StrType(const H5Location &loc, const char *dtype_name) : AtomType()
 {
     id = p_opentype(loc, dtype_name);
 }
@@ -176,7 +184,7 @@ StrType::StrType(const H5Location& loc, const char *dtype_name) : AtomType()
 //              to improve usability.
 //              -BMR, Dec 2016
 //--------------------------------------------------------------------------
-StrType::StrType(const H5Location& loc, const H5std_string& dtype_name) : AtomType()
+StrType::StrType(const H5Location &loc, const H5std_string &dtype_name) : AtomType()
 {
     id = p_opentype(loc, dtype_name.c_str());
 }
@@ -185,10 +193,12 @@ StrType::StrType(const H5Location& loc, const H5std_string& dtype_name) : AtomTy
 // Function:    StrType::decode
 ///\brief       Returns an StrType object via DataType* by decoding the
 ///             binary object description of this type.
+///
 ///\exception   H5::DataTypeIException
 // Programmer   Binh-Minh Ribler - Aug 2017
 //--------------------------------------------------------------------------
-DataType* StrType::decode() const
+DataType *
+StrType::decode() const
 {
     hid_t encoded_strtype_id = H5I_INVALID_HID;
     try {
@@ -199,7 +209,7 @@ DataType* StrType::decode() const
     }
     StrType *encoded_strtype = new StrType;
     encoded_strtype->p_setId(encoded_strtype_id);
-    return(encoded_strtype);
+    return (encoded_strtype);
 }
 
 //--------------------------------------------------------------------------
@@ -217,16 +227,16 @@ DataType* StrType::decode() const
 ///\exception   H5::DataTypeIException
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-H5T_cset_t StrType::getCset() const
+H5T_cset_t
+StrType::getCset() const
 {
     H5T_cset_t cset = H5Tget_cset(id);
 
     // Returns a valid character set type if successful
-    if (cset == H5T_CSET_ERROR)
-    {
+    if (cset == H5T_CSET_ERROR) {
         throw DataTypeIException("StrType::getCset", "H5Tget_cset failed");
     }
-    return(cset);
+    return (cset);
 }
 
 //--------------------------------------------------------------------------
@@ -244,11 +254,11 @@ H5T_cset_t StrType::getCset() const
 ///\exception   H5::DataTypeIException
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void StrType::setCset(H5T_cset_t cset) const
+void
+StrType::setCset(H5T_cset_t cset) const
 {
     herr_t ret_value = H5Tset_cset(id, cset);
-    if (ret_value < 0)
-    {
+    if (ret_value < 0) {
         throw DataTypeIException("StrType::setCset", "H5Tset_cset failed");
     }
 }
@@ -263,17 +273,16 @@ void StrType::setCset(H5T_cset_t cset) const
 ///\exception   H5::DataTypeIException
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-H5T_str_t StrType::getStrpad() const
+H5T_str_t
+StrType::getStrpad() const
 {
     H5T_str_t strpad = H5Tget_strpad(id);
 
     // Returns a valid string padding type if successful
-    if (strpad == H5T_STR_ERROR)
-    {
-        throw DataTypeIException("StrType::getStrpad",
-            "H5Tget_strpad failed - returned H5T_STR_ERROR");
+    if (strpad == H5T_STR_ERROR) {
+        throw DataTypeIException("StrType::getStrpad", "H5Tget_strpad failed - returned H5T_STR_ERROR");
     }
-    return(strpad);
+    return (strpad);
 }
 
 //--------------------------------------------------------------------------
@@ -286,11 +295,11 @@ H5T_str_t StrType::getStrpad() const
 ///             the HDF5 C Reference Manual.
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void StrType::setStrpad(H5T_str_t strpad) const
+void
+StrType::setStrpad(H5T_str_t strpad) const
 {
     herr_t ret_value = H5Tset_strpad(id, strpad);
-    if (ret_value < 0)
-    {
+    if (ret_value < 0) {
         throw DataTypeIException("StrType::setStrpad", "H5Tset_strpad failed");
     }
 }
@@ -300,6 +309,8 @@ void StrType::setStrpad(H5T_str_t strpad) const
 ///\brief       Properly terminates access to this string datatype.
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-StrType::~StrType() {}
+StrType::~StrType()
+{
+}
 
-} // end namespace
+} // namespace H5
