@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -53,8 +52,8 @@
 static int
 test_file_image(size_t open_images, size_t nflags, const unsigned *flags)
 {
-    hid_t * file_id, *dset_id, file_space, plist; /* HDF5 ids */
-    hsize_t dims1[RANK]    = {2, 3};              /* original dimension of datasets */
+    hid_t  *file_id = NULL, *dset_id = NULL, file_space, plist; /* HDF5 ids */
+    hsize_t dims1[RANK]    = {2, 3};                            /* original dimension of datasets */
     hsize_t max_dims[RANK] = {H5S_UNLIMITED, H5S_UNLIMITED};
     int     data1[6]       = {1, 2, 3, 4, 5, 6};    /* original contents of dataset */
     int     data2[6]       = {7, 8, 9, 10, 11, 12}; /* "wrong" contents of dataset */
@@ -63,13 +62,13 @@ test_file_image(size_t open_images, size_t nflags, const unsigned *flags)
     hsize_t dims4[RANK] = {3, 5};                   /* extended dimensions of datasets */
     int     data4[15]   = {1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15};
     /* extended contents of dataset */
-    ssize_t *       buf_size;    /* pointer to array of buffer sizes */
-    void **         buf_ptr;     /* pointer to array of pointers to image buffers */
-    char **         filename;    /* pointer to array of pointers to filenames */
-    unsigned *      input_flags; /* pointer to array of flag combinations */
+    ssize_t        *buf_size    = NULL; /* pointer to array of buffer sizes */
+    void          **buf_ptr     = NULL; /* pointer to array of pointers to image buffers */
+    char          **filename    = NULL; /* pointer to array of pointers to filenames */
+    unsigned       *input_flags = NULL; /* pointer to array of flag combinations */
     size_t          i, j, k, nrow, n_values;
     herr_t          status1;
-    void *          handle_ptr       = NULL; /* pointers to driver buffer */
+    void           *handle_ptr       = NULL; /* pointers to driver buffer */
     unsigned char **core_buf_ptr_ptr = NULL;
 
     VERIFY(open_images > 1, "The number of open images must be greater than 1");
@@ -85,7 +84,7 @@ test_file_image(size_t open_images, size_t nflags, const unsigned *flags)
         FAIL_PUTS_ERROR("malloc() failed");
 
     /* allocate array to store the name of each of the open images */
-    if (NULL == (filename = (char **)HDmalloc(sizeof(char *) * open_images)))
+    if (NULL == (filename = (char **)HDcalloc(1, sizeof(char *) * open_images)))
         FAIL_PUTS_ERROR("malloc() failed");
 
     /* allocate array to store the size of each of the open images */
@@ -109,10 +108,13 @@ test_file_image(size_t open_images, size_t nflags, const unsigned *flags)
         input_flags[i] = flags[(nflags + i) % nflags];
 
         /* allocate name buffer for image i */
-        filename[i] = (char *)HDmalloc(sizeof(char) * 32);
+        size_t filenamelength = sizeof(char) * 32;
+        filename[i]           = (char *)HDmalloc(filenamelength);
+        if (!filename[i])
+            FAIL_PUTS_ERROR("HDmalloc() failed");
 
         /* create file name */
-        HDsprintf(filename[i], "image_file%d.h5", (int)i);
+        HDsnprintf(filename[i], filenamelength, "image_file%d.h5", (int)i);
 
         /* create file */
         if ((file_id[i] = H5Fcreate(filename[i], H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT)) < 0)
@@ -232,13 +234,16 @@ test_file_image(size_t open_images, size_t nflags, const unsigned *flags)
             if (input_flags[i] & H5LT_FILE_IMAGE_OPEN_RW && !(input_flags[i] & H5LT_FILE_IMAGE_DONT_COPY)) {
 
                 void *tmp_ptr = HDmalloc((size_t)buf_size[i]);
+                if (!tmp_ptr)
+                    FAIL_PUTS_ERROR("buffer allocation failed");
+
                 /* Copy vfd buffer to a temporary buffer */
                 HDmemcpy(tmp_ptr, (void *)*core_buf_ptr_ptr, (size_t)buf_size[i]);
                 /* Clear status_flags in the superblock for the vfd buffer: file locking is using status_flags
                  */
                 HDmemset((uint8_t *)tmp_ptr + SUPER_STATUS_FLAGS_OFF_V0_V1, (int)0,
                          (size_t)SUPER_STATUS_FLAGS_SIZE_V0_V1);
-                /* Does the comparision */
+                /* Does the comparison */
                 if (HDmemcmp(tmp_ptr, buf_ptr[i], (size_t)buf_size[i]) != 0)
                     FAIL_PUTS_ERROR("comparison of TMP vfd and user buffer failed");
                 /* Free the temporary buffer */
@@ -525,6 +530,17 @@ test_file_image(size_t open_images, size_t nflags, const unsigned *flags)
     return 0;
 
 error:
+    if (filename) {
+        for (i = 0; i < open_images; i++)
+            HDfree(filename[i]);
+        HDfree(filename);
+    }
+    HDfree(file_id);
+    HDfree(dset_id);
+    HDfree(buf_ptr);
+    HDfree(buf_size);
+    HDfree(input_flags);
+
     H5_FAILED();
     return -1;
 }
