@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -224,7 +223,7 @@ main(void)
         one_cbuf[i].field2.b.a = 20;
         one_cbuf[i].field2.b.b = 40;
         one_cbuf[i].field2.b.c = 80;
-        one_cbuf[i].field3     = 3.0F;
+        one_cbuf[i].field3     = 3.0;
         one_cbuf[i].field4.a   = 4;
         one_cbuf[i].field4.b   = 8;
     } /* end for */
@@ -313,7 +312,7 @@ main(void)
         two_cbuf[i].field2.b.a = 20;
         two_cbuf[i].field2.b.b = 40;
         two_cbuf[i].field2.b.c = 80;
-        two_cbuf[i].field3     = 3.0F;
+        two_cbuf[i].field3     = 3.0;
         two_cbuf[i].field4.a   = 4;
         two_cbuf[i].field4.b   = 8;
     } /* end for */
