@@ -1,15 +1,13 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
- * Read-Only HDFS Virtual File Driver (VFD)                                  *
- * Copyright (c) 2018, The HDF Group.                                        *
- *                                                                           *
+ * Copyright by The HDF Group.                                               *
  * All rights reserved.                                                      *
  *                                                                           *
- * NOTICE:                                                                   *
- * All information contained herein is, and remains, the property of The HDF *
- * Group. The intellectual and technical concepts contained herein are       *
- * proprietary to The HDF Group. Dissemination of this information or        *
- * reproduction of this material is strictly forbidden unless prior written  *
- * permission is obtained from The HDF Group.                                *
+ * This file is part of HDF5.  The full HDF5 copyright notice, including     *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the COPYING file, which can be found at the root of the source code       *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
+ * If you do not have access to either file, you may request a copy from     *
+ * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 package hdf.hdf5lib.structs;
@@ -27,17 +25,17 @@ public class H5FD_hdfs_fapl_t implements Serializable {
     private static final long serialVersionUID = 2072473407027648309L;
 
     /** Version number of the H5FD_hdfs_fapl_t structure. */
-    private int    version;
+    private int version;
     /** Name of "Name Node" to access as the HDFS server. */
     private String namenode_name;
     /** Port number to use to connect with Name Node. */
-    private int    namenode_port;
+    private int namenode_port;
     /** Username to use when accessing file. */
     private String user_name;
     /** Path to the location of the Kerberos authentication cache. */
     private String kerberos_ticket_cache;
     /** Size (in bytes) of the file read stream buffer. */
-    private int    stream_buffer_size;
+    private int stream_buffer_size;
 
     /**
      * Create a fapl_t structure with the specified components.
@@ -52,23 +50,20 @@ public class H5FD_hdfs_fapl_t implements Serializable {
      * @param stream_buffer_size
      *     Size (in bytes) of the file read stream buffer.
      */
-    public H5FD_hdfs_fapl_t(
-            String namenode_name,
-            int    namenode_port,
-            String user_name,
-            String kerberos_ticket_cache,
-            int    stream_buffer_size)
+    public H5FD_hdfs_fapl_t(String namenode_name, int namenode_port, String user_name,
+                            String kerberos_ticket_cache, int stream_buffer_size)
     {
-        this.version                = 1;
-        this.namenode_name          = namenode_name;
-        this.namenode_port          = namenode_port;
-        this.user_name              = user_name;
-        this.kerberos_ticket_cache  = kerberos_ticket_cache;
-        this.stream_buffer_size     = stream_buffer_size;
+        this.version               = 1;
+        this.namenode_name         = namenode_name;
+        this.namenode_port         = namenode_port;
+        this.user_name             = user_name;
+        this.kerberos_ticket_cache = kerberos_ticket_cache;
+        this.stream_buffer_size    = stream_buffer_size;
     }
 
     @Override
-    public boolean equals(Object o) {
+    public boolean equals(Object o)
+    {
         if (o == null)
             return false;
         if (!(o instanceof H5FD_hdfs_fapl_t))
@@ -91,7 +86,8 @@ public class H5FD_hdfs_fapl_t implements Serializable {
     }
 
     @Override
-    public int hashCode() {
+    public int hashCode()
+    {
         /* this is a _very bad_ hash algorithm for purposes of hashing! */
         /* implemented to satisfy the "contract" regarding equality     */
         int k = (int)this.version;
@@ -104,15 +100,11 @@ public class H5FD_hdfs_fapl_t implements Serializable {
     }
 
     @Override
-    public String toString() {
-    return "H5FD_hdfs_fapl_t (Version: " + this.version + ") {" +
-           "\n    namenode_name: '" + this.namenode_name +
-           "'\n    namenode_port: " + this.namenode_port +
-           "\n    user_name: '" + this.user_name +
-           "'\n    kerberos_ticket_cache: '" + this.kerberos_ticket_cache +
-           "'\n    stream_buffer_size: " + this.stream_buffer_size +
-           "\n}\n";
+    public String toString()
+    {
+        return "H5FD_hdfs_fapl_t (Version: " + this.version + ") {"
+            + "\n    namenode_name: '" + this.namenode_name + "'\n    namenode_port: " + this.namenode_port +
+            "\n    user_name: '" + this.user_name + "'\n    kerberos_ticket_cache: '" +
+            this.kerberos_ticket_cache + "'\n    stream_buffer_size: " + this.stream_buffer_size + "\n}\n";
     }
 }
-
-
