@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -75,7 +74,7 @@ typedef struct H5AC_slist_entry_t {
 /* User data for address list building callbacks */
 typedef struct H5AC_addr_list_ud_t {
     H5AC_aux_t *aux_ptr;      /* 'Auxiliary' parallel cache info */
-    haddr_t *   addr_buf_ptr; /* Array to store addresses */
+    haddr_t    *addr_buf_ptr; /* Array to store addresses */
     unsigned    u;            /* Counter for position in array */
 } H5AC_addr_list_ud_t;
 
@@ -208,7 +207,7 @@ H5AC__set_write_done_callback(H5C_t *cache_ptr, void (*write_done)(void))
 herr_t
 H5AC_add_candidate(H5AC_t *cache_ptr, haddr_t addr)
 {
-    H5AC_aux_t *        aux_ptr;
+    H5AC_aux_t         *aux_ptr;
     H5AC_slist_entry_t *slist_entry_ptr = NULL;
     herr_t              ret_value       = SUCCEED; /* Return value */
 
@@ -269,7 +268,7 @@ static herr_t
 H5AC__broadcast_candidate_list(H5AC_t *cache_ptr, unsigned *num_entries_ptr, haddr_t **haddr_buf_ptr_ptr)
 {
     H5AC_aux_t *aux_ptr       = NULL;
-    haddr_t *   haddr_buf_ptr = NULL;
+    haddr_t    *haddr_buf_ptr = NULL;
     int         mpi_result;
     unsigned    num_entries;
     herr_t      ret_value = SUCCEED; /* Return value */
@@ -350,7 +349,7 @@ done:
 static herr_t
 H5AC__broadcast_clean_list_cb(void *_item, void H5_ATTR_UNUSED *_key, void *_udata)
 {
-    H5AC_slist_entry_t * slist_entry_ptr = (H5AC_slist_entry_t *)_item;   /* Address of item */
+    H5AC_slist_entry_t  *slist_entry_ptr = (H5AC_slist_entry_t *)_item;   /* Address of item */
     H5AC_addr_list_ud_t *udata           = (H5AC_addr_list_ud_t *)_udata; /* Context for callback */
     haddr_t              addr;
 
@@ -401,7 +400,7 @@ H5AC__broadcast_clean_list_cb(void *_item, void H5_ATTR_UNUSED *_key, void *_uda
 static herr_t
 H5AC__broadcast_clean_list(H5AC_t *cache_ptr)
 {
-    haddr_t *   addr_buf_ptr = NULL;
+    haddr_t    *addr_buf_ptr = NULL;
     H5AC_aux_t *aux_ptr;
     int         mpi_result;
     unsigned    num_entries = 0;
@@ -547,7 +546,7 @@ done:
 static herr_t
 H5AC__copy_candidate_list_to_buffer_cb(void *_item, void H5_ATTR_UNUSED *_key, void *_udata)
 {
-    H5AC_slist_entry_t * slist_entry_ptr = (H5AC_slist_entry_t *)_item;   /* Address of item */
+    H5AC_slist_entry_t  *slist_entry_ptr = (H5AC_slist_entry_t *)_item;   /* Address of item */
     H5AC_addr_list_ud_t *udata           = (H5AC_addr_list_ud_t *)_udata; /* Context for callback */
 
     FUNC_ENTER_STATIC_NOERR
@@ -601,9 +600,9 @@ static herr_t
 H5AC__copy_candidate_list_to_buffer(const H5AC_t *cache_ptr, unsigned *num_entries_ptr,
                                     haddr_t **haddr_buf_ptr_ptr)
 {
-    H5AC_aux_t *        aux_ptr = NULL;
+    H5AC_aux_t         *aux_ptr = NULL;
     H5AC_addr_list_ud_t udata;
-    haddr_t *           haddr_buf_ptr = NULL;
+    haddr_t            *haddr_buf_ptr = NULL;
     size_t              buf_size;
     unsigned            num_entries = 0;
     herr_t              ret_value   = SUCCEED; /* Return value */
@@ -675,8 +674,8 @@ done:
 herr_t
 H5AC__log_deleted_entry(const H5AC_info_t *entry_ptr)
 {
-    H5AC_t *            cache_ptr;
-    H5AC_aux_t *        aux_ptr;
+    H5AC_t             *cache_ptr;
+    H5AC_aux_t         *aux_ptr;
     H5AC_slist_entry_t *slist_entry_ptr = NULL;
     haddr_t             addr;
 
@@ -729,7 +728,7 @@ H5AC__log_deleted_entry(const H5AC_info_t *entry_ptr)
 herr_t
 H5AC__log_dirtied_entry(const H5AC_info_t *entry_ptr)
 {
-    H5AC_t *    cache_ptr;
+    H5AC_t     *cache_ptr;
     H5AC_aux_t *aux_ptr;
     herr_t      ret_value = SUCCEED; /* Return value */
 
@@ -807,7 +806,7 @@ done:
 herr_t
 H5AC__log_cleaned_entry(const H5AC_info_t *entry_ptr)
 {
-    H5AC_t *    cache_ptr;
+    H5AC_t     *cache_ptr;
     H5AC_aux_t *aux_ptr;
 
     FUNC_ENTER_PACKAGE_NOERR
@@ -870,7 +869,7 @@ herr_t
 H5AC__log_flushed_entry(H5C_t *cache_ptr, haddr_t addr, hbool_t was_dirty, unsigned flags)
 {
     hbool_t             cleared;
-    H5AC_aux_t *        aux_ptr;
+    H5AC_aux_t         *aux_ptr;
     H5AC_slist_entry_t *slist_entry_ptr = NULL;
     herr_t              ret_value       = SUCCEED; /* Return value */
 
@@ -937,7 +936,7 @@ done:
 herr_t
 H5AC__log_inserted_entry(const H5AC_info_t *entry_ptr)
 {
-    H5AC_t *    cache_ptr;
+    H5AC_t     *cache_ptr;
     H5AC_aux_t *aux_ptr;
     herr_t      ret_value = SUCCEED; /* Return value */
 
@@ -1020,7 +1019,7 @@ done:
  *		dirty bytes count.
  *
  *		The rank 0 process then removes any references to the
- *		entry under its old address from the cleands and dirtied
+ *		entry under its old address from the cleaned and dirtied
  *		lists, and inserts an entry in the dirtied list under the
  *		new address.
  *
@@ -1035,7 +1034,7 @@ done:
 herr_t
 H5AC__log_moved_entry(const H5F_t *f, haddr_t old_addr, haddr_t new_addr)
 {
-    H5AC_t *    cache_ptr;
+    H5AC_t     *cache_ptr;
     H5AC_aux_t *aux_ptr;
     hbool_t     entry_in_cache;
     hbool_t     entry_dirty;
@@ -1215,9 +1214,9 @@ done:
 static herr_t
 H5AC__propagate_and_apply_candidate_list(H5F_t *f)
 {
-    H5AC_t *    cache_ptr;
+    H5AC_t     *cache_ptr;
     H5AC_aux_t *aux_ptr;
-    haddr_t *   candidates_list_ptr = NULL;
+    haddr_t    *candidates_list_ptr = NULL;
     int         mpi_result;
     unsigned    num_candidates = 0;
     herr_t      ret_value      = SUCCEED; /* Return value */
@@ -1381,7 +1380,7 @@ done:
 static herr_t
 H5AC__propagate_flushed_and_still_clean_entries_list(H5F_t *f)
 {
-    H5AC_t *    cache_ptr;
+    H5AC_t     *cache_ptr;
     H5AC_aux_t *aux_ptr;
     herr_t      ret_value = SUCCEED; /* Return value */
 
@@ -1502,9 +1501,9 @@ done:
 static herr_t
 H5AC__receive_and_apply_clean_list(H5F_t *f)
 {
-    H5AC_t *    cache_ptr;
+    H5AC_t     *cache_ptr;
     H5AC_aux_t *aux_ptr;
-    haddr_t *   haddr_buf_ptr = NULL;
+    haddr_t    *haddr_buf_ptr = NULL;
     unsigned    num_entries   = 0;
     herr_t      ret_value     = SUCCEED; /* Return value */
 
@@ -1642,9 +1641,9 @@ done:
 static herr_t
 H5AC__rsp__dist_md_write__flush(H5F_t *f)
 {
-    H5AC_t *    cache_ptr;
+    H5AC_t     *cache_ptr;
     H5AC_aux_t *aux_ptr;
-    haddr_t *   haddr_buf_ptr = NULL;
+    haddr_t    *haddr_buf_ptr = NULL;
     int         mpi_result;
     unsigned    num_entries = 0;
     herr_t      ret_value   = SUCCEED; /* Return value */
@@ -1788,7 +1787,7 @@ done:
 static herr_t
 H5AC__rsp__dist_md_write__flush_to_min_clean(H5F_t *f)
 {
-    H5AC_t *    cache_ptr;
+    H5AC_t     *cache_ptr;
     H5AC_aux_t *aux_ptr;
     hbool_t     evictions_enabled;
     herr_t      ret_value = SUCCEED; /* Return value */
@@ -1869,7 +1868,7 @@ done:
 static herr_t
 H5AC__rsp__p0_only__flush(H5F_t *f)
 {
-    H5AC_t *    cache_ptr;
+    H5AC_t     *cache_ptr;
     H5AC_aux_t *aux_ptr;
     int         mpi_result;
     herr_t      ret_value = SUCCEED; /* Return value */
@@ -1983,7 +1982,7 @@ done:
 static herr_t
 H5AC__rsp__p0_only__flush_to_min_clean(H5F_t *f)
 {
-    H5AC_t *    cache_ptr;
+    H5AC_t     *cache_ptr;
     H5AC_aux_t *aux_ptr;
     hbool_t     evictions_enabled;
     herr_t      ret_value = SUCCEED; /* Return value */
@@ -2098,7 +2097,7 @@ done:
 herr_t
 H5AC__run_sync_point(H5F_t *f, int sync_point_op)
 {
-    H5AC_t *    cache_ptr;
+    H5AC_t     *cache_ptr;
     H5AC_aux_t *aux_ptr;
     herr_t      ret_value = SUCCEED; /* Return value */
 
