@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -47,11 +46,13 @@
 /* [Simple] Macro to construct a H5D_io_info_t from it's components */
 #define H5D_BUILD_IO_INFO_WRT(io_info, ds, str, buf)                                                         \
     (io_info)->dset    = ds;                                                                                 \
+    (io_info)->f_sh    = H5F_SHARED((ds)->oloc.file);                                                        \
     (io_info)->store   = str;                                                                                \
     (io_info)->op_type = H5D_IO_OP_WRITE;                                                                    \
     (io_info)->u.wbuf  = buf
 #define H5D_BUILD_IO_INFO_RD(io_info, ds, str, buf)                                                          \
     (io_info)->dset    = ds;                                                                                 \
+    (io_info)->f_sh    = H5F_SHARED((ds)->oloc.file);                                                        \
     (io_info)->store   = str;                                                                                \
     (io_info)->op_type = H5D_IO_OP_READ;                                                                     \
     (io_info)->u.rbuf  = buf
@@ -90,7 +91,7 @@ typedef struct H5D_type_info_t {
     /* Initial values */
     const H5T_t *mem_type;    /* Pointer to memory datatype */
     const H5T_t *dset_type;   /* Pointer to dataset datatype */
-    H5T_path_t * tpath;       /* Datatype conversion path */
+    H5T_path_t  *tpath;       /* Datatype conversion path */
     hid_t        src_type_id; /* Source datatype ID */
     hid_t        dst_type_id; /* Destination datatype ID */
 
@@ -103,9 +104,9 @@ typedef struct H5D_type_info_t {
     const H5T_subset_info_t *cmpd_subset;    /* Info related to the compound subset conversion functions */
     H5T_bkg_t                need_bkg;       /* Type of background buf needed */
     size_t                   request_nelmts; /* Requested strip mine */
-    uint8_t *                tconv_buf;      /* Datatype conv buffer */
+    uint8_t                 *tconv_buf;      /* Datatype conv buffer */
     hbool_t                  tconv_buf_allocated; /* Whether the type conversion buffer was allocated */
-    uint8_t *                bkg_buf;             /* Background buffer */
+    uint8_t                 *bkg_buf;             /* Background buffer */
     hbool_t                  bkg_buf_allocated;   /* Whether the background buffer was allocated */
 } H5D_type_info_t;
 
@@ -121,13 +122,12 @@ typedef hbool_t (*H5D_layout_is_space_alloc_func_t)(const H5O_storage_t *storage
 typedef hbool_t (*H5D_layout_is_data_cached_func_t)(const H5D_shared_t *shared_dset);
 typedef herr_t (*H5D_layout_io_init_func_t)(const struct H5D_io_info_t *io_info,
                                             const H5D_type_info_t *type_info, hsize_t nelmts,
-                                            const H5S_t *file_space, const H5S_t *mem_space,
-                                            struct H5D_chunk_map_t *cm);
+                                            H5S_t *file_space, H5S_t *mem_space, struct H5D_chunk_map_t *cm);
 typedef herr_t (*H5D_layout_read_func_t)(struct H5D_io_info_t *io_info, const H5D_type_info_t *type_info,
-                                         hsize_t nelmts, const H5S_t *file_space, const H5S_t *mem_space,
+                                         hsize_t nelmts, H5S_t *file_space, H5S_t *mem_space,
                                          struct H5D_chunk_map_t *fm);
 typedef herr_t (*H5D_layout_write_func_t)(struct H5D_io_info_t *io_info, const H5D_type_info_t *type_info,
-                                          hsize_t nelmts, const H5S_t *file_space, const H5S_t *mem_space,
+                                          hsize_t nelmts, H5S_t *file_space, H5S_t *mem_space,
                                           struct H5D_chunk_map_t *fm);
 typedef ssize_t (*H5D_layout_readvv_func_t)(const struct H5D_io_info_t *io_info, size_t dset_max_nseq,
                                             size_t *dset_curr_seq, size_t dset_len_arr[],
@@ -168,10 +168,10 @@ typedef struct H5D_layout_ops_t {
 /* Function pointers for either multiple or single block I/O access */
 typedef herr_t (*H5D_io_single_read_func_t)(const struct H5D_io_info_t *io_info,
                                             const H5D_type_info_t *type_info, hsize_t nelmts,
-                                            const H5S_t *file_space, const H5S_t *mem_space);
+                                            H5S_t *file_space, H5S_t *mem_space);
 typedef herr_t (*H5D_io_single_write_func_t)(const struct H5D_io_info_t *io_info,
                                              const H5D_type_info_t *type_info, hsize_t nelmts,
-                                             const H5S_t *file_space, const H5S_t *mem_space);
+                                             H5S_t *file_space, H5S_t *mem_space);
 
 /* Typedef for raw data I/O framework info */
 typedef struct H5D_io_ops_t {
@@ -192,7 +192,7 @@ typedef struct {
 } H5D_chunk_storage_t;
 
 typedef struct {
-    void *   buf;   /* Buffer for compact dataset */
+    void    *buf;   /* Buffer for compact dataset */
     hbool_t *dirty; /* Pointer to dirty flag to mark */
 } H5D_compact_storage_t;
 
@@ -210,17 +210,19 @@ typedef enum H5D_io_op_type_t {
 } H5D_io_op_type_t;
 
 typedef struct H5D_io_info_t {
-    const H5D_t *dset; /* Pointer to dataset being operated on */
+    const H5D_t *dset;  /* Pointer to dataset being operated on */
+                        /* QAK: Delete the f_sh field when oloc has a shared file pointer? */
+    H5F_shared_t *f_sh; /* Pointer to shared file struct that dataset is within */
 #ifdef H5_HAVE_PARALLEL
     MPI_Comm comm;               /* MPI communicator for file */
     hbool_t  using_mpi_vfd;      /* Whether the file is using an MPI-based VFD */
 #endif                           /* H5_HAVE_PARALLEL */
-    H5D_storage_t *  store;      /* Dataset storage info */
+    H5D_storage_t   *store;      /* Dataset storage info */
     H5D_layout_ops_t layout_ops; /* Dataset layout I/O operation function pointers */
     H5D_io_ops_t     io_ops;     /* I/O operation function pointers */
     H5D_io_op_type_t op_type;
     union {
-        void *      rbuf; /* Pointer to buffer for read */
+        void       *rbuf; /* Pointer to buffer for read */
         const void *wbuf; /* Pointer to buffer to write */
     } u;
 } H5D_io_info_t;
@@ -231,9 +233,9 @@ typedef struct H5D_io_info_t {
 
 /* Typedef for chunked dataset index operation info */
 typedef struct H5D_chk_idx_info_t {
-    H5F_t *              f;       /* File pointer for operation */
-    const H5O_pline_t *  pline;   /* I/O pipeline info */
-    H5O_layout_chunk_t * layout;  /* Chunk layout description */
+    H5F_t               *f;       /* File pointer for operation */
+    const H5O_pline_t   *pline;   /* I/O pipeline info */
+    H5O_layout_chunk_t  *layout;  /* Chunk layout description */
     H5O_storage_chunk_t *storage; /* Chunk storage description */
 } H5D_chk_idx_info_t;
 
@@ -261,9 +263,9 @@ typedef struct H5D_chunk_rec_t {
  * to which the index points.
  */
 typedef struct H5D_chunk_common_ud_t {
-    const H5O_layout_chunk_t * layout;  /* Chunk layout description */
+    const H5O_layout_chunk_t  *layout;  /* Chunk layout description */
     const H5O_storage_chunk_t *storage; /* Chunk storage description */
-    const hsize_t *            scaled;  /* Scaled coordinates for a chunk */
+    const hsize_t             *scaled;  /* Scaled coordinates for a chunk */
 } H5D_chunk_common_ud_t;
 
 /* B-tree callback info for various operations */
@@ -331,9 +333,9 @@ typedef struct H5D_chunk_info_t {
     hsize_t  index;                    /* "Index" of chunk in dataset */
     uint32_t chunk_points;             /* Number of elements selected in chunk */
     hsize_t  scaled[H5O_LAYOUT_NDIMS]; /* Scaled coordinates of chunk (in file dataset's dataspace) */
-    H5S_t *  fspace;                   /* Dataspace describing chunk & selection in it */
+    H5S_t   *fspace;                   /* Dataspace describing chunk & selection in it */
     hbool_t  fspace_shared; /* Indicate that the file space for a chunk is shared and shouldn't be freed */
-    H5S_t *  mspace;        /* Dataspace describing selection in memory corresponding to this chunk */
+    H5S_t   *mspace;        /* Dataspace describing selection in memory corresponding to this chunk */
     hbool_t  mspace_shared; /* Indicate that the memory space for a chunk is shared and shouldn't be freed */
 } H5D_chunk_info_t;
 
@@ -342,11 +344,11 @@ typedef struct H5D_chunk_map_t {
     H5O_layout_t *layout; /* Dataset layout information*/
     hsize_t       nelmts; /* Number of elements selected in file & memory dataspaces */
 
-    const H5S_t *file_space; /* Pointer to the file dataspace */
-    unsigned     f_ndims;    /* Number of dimensions for file dataspace */
+    H5S_t   *file_space; /* Pointer to the file dataspace */
+    unsigned f_ndims;    /* Number of dimensions for file dataspace */
 
-    const H5S_t *  mem_space;   /* Pointer to the memory dataspace */
-    H5S_t *        mchunk_tmpl; /* Dataspace template for new memory chunks */
+    H5S_t         *mem_space;   /* Pointer to the memory dataspace */
+    H5S_t         *mchunk_tmpl; /* Dataspace template for new memory chunks */
     H5S_sel_iter_t mem_iter;    /* Iterator for elements in memory selection */
     unsigned       m_ndims;     /* Number of dimensions for memory dataspace */
     H5S_sel_type   msel_type;   /* Selection type in memory */
@@ -354,7 +356,7 @@ typedef struct H5D_chunk_map_t {
 
     H5SL_t *sel_chunks; /* Skip list containing information for each chunk selected */
 
-    H5S_t *           single_space;      /* Dataspace for single chunk */
+    H5S_t            *single_space;      /* Dataspace for single chunk */
     H5D_chunk_info_t *single_chunk_info; /* Pointer to single chunk's info */
     hbool_t           use_single;        /* Whether I/O is on a single element */
 
@@ -384,7 +386,7 @@ typedef struct H5D_chunk_cached_t {
 
 /* List of files held open during refresh operations */
 typedef struct H5D_virtual_held_file_t {
-    H5F_t *                         file; /* Pointer to file held open */
+    H5F_t                          *file; /* Pointer to file held open */
     struct H5D_virtual_held_file_t *next; /* Pointer to next node in list */
 } H5D_virtual_held_file_t;
 
@@ -409,9 +411,9 @@ typedef struct H5D_rdcc_t {
     int                     nused;             /* Number of chunk slots in use        */
     H5D_chunk_cached_t      last;              /* Cached copy of last chunk information */
     struct H5D_rdcc_ent_t **slot;              /* Chunk slots, each points to a chunk*/
-    H5SL_t *                sel_chunks;        /* Skip list containing information for each chunk selected */
-    H5S_t *                 single_space;      /* Dataspace for single element I/O on chunks */
-    H5D_chunk_info_t *      single_chunk_info; /* Pointer to single chunk's info */
+    H5SL_t                 *sel_chunks;        /* Skip list containing information for each chunk selected */
+    H5S_t                  *single_space;      /* Dataspace for single element I/O on chunks */
+    H5D_chunk_info_t       *single_chunk_info; /* Pointer to single chunk's info */
 
     /* Cached information about scaled dataspace dimensions */
     hsize_t  scaled_dims[H5S_MAX_RANK];        /* The scaled dim sizes */
@@ -430,7 +432,7 @@ typedef struct H5D_rdcdc_t {
 
 /*
  * A dataset is made of two layers, an H5D_t struct that is unique to
- * each instance of an opened datset, and a shared struct that is only
+ * each instance of an opened dataset, and a shared struct that is only
  * created once for a given dataset.  Thus, if a dataset is opened twice,
  * there will be two IDs and two H5D_t structs, both sharing one H5D_shared_t.
  */
@@ -438,8 +440,8 @@ struct H5D_shared_t {
     size_t           fo_count;        /* Reference count */
     hbool_t          closing;         /* Flag to indicate dataset is closing */
     hid_t            type_id;         /* ID for dataset's datatype    */
-    H5T_t *          type;            /* Datatype for this dataset     */
-    H5S_t *          space;           /* Dataspace of this dataset    */
+    H5T_t           *type;            /* Datatype for this dataset     */
+    H5S_t           *space;           /* Dataspace of this dataset    */
     hid_t            dcpl_id;         /* Dataset creation property id */
     hid_t            dapl_id;         /* Dataset access property id */
     H5D_dcpl_cache_t dcpl_cache;      /* Cached DCPL values */
@@ -463,8 +465,8 @@ struct H5D_shared_t {
     } cache;
 
     H5D_append_flush_t append_flush;   /* Append flush property information */
-    char *             extfile_prefix; /* expanded external file prefix */
-    char *             vds_prefix;     /* expanded vds prefix */
+    char              *extfile_prefix; /* expanded external file prefix */
+    char              *vds_prefix;     /* expanded vds prefix */
 };
 
 struct H5D_t {
@@ -492,21 +494,21 @@ typedef struct {
 /* Typedef for filling a buffer with a fill value */
 typedef struct H5D_fill_buf_info_t {
     H5MM_allocate_t fill_alloc_func; /* Routine to call for allocating fill buffer */
-    void *          fill_alloc_info; /* Extra info for allocation routine */
+    void           *fill_alloc_info; /* Extra info for allocation routine */
     H5MM_free_t     fill_free_func;  /* Routine to call for freeing fill buffer */
-    void *          fill_free_info;  /* Extra info for free routine */
+    void           *fill_free_info;  /* Extra info for free routine */
     H5T_path_t
         *fill_to_mem_tpath; /* Datatype conversion path for converting the fill value to the memory buffer */
     H5T_path_t *mem_to_dset_tpath; /* Datatype conversion path for converting the memory buffer to the dataset
                                       elements */
     const H5O_fill_t *fill;        /* Pointer to fill value */
-    void *            fill_buf;    /* Fill buffer */
+    void             *fill_buf;    /* Fill buffer */
     size_t            fill_buf_size;                 /* Size of fill buffer */
     hbool_t           use_caller_fill_buf;           /* Whether the caller provided the fill buffer */
-    void *            bkg_buf;                       /* Background conversion buffer */
+    void             *bkg_buf;                       /* Background conversion buffer */
     size_t            bkg_buf_size;                  /* Size of background buffer */
-    H5T_t *           mem_type;                      /* Pointer to memory datatype */
-    const H5T_t *     file_type;                     /* Pointer to file datatype */
+    H5T_t            *mem_type;                      /* Pointer to memory datatype */
+    const H5T_t      *file_type;                     /* Pointer to file datatype */
     hid_t             mem_tid;                       /* ID for memory version of disk datatype */
     hid_t             file_tid;                      /* ID for disk datatype */
     size_t            mem_elmt_size, file_elmt_size; /* Size of element in memory and on disk */
@@ -515,16 +517,6 @@ typedef struct H5D_fill_buf_info_t {
     hbool_t has_vlen_fill_type; /* Whether the datatype for the fill value has a variable-length component */
 } H5D_fill_buf_info_t;
 
-/* Internal data structure for computing variable-length dataset's total size */
-typedef struct {
-    H5D_t * dset;    /* Dataset for operation */
-    H5S_t * fspace;  /* Dataset's dataspace for operation */
-    H5S_t * mspace;  /* Memory dataspace for operation */
-    void *  fl_tbuf; /* Ptr to the temporary buffer we are using for fixed-length data */
-    void *  vl_tbuf; /* Ptr to the temporary buffer we are using for VL data */
-    hsize_t size;    /* Accumulated number of bytes for the selection */
-} H5D_vlen_bufsize_t;
-
 /*****************************/
 /* Package Private Variables */
 /*****************************/
@@ -555,10 +547,10 @@ H5_DLLVAR const unsigned H5O_layout_ver_bounds[H5F_LIBVER_NBOUNDS];
 /* Package Private Prototypes */
 /******************************/
 
-H5_DLL H5D_t *H5D__create(H5F_t *file, hid_t type_id, const H5S_t *space, hid_t dcpl_id, hid_t dapl_id);
-H5_DLL H5D_t *H5D__create_named(const H5G_loc_t *loc, const char *name, hid_t type_id, const H5S_t *space,
-                                hid_t lcpl_id, hid_t dcpl_id, hid_t dapl_id);
-H5_DLL H5D_t * H5D__open_name(const H5G_loc_t *loc, const char *name, hid_t dapl_id);
+H5_DLL H5D_t  *H5D__create(H5F_t *file, hid_t type_id, const H5S_t *space, hid_t dcpl_id, hid_t dapl_id);
+H5_DLL H5D_t  *H5D__create_named(const H5G_loc_t *loc, const char *name, hid_t type_id, const H5S_t *space,
+                                 hid_t lcpl_id, hid_t dcpl_id, hid_t dapl_id);
+H5_DLL H5D_t  *H5D__open_name(const H5G_loc_t *loc, const char *name, hid_t dapl_id);
 H5_DLL hid_t   H5D__get_space(const H5D_t *dset);
 H5_DLL hid_t   H5D__get_type(const H5D_t *dset);
 H5_DLL herr_t  H5D__get_space_status(const H5D_t *dset, H5D_space_status_t *allocation);
@@ -566,16 +558,17 @@ H5_DLL herr_t  H5D__alloc_storage(const H5D_io_info_t *io_info, H5D_time_alloc_t
                                   hbool_t full_overwrite, hsize_t old_dim[]);
 H5_DLL herr_t  H5D__get_storage_size(const H5D_t *dset, hsize_t *storage_size);
 H5_DLL herr_t  H5D__get_chunk_storage_size(H5D_t *dset, const hsize_t *offset, hsize_t *storage_size);
+H5_DLL herr_t  H5D__chunk_index_empty(const H5D_t *dset, hbool_t *empty);
 H5_DLL herr_t  H5D__get_num_chunks(const H5D_t *dset, const H5S_t *space, hsize_t *nchunks);
 H5_DLL herr_t  H5D__get_chunk_info(const H5D_t *dset, const H5S_t *space, hsize_t chk_idx, hsize_t *coord,
                                    unsigned *filter_mask, haddr_t *offset, hsize_t *size);
 H5_DLL herr_t  H5D__get_chunk_info_by_coord(const H5D_t *dset, const hsize_t *coord, unsigned *filter_mask,
                                             haddr_t *addr, hsize_t *size);
+H5_DLL herr_t  H5D__chunk_iter(H5D_t *dset, H5D_chunk_iter_op_t cb, void *op_data);
 H5_DLL haddr_t H5D__get_offset(const H5D_t *dset);
-H5_DLL void *  H5D__vlen_get_buf_size_alloc(size_t size, void *info);
-H5_DLL herr_t  H5D__vlen_get_buf_size(void *elem, hid_t type_id, unsigned ndim, const hsize_t *point,
-                                      void *op_data);
-H5_DLL herr_t  H5D__check_filters(H5D_t *dataset);
+H5_DLL herr_t  H5D__vlen_get_buf_size(H5D_t *dset, hid_t type_id, hid_t space_id, hsize_t *size);
+H5_DLL herr_t  H5D__vlen_get_buf_size_gen(H5VL_object_t *vol_obj, hid_t type_id, hid_t space_id,
+                                          hsize_t *size);
 H5_DLL herr_t  H5D__set_extent(H5D_t *dataset, const hsize_t *size);
 H5_DLL herr_t  H5D__flush_sieve_buf(H5D_t *dataset);
 H5_DLL herr_t  H5D__flush_real(H5D_t *dataset);
@@ -587,25 +580,29 @@ H5_DLL herr_t  H5D__refresh(hid_t dset_id, H5D_t *dataset);
 H5_DLL herr_t H5D__format_convert(H5D_t *dataset);
 
 /* Internal I/O routines */
-H5_DLL herr_t H5D__read(H5D_t *dataset, hid_t mem_type_id, const H5S_t *mem_space, const H5S_t *file_space,
+H5_DLL herr_t H5D__read(H5D_t *dataset, hid_t mem_type_id, H5S_t *mem_space, H5S_t *file_space,
                         void *buf /*out*/);
-H5_DLL herr_t H5D__write(H5D_t *dataset, hid_t mem_type_id, const H5S_t *mem_space, const H5S_t *file_space,
+H5_DLL herr_t H5D__write(H5D_t *dataset, hid_t mem_type_id, H5S_t *mem_space, H5S_t *file_space,
                          const void *buf);
 
 /* Functions that perform direct serial I/O operations */
 H5_DLL herr_t H5D__select_read(const H5D_io_info_t *io_info, const H5D_type_info_t *type_info, hsize_t nelmts,
-                               const H5S_t *file_space, const H5S_t *mem_space);
+                               H5S_t *file_space, H5S_t *mem_space);
 H5_DLL herr_t H5D__select_write(const H5D_io_info_t *io_info, const H5D_type_info_t *type_info,
-                                hsize_t nelmts, const H5S_t *file_space, const H5S_t *mem_space);
+                                hsize_t nelmts, H5S_t *file_space, H5S_t *mem_space);
+
+/* Functions that perform direct copying between memory buffers */
+H5_DLL herr_t H5D_select_io_mem(void *dst_buf, H5S_t *dst_space, const void *src_buf, H5S_t *src_space,
+                                size_t elmt_size, size_t nelmts);
 
 /* Functions that perform scatter-gather serial I/O operations */
 H5_DLL herr_t H5D__scatter_mem(const void *_tscat_buf, H5S_sel_iter_t *iter, size_t nelmts, void *_buf);
 H5_DLL size_t H5D__gather_mem(const void *_buf, H5S_sel_iter_t *iter, size_t nelmts,
                               void *_tgath_buf /*out*/);
 H5_DLL herr_t H5D__scatgath_read(const H5D_io_info_t *io_info, const H5D_type_info_t *type_info,
-                                 hsize_t nelmts, const H5S_t *file_space, const H5S_t *mem_space);
+                                 hsize_t nelmts, H5S_t *file_space, H5S_t *mem_space);
 H5_DLL herr_t H5D__scatgath_write(const H5D_io_info_t *io_info, const H5D_type_info_t *type_info,
-                                  hsize_t nelmts, const H5S_t *file_space, const H5S_t *mem_space);
+                                  hsize_t nelmts, H5S_t *file_space, H5S_t *mem_space);
 
 /* Functions that operate on dataset's layout information */
 H5_DLL herr_t H5D__layout_set_io_ops(const H5D_t *dataset);
@@ -623,9 +620,9 @@ H5_DLL hbool_t H5D__contig_is_space_alloc(const H5O_storage_t *storage);
 H5_DLL hbool_t H5D__contig_is_data_cached(const H5D_shared_t *shared_dset);
 H5_DLL herr_t  H5D__contig_fill(const H5D_io_info_t *io_info);
 H5_DLL herr_t  H5D__contig_read(H5D_io_info_t *io_info, const H5D_type_info_t *type_info, hsize_t nelmts,
-                                const H5S_t *file_space, const H5S_t *mem_space, H5D_chunk_map_t *fm);
+                                H5S_t *file_space, H5S_t *mem_space, H5D_chunk_map_t *fm);
 H5_DLL herr_t  H5D__contig_write(H5D_io_info_t *io_info, const H5D_type_info_t *type_info, hsize_t nelmts,
-                                 const H5S_t *file_space, const H5S_t *mem_space, H5D_chunk_map_t *fm);
+                                 H5S_t *file_space, H5S_t *mem_space, H5D_chunk_map_t *fm);
 H5_DLL herr_t  H5D__contig_copy(H5F_t *f_src, const H5O_storage_contig_t *storage_src, H5F_t *f_dst,
                                 H5O_storage_contig_t *storage_dst, H5T_t *src_dtype, H5O_copy_t *cpy_info);
 H5_DLL herr_t  H5D__contig_delete(H5F_t *f, const H5O_storage_t *store);
@@ -641,8 +638,14 @@ H5_DLL herr_t  H5D__chunk_allocated(const H5D_t *dset, hsize_t *nbytes);
 H5_DLL herr_t  H5D__chunk_allocate(const H5D_io_info_t *io_info, hbool_t full_overwrite,
                                    const hsize_t old_dim[]);
 H5_DLL herr_t  H5D__chunk_file_alloc(const H5D_chk_idx_info_t *idx_info, const H5F_block_t *old_chunk,
-                                     H5F_block_t *new_chunk, hbool_t *need_insert, hsize_t scaled[]);
+                                     H5F_block_t *new_chunk, hbool_t *need_insert, const hsize_t *scaled);
+H5_DLL void   *H5D__chunk_mem_alloc(size_t size, void *pline);
+H5_DLL void    H5D__chunk_mem_free(void *chk, void *pline);
+H5_DLL void   *H5D__chunk_mem_xfree(void *chk, const void *pline);
+H5_DLL void   *H5D__chunk_mem_realloc(void *chk, size_t size, const H5O_pline_t *pline);
 H5_DLL herr_t  H5D__chunk_update_old_edge_chunks(H5D_t *dset, hsize_t old_dim[]);
+H5_DLL hbool_t H5D__chunk_is_partial_edge_chunk(unsigned dset_ndims, const uint32_t *chunk_dims,
+                                                const hsize_t *chunk_scaled, const hsize_t *dset_dims);
 H5_DLL herr_t  H5D__chunk_prune_by_extent(H5D_t *dset, const hsize_t *old_dim);
 H5_DLL herr_t  H5D__chunk_set_sizes(H5D_t *dset);
 #ifdef H5_HAVE_PARALLEL
@@ -656,6 +659,7 @@ H5_DLL herr_t H5D__chunk_copy(H5F_t *f_src, H5O_storage_chunk_t *storage_src, H5
 H5_DLL herr_t H5D__chunk_bh_info(const H5O_loc_t *loc, H5O_t *oh, H5O_layout_t *layout, hsize_t *btree_size);
 H5_DLL herr_t H5D__chunk_dump_index(H5D_t *dset, FILE *stream);
 H5_DLL herr_t H5D__chunk_delete(H5F_t *f, H5O_t *oh, H5O_storage_t *store);
+H5_DLL herr_t H5D__get_offset_copy(const H5D_t *dset, const hsize_t *offset, hsize_t *offset_copy);
 H5_DLL herr_t H5D__chunk_direct_write(const H5D_t *dset, uint32_t filters, hsize_t *offset,
                                       uint32_t data_size, const void *buf);
 H5_DLL herr_t H5D__chunk_direct_read(const H5D_t *dset, hsize_t *offset, uint32_t *filters, void *buf);
@@ -691,7 +695,7 @@ H5_DLL herr_t  H5D__efl_bh_info(H5F_t *f, H5O_efl_t *efl, hsize_t *heap_size);
 
 /* Functions that perform fill value operations on datasets */
 H5_DLL herr_t H5D__fill(const void *fill, const H5T_t *fill_type, void *buf, const H5T_t *buf_type,
-                        const H5S_t *space);
+                        H5S_t *space);
 H5_DLL herr_t H5D__fill_init(H5D_fill_buf_info_t *fb_info, void *caller_fill_buf, H5MM_allocate_t alloc_func,
                              void *alloc_info, H5MM_free_t free_func, void *free_info, const H5O_fill_t *fill,
                              const H5T_t *dset_type, hid_t dset_type_id, size_t nelmts, size_t min_buf_size);
@@ -700,39 +704,41 @@ H5_DLL herr_t H5D__fill_term(H5D_fill_buf_info_t *fb_info);
 
 #ifdef H5_HAVE_PARALLEL
 
-#ifdef H5S_DEBUG
+#ifdef H5D_DEBUG
 #ifndef H5Dmpio_DEBUG
 #define H5Dmpio_DEBUG
 #endif /*H5Dmpio_DEBUG*/
-#endif /*H5S_DEBUG*/
+#endif /*H5D_DEBUG*/
 /* MPI-IO function to read, it will select either regular or irregular read */
 H5_DLL herr_t H5D__mpio_select_read(const H5D_io_info_t *io_info, const H5D_type_info_t *type_info,
-                                    hsize_t nelmts, const H5S_t *file_space, const H5S_t *mem_space);
+                                    hsize_t nelmts, H5S_t *file_space, H5S_t *mem_space);
 
 /* MPI-IO function to write, it will select either regular or irregular read */
 H5_DLL herr_t H5D__mpio_select_write(const H5D_io_info_t *io_info, const H5D_type_info_t *type_info,
-                                     hsize_t nelmts, const H5S_t *file_space, const H5S_t *mem_space);
+                                     hsize_t nelmts, H5S_t *file_space, H5S_t *mem_space);
 
 /* MPI-IO functions to handle contiguous collective IO */
 H5_DLL herr_t H5D__contig_collective_read(H5D_io_info_t *io_info, const H5D_type_info_t *type_info,
-                                          hsize_t nelmts, const H5S_t *file_space, const H5S_t *mem_space,
+                                          hsize_t nelmts, H5S_t *file_space, H5S_t *mem_space,
                                           H5D_chunk_map_t *fm);
 H5_DLL herr_t H5D__contig_collective_write(H5D_io_info_t *io_info, const H5D_type_info_t *type_info,
-                                           hsize_t nelmts, const H5S_t *file_space, const H5S_t *mem_space,
+                                           hsize_t nelmts, H5S_t *file_space, H5S_t *mem_space,
                                            H5D_chunk_map_t *fm);
 
 /* MPI-IO functions to handle chunked collective IO */
 H5_DLL herr_t H5D__chunk_collective_read(H5D_io_info_t *io_info, const H5D_type_info_t *type_info,
-                                         hsize_t nelmts, const H5S_t *file_space, const H5S_t *mem_space,
+                                         hsize_t nelmts, H5S_t *file_space, H5S_t *mem_space,
                                          H5D_chunk_map_t *fm);
 H5_DLL herr_t H5D__chunk_collective_write(H5D_io_info_t *io_info, const H5D_type_info_t *type_info,
-                                          hsize_t nelmts, const H5S_t *file_space, const H5S_t *mem_space,
+                                          hsize_t nelmts, H5S_t *file_space, H5S_t *mem_space,
                                           H5D_chunk_map_t *fm);
 
 /* MPI-IO function to check if a direct I/O transfer is possible between
  * memory and the file */
 H5_DLL htri_t H5D__mpio_opt_possible(const H5D_io_info_t *io_info, const H5S_t *file_space,
                                      const H5S_t *mem_space, const H5D_type_info_t *type_info);
+H5_DLL herr_t H5D__mpio_get_no_coll_cause_strings(char *local_cause, size_t local_cause_len,
+                                                  char *global_cause, size_t global_cause_len);
 
 #endif /* H5_HAVE_PARALLEL */
 
