@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -119,58 +118,58 @@ typedef struct H5FD_direct_t {
     (ADDR_OVERFLOW(A) || SIZE_OVERFLOW(Z) || HADDR_UNDEF == (A) + (Z) || (HDoff_t)((A) + (Z)) < (HDoff_t)(A))
 
 /* Prototypes */
-static herr_t  H5FD_direct_term(void);
-static void *  H5FD_direct_fapl_get(H5FD_t *file);
-static void *  H5FD_direct_fapl_copy(const void *_old_fa);
-static H5FD_t *H5FD_direct_open(const char *name, unsigned flags, hid_t fapl_id, haddr_t maxaddr);
-static herr_t  H5FD_direct_close(H5FD_t *_file);
-static int     H5FD_direct_cmp(const H5FD_t *_f1, const H5FD_t *_f2);
-static herr_t  H5FD_direct_query(const H5FD_t *_f1, unsigned long *flags);
-static haddr_t H5FD_direct_get_eoa(const H5FD_t *_file, H5FD_mem_t type);
-static herr_t  H5FD_direct_set_eoa(H5FD_t *_file, H5FD_mem_t type, haddr_t addr);
-static haddr_t H5FD_direct_get_eof(const H5FD_t *_file, H5FD_mem_t type);
-static herr_t  H5FD_direct_get_handle(H5FD_t *_file, hid_t fapl, void **file_handle);
-static herr_t  H5FD_direct_read(H5FD_t *_file, H5FD_mem_t type, hid_t fapl_id, haddr_t addr, size_t size,
-                                void *buf);
-static herr_t  H5FD_direct_write(H5FD_t *_file, H5FD_mem_t type, hid_t fapl_id, haddr_t addr, size_t size,
-                                 const void *buf);
-static herr_t  H5FD_direct_truncate(H5FD_t *_file, hid_t dxpl_id, hbool_t closing);
-static herr_t  H5FD_direct_lock(H5FD_t *_file, hbool_t rw);
-static herr_t  H5FD_direct_unlock(H5FD_t *_file);
+static herr_t  H5FD__direct_term(void);
+static void   *H5FD__direct_fapl_get(H5FD_t *file);
+static void   *H5FD__direct_fapl_copy(const void *_old_fa);
+static H5FD_t *H5FD__direct_open(const char *name, unsigned flags, hid_t fapl_id, haddr_t maxaddr);
+static herr_t  H5FD__direct_close(H5FD_t *_file);
+static int     H5FD__direct_cmp(const H5FD_t *_f1, const H5FD_t *_f2);
+static herr_t  H5FD__direct_query(const H5FD_t *_f1, unsigned long *flags);
+static haddr_t H5FD__direct_get_eoa(const H5FD_t *_file, H5FD_mem_t type);
+static herr_t  H5FD__direct_set_eoa(H5FD_t *_file, H5FD_mem_t type, haddr_t addr);
+static haddr_t H5FD__direct_get_eof(const H5FD_t *_file, H5FD_mem_t type);
+static herr_t  H5FD__direct_get_handle(H5FD_t *_file, hid_t fapl, void **file_handle);
+static herr_t  H5FD__direct_read(H5FD_t *_file, H5FD_mem_t type, hid_t fapl_id, haddr_t addr, size_t size,
+                                 void *buf);
+static herr_t  H5FD__direct_write(H5FD_t *_file, H5FD_mem_t type, hid_t fapl_id, haddr_t addr, size_t size,
+                                  const void *buf);
+static herr_t  H5FD__direct_truncate(H5FD_t *_file, hid_t dxpl_id, hbool_t closing);
+static herr_t  H5FD__direct_lock(H5FD_t *_file, hbool_t rw);
+static herr_t  H5FD__direct_unlock(H5FD_t *_file);
 
 static const H5FD_class_t H5FD_direct_g = {
-    "direct",                   /*name      */
-    MAXADDR,                    /*maxaddr    */
-    H5F_CLOSE_WEAK,             /* fc_degree    */
-    H5FD_direct_term,           /*terminate             */
-    NULL,                       /*sb_size    */
-    NULL,                       /*sb_encode    */
-    NULL,                       /*sb_decode    */
-    sizeof(H5FD_direct_fapl_t), /*fapl_size    */
-    H5FD_direct_fapl_get,       /*fapl_get    */
-    H5FD_direct_fapl_copy,      /*fapl_copy    */
-    NULL,                       /*fapl_free    */
-    0,                          /*dxpl_size    */
-    NULL,                       /*dxpl_copy    */
-    NULL,                       /*dxpl_free    */
-    H5FD_direct_open,           /*open      */
-    H5FD_direct_close,          /*close      */
-    H5FD_direct_cmp,            /*cmp      */
-    H5FD_direct_query,          /*query      */
-    NULL,                       /*get_type_map    */
-    NULL,                       /*alloc      */
-    NULL,                       /*free      */
-    H5FD_direct_get_eoa,        /*get_eoa    */
-    H5FD_direct_set_eoa,        /*set_eoa    */
-    H5FD_direct_get_eof,        /*get_eof    */
-    H5FD_direct_get_handle,     /*get_handle            */
-    H5FD_direct_read,           /*read      */
-    H5FD_direct_write,          /*write      */
-    NULL,                       /*flush      */
-    H5FD_direct_truncate,       /*truncate    */
-    H5FD_direct_lock,           /*lock                  */
-    H5FD_direct_unlock,         /*unlock                */
-    H5FD_FLMAP_DICHOTOMY        /*fl_map                */
+    "direct",                   /* name                 */
+    MAXADDR,                    /* maxaddr              */
+    H5F_CLOSE_WEAK,             /* fc_degree            */
+    H5FD__direct_term,          /* terminate            */
+    NULL,                       /* sb_size              */
+    NULL,                       /* sb_encode            */
+    NULL,                       /* sb_decode            */
+    sizeof(H5FD_direct_fapl_t), /* fapl_size            */
+    H5FD__direct_fapl_get,      /* fapl_get             */
+    H5FD__direct_fapl_copy,     /* fapl_copy            */
+    NULL,                       /* fapl_free            */
+    0,                          /* dxpl_size            */
+    NULL,                       /* dxpl_copy            */
+    NULL,                       /* dxpl_free            */
+    H5FD__direct_open,          /* open                 */
+    H5FD__direct_close,         /* close                */
+    H5FD__direct_cmp,           /* cmp                  */
+    H5FD__direct_query,         /* query                */
+    NULL,                       /* get_type_map         */
+    NULL,                       /* alloc                */
+    NULL,                       /* free                 */
+    H5FD__direct_get_eoa,       /* get_eoa              */
+    H5FD__direct_set_eoa,       /* set_eoa              */
+    H5FD__direct_get_eof,       /* get_eof              */
+    H5FD__direct_get_handle,    /* get_handle           */
+    H5FD__direct_read,          /* read                 */
+    H5FD__direct_write,         /* write                */
+    NULL,                       /* flush                */
+    H5FD__direct_truncate,      /* truncate             */
+    H5FD__direct_lock,          /* lock                 */
+    H5FD__direct_unlock,        /* unlock               */
+    H5FD_FLMAP_DICHOTOMY        /* fl_map               */
 };
 
 /* Declare a free list to manage the H5FD_direct_t struct */
@@ -191,7 +190,7 @@ DESCRIPTION
 static herr_t
 H5FD__init_package(void)
 {
-    char * lock_env_var = NULL; /* Environment variable pointer */
+    char  *lock_env_var = NULL; /* Environment variable pointer */
     herr_t ret_value    = SUCCEED;
 
     FUNC_ENTER_STATIC
@@ -233,8 +232,11 @@ H5FD_direct_init(void)
 
     FUNC_ENTER_NOAPI(H5I_INVALID_HID)
 
-    if (H5I_VFL != H5I_get_type(H5FD_DIRECT_g))
+    if (H5I_VFL != H5I_get_type(H5FD_DIRECT_g)) {
         H5FD_DIRECT_g = H5FD_register(&H5FD_direct_g, sizeof(H5FD_class_t), FALSE);
+        if (H5I_INVALID_HID == H5FD_DIRECT_g)
+            HGOTO_ERROR(H5E_ATOM, H5E_CANTREGISTER, H5I_INVALID_HID, "unable to register direct");
+    }
 
     /* Set return value */
     ret_value = H5FD_DIRECT_g;
@@ -244,7 +246,7 @@ done:
 } /* end H5FD_direct_init() */
 
 /*---------------------------------------------------------------------------
- * Function:  H5FD_direct_term
+ * Function:  H5FD__direct_term
  *
  * Purpose:  Shut down the VFD
  *
@@ -256,15 +258,15 @@ done:
  *---------------------------------------------------------------------------
  */
 static herr_t
-H5FD_direct_term(void)
+H5FD__direct_term(void)
 {
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_STATIC_NOERR
 
     /* Reset VFL ID */
     H5FD_DIRECT_g = 0;
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5FD_direct_term() */
+} /* end H5FD__direct_term() */
 
 /*-------------------------------------------------------------------------
  * Function:  H5Pset_fapl_direct
@@ -283,7 +285,7 @@ H5FD_direct_term(void)
 herr_t
 H5Pset_fapl_direct(hid_t fapl_id, size_t boundary, size_t block_size, size_t cbuf_size)
 {
-    H5P_genplist_t *   plist; /* Property list pointer */
+    H5P_genplist_t    *plist; /* Property list pointer */
     H5FD_direct_fapl_t fa;
     herr_t             ret_value;
 
@@ -339,7 +341,7 @@ herr_t
 H5Pget_fapl_direct(hid_t fapl_id, size_t *boundary /*out*/, size_t *block_size /*out*/,
                    size_t *cbuf_size /*out*/)
 {
-    H5P_genplist_t *          plist; /* Property list pointer */
+    H5P_genplist_t           *plist; /* Property list pointer */
     const H5FD_direct_fapl_t *fa;
     herr_t                    ret_value = SUCCEED; /* Return value */
 
@@ -364,7 +366,7 @@ done:
 } /* end H5Pget_fapl_direct() */
 
 /*-------------------------------------------------------------------------
- * Function:  H5FD_direct_fapl_get
+ * Function:  H5FD__direct_fapl_get
  *
  * Purpose:  Returns a file access property list which indicates how the
  *    specified file is being accessed. The return list could be
@@ -381,22 +383,21 @@ done:
  *-------------------------------------------------------------------------
  */
 static void *
-H5FD_direct_fapl_get(H5FD_t *_file)
+H5FD__direct_fapl_get(H5FD_t *_file)
 {
-    H5FD_direct_t *file = (H5FD_direct_t *)_file;
-    void *         ret_value; /* Return value */
+    H5FD_direct_t *file      = (H5FD_direct_t *)_file;
+    void          *ret_value = NULL; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_STATIC_NOERR
 
     /* Set return value */
-    ret_value = H5FD_direct_fapl_copy(&(file->fa));
+    ret_value = H5FD__direct_fapl_copy(&(file->fa));
 
-done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5FD_direct_fapl_get() */
+} /* end H5FD__direct_fapl_get() */
 
 /*-------------------------------------------------------------------------
- * Function:  H5FD_direct_fapl_copy
+ * Function:  H5FD__direct_fapl_copy
  *
  * Purpose:  Copies the direct-specific file access properties.
  *
@@ -410,12 +411,12 @@ done:
  *-------------------------------------------------------------------------
  */
 static void *
-H5FD_direct_fapl_copy(const void *_old_fa)
+H5FD__direct_fapl_copy(const void *_old_fa)
 {
     const H5FD_direct_fapl_t *old_fa = (const H5FD_direct_fapl_t *)_old_fa;
-    H5FD_direct_fapl_t *      new_fa = H5MM_calloc(sizeof(H5FD_direct_fapl_t));
+    H5FD_direct_fapl_t       *new_fa = H5MM_calloc(sizeof(H5FD_direct_fapl_t));
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_STATIC_NOERR
 
     HDassert(new_fa);
 
@@ -423,10 +424,10 @@ H5FD_direct_fapl_copy(const void *_old_fa)
     H5MM_memcpy(new_fa, old_fa, sizeof(H5FD_direct_fapl_t));
 
     FUNC_LEAVE_NOAPI(new_fa)
-} /* end H5FD_direct_fapl_copy() */
+} /* end H5FD__direct_fapl_copy() */
 
 /*-------------------------------------------------------------------------
- * Function:  H5FD_direct_open
+ * Function:  H5FD__direct_open
  *
  * Purpose:  Create and/or opens a Unix file for direct I/O as an HDF5 file.
  *
@@ -442,22 +443,22 @@ H5FD_direct_fapl_copy(const void *_old_fa)
  *-------------------------------------------------------------------------
  */
 static H5FD_t *
-H5FD_direct_open(const char *name, unsigned flags, hid_t fapl_id, haddr_t maxaddr)
+H5FD__direct_open(const char *name, unsigned flags, hid_t fapl_id, haddr_t maxaddr)
 {
-    int                 o_flags;
-    int                 fd   = (-1);
-    H5FD_direct_t *     file = NULL;
-    H5FD_direct_fapl_t *fa;
+    int                       o_flags;
+    int                       fd   = (-1);
+    H5FD_direct_t            *file = NULL;
+    const H5FD_direct_fapl_t *fa;
 #ifdef H5_HAVE_WIN32_API
     HFILE                              filehandle;
     struct _BY_HANDLE_FILE_INFORMATION fileinfo;
 #endif
     h5_stat_t       sb;
     H5P_genplist_t *plist; /* Property list */
-    void *          buf1, *buf2;
-    H5FD_t *        ret_value = NULL;
+    void           *buf1, *buf2;
+    H5FD_t         *ret_value = NULL;
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_STATIC
 
     /* Sanity check on file offsets */
     HDassert(sizeof(HDoff_t) >= sizeof(size_t));
@@ -496,7 +497,7 @@ H5FD_direct_open(const char *name, unsigned flags, hid_t fapl_id, haddr_t maxadd
     /* Get the driver specific information */
     if (NULL == (plist = H5P_object_verify(fapl_id, H5P_FILE_ACCESS)))
         HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, NULL, "not a file access property list")
-    if (NULL == (fa = (H5FD_direct_fapl_t *)H5P_peek_driver_info(plist)))
+    if (NULL == (fa = (const H5FD_direct_fapl_t *)H5P_peek_driver_info(plist)))
         HGOTO_ERROR(H5E_PLIST, H5E_BADVALUE, NULL, "bad VFL driver info")
 
     file->fd = fd;
@@ -546,7 +547,8 @@ H5FD_direct_open(const char *name, unsigned flags, hid_t fapl_id, haddr_t maxadd
         }
         else {
             file->fa.must_align = FALSE;
-            HDftruncate(file->fd, (HDoff_t)0);
+            if (-1 == HDftruncate(file->fd, (HDoff_t)0))
+                HSYS_GOTO_ERROR(H5E_IO, H5E_SEEKERROR, NULL, "unable to truncate file")
         }
     }
     else {
@@ -588,7 +590,7 @@ done:
 }
 
 /*-------------------------------------------------------------------------
- * Function:  H5FD_direct_close
+ * Function:  H5FD__direct_close
  *
  * Purpose:  Closes the file.
  *
@@ -602,12 +604,12 @@ done:
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_direct_close(H5FD_t *_file)
+H5FD__direct_close(H5FD_t *_file)
 {
     H5FD_direct_t *file      = (H5FD_direct_t *)_file;
     herr_t         ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_STATIC
 
     if (HDclose(file->fd) < 0)
         HSYS_GOTO_ERROR(H5E_IO, H5E_CANTCLOSEFILE, FAIL, "unable to close file")
@@ -619,7 +621,7 @@ done:
 }
 
 /*-------------------------------------------------------------------------
- * Function:  H5FD_direct_cmp
+ * Function:  H5FD__direct_cmp
  *
  * Purpose:  Compares two files belonging to this driver using an
  *    arbitrary (but consistent) ordering.
@@ -635,13 +637,13 @@ done:
  *-------------------------------------------------------------------------
  */
 static int
-H5FD_direct_cmp(const H5FD_t *_f1, const H5FD_t *_f2)
+H5FD__direct_cmp(const H5FD_t *_f1, const H5FD_t *_f2)
 {
     const H5FD_direct_t *f1        = (const H5FD_direct_t *)_f1;
     const H5FD_direct_t *f2        = (const H5FD_direct_t *)_f2;
     int                  ret_value = 0;
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_STATIC_NOERR
 
 #ifdef H5_HAVE_WIN32_API
     if (f1->fileindexhi < f2->fileindexhi)
@@ -683,7 +685,7 @@ done:
 }
 
 /*-------------------------------------------------------------------------
- * Function:  H5FD_direct_query
+ * Function:  H5FD__direct_query
  *
  * Purpose:  Set the flags that this VFL driver is capable of supporting.
  *              (listed in H5FDpublic.h)
@@ -698,9 +700,9 @@ done:
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_direct_query(const H5FD_t H5_ATTR_UNUSED *_f, unsigned long *flags /* out */)
+H5FD__direct_query(const H5FD_t H5_ATTR_UNUSED *_f, unsigned long *flags /* out */)
 {
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_STATIC_NOERR
 
     /* Set the VFL feature flags that this driver supports */
     if (flags) {
@@ -717,7 +719,7 @@ H5FD_direct_query(const H5FD_t H5_ATTR_UNUSED *_f, unsigned long *flags /* out *
 }
 
 /*-------------------------------------------------------------------------
- * Function:  H5FD_direct_get_eoa
+ * Function:  H5FD__direct_get_eoa
  *
  * Purpose:  Gets the end-of-address marker for the file. The EOA marker
  *    is the first address past the last byte allocated in the
@@ -733,17 +735,17 @@ H5FD_direct_query(const H5FD_t H5_ATTR_UNUSED *_f, unsigned long *flags /* out *
  *-------------------------------------------------------------------------
  */
 static haddr_t
-H5FD_direct_get_eoa(const H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type)
+H5FD__direct_get_eoa(const H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type)
 {
     const H5FD_direct_t *file = (const H5FD_direct_t *)_file;
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_STATIC_NOERR
 
     FUNC_LEAVE_NOAPI(file->eoa)
 }
 
 /*-------------------------------------------------------------------------
- * Function:  H5FD_direct_set_eoa
+ * Function:  H5FD__direct_set_eoa
  *
  * Purpose:  Set the end-of-address marker for the file. This function is
  *    called shortly after an existing HDF5 file is opened in order
@@ -759,11 +761,11 @@ H5FD_direct_get_eoa(const H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type)
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_direct_set_eoa(H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type, haddr_t addr)
+H5FD__direct_set_eoa(H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type, haddr_t addr)
 {
     H5FD_direct_t *file = (H5FD_direct_t *)_file;
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_STATIC_NOERR
 
     file->eoa = addr;
 
@@ -771,7 +773,7 @@ H5FD_direct_set_eoa(H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type, haddr_t addr)
 }
 
 /*-------------------------------------------------------------------------
- * Function:  H5FD_direct_get_eof
+ * Function:  H5FD__direct_get_eof
  *
  * Purpose:  Returns the end-of-file marker, which is the greater of
  *    either the Unix end-of-file or the HDF5 end-of-address
@@ -789,11 +791,11 @@ H5FD_direct_set_eoa(H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type, haddr_t addr)
  *-------------------------------------------------------------------------
  */
 static haddr_t
-H5FD_direct_get_eof(const H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type)
+H5FD__direct_get_eof(const H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type)
 {
     const H5FD_direct_t *file = (const H5FD_direct_t *)_file;
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_STATIC_NOERR
 
     FUNC_LEAVE_NOAPI(file->eof)
 }
@@ -811,12 +813,12 @@ H5FD_direct_get_eof(const H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type)
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_direct_get_handle(H5FD_t *_file, hid_t H5_ATTR_UNUSED fapl, void **file_handle)
+H5FD__direct_get_handle(H5FD_t *_file, hid_t H5_ATTR_UNUSED fapl, void **file_handle)
 {
     H5FD_direct_t *file      = (H5FD_direct_t *)_file;
     herr_t         ret_value = SUCCEED;
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_STATIC
 
     if (!file_handle)
         HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "file handle not valid")
@@ -827,7 +829,7 @@ done:
 }
 
 /*-------------------------------------------------------------------------
- * Function:  H5FD_direct_read
+ * Function:  H5FD__direct_read
  *
  * Purpose:  Reads SIZE bytes of data from FILE beginning at address ADDR
  *    into buffer BUF according to data transfer properties in
@@ -844,15 +846,15 @@ done:
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_direct_read(H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type, hid_t H5_ATTR_UNUSED dxpl_id, haddr_t addr,
-                 size_t size, void *buf /*out*/)
+H5FD__direct_read(H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type, hid_t H5_ATTR_UNUSED dxpl_id, haddr_t addr,
+                  size_t size, void *buf /*out*/)
 {
     H5FD_direct_t *file = (H5FD_direct_t *)_file;
     ssize_t        nbytes;
     hbool_t        _must_align = TRUE;
     herr_t         ret_value   = SUCCEED; /* Return value */
     size_t         alloc_size;
-    void *         copy_buf = NULL, *p2;
+    void          *copy_buf = NULL, *p2;
     size_t         _boundary;
     size_t         _fbsize;
     size_t         _cbsize;
@@ -860,7 +862,7 @@ H5FD_direct_read(H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type, hid_t H5_ATTR_UN
     size_t         copy_size = size; /* Size remaining to read when using copy buffer */
     size_t         copy_offset;      /* Offset into copy buffer of the requested data */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_STATIC
 
     HDassert(file && file->pub.cls);
     HDassert(buf);
@@ -1008,7 +1010,7 @@ done:
 }
 
 /*-------------------------------------------------------------------------
- * Function:  H5FD_direct_write
+ * Function:  H5FD__direct_write
  *
  * Purpose:  Writes SIZE bytes of data to FILE beginning at address ADDR
  *    from buffer BUF according to data transfer properties in
@@ -1024,16 +1026,16 @@ done:
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_direct_write(H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type, hid_t H5_ATTR_UNUSED dxpl_id, haddr_t addr,
-                  size_t size, const void *buf)
+H5FD__direct_write(H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type, hid_t H5_ATTR_UNUSED dxpl_id, haddr_t addr,
+                   size_t size, const void *buf)
 {
     H5FD_direct_t *file = (H5FD_direct_t *)_file;
     ssize_t        nbytes;
     hbool_t        _must_align = TRUE;
     herr_t         ret_value   = SUCCEED; /* Return value */
     size_t         alloc_size;
-    void *         copy_buf = NULL, *p1;
-    const void *   p3;
+    void          *copy_buf = NULL, *p1;
+    const void    *p3;
     size_t         _boundary;
     size_t         _fbsize;
     size_t         _cbsize;
@@ -1043,7 +1045,7 @@ H5FD_direct_write(H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type, hid_t H5_ATTR_U
     size_t         copy_size = size; /* Size remaining to write when using copy buffer */
     size_t         copy_offset;      /* Offset into copy buffer of the data to write */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_STATIC
 
     HDassert(file && file->pub.cls);
     HDassert(buf);
@@ -1237,7 +1239,7 @@ done:
 }
 
 /*-------------------------------------------------------------------------
- * Function:  H5FD_direct_truncate
+ * Function:  H5FD__direct_truncate
  *
  * Purpose:  Makes sure that the true file size is the same (or larger)
  *    than the end-of-address.
@@ -1252,12 +1254,12 @@ done:
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_direct_truncate(H5FD_t *_file, hid_t H5_ATTR_UNUSED dxpl_id, hbool_t H5_ATTR_UNUSED closing)
+H5FD__direct_truncate(H5FD_t *_file, hid_t H5_ATTR_UNUSED dxpl_id, hbool_t H5_ATTR_UNUSED closing)
 {
     H5FD_direct_t *file      = (H5FD_direct_t *)_file;
     herr_t         ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_STATIC
 
     HDassert(file);
 
@@ -1298,10 +1300,10 @@ H5FD_direct_truncate(H5FD_t *_file, hid_t H5_ATTR_UNUSED dxpl_id, hbool_t H5_ATT
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5FD_direct_truncate() */
+} /* end H5FD__direct_truncate() */
 
 /*-------------------------------------------------------------------------
- * Function:    H5FD_direct_lock
+ * Function:    H5FD__direct_lock
  *
  * Purpose:     To place an advisory lock on a file.
  *		The lock type to apply depends on the parameter "rw":
@@ -1315,13 +1317,13 @@ done:
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_direct_lock(H5FD_t *_file, hbool_t rw)
+H5FD__direct_lock(H5FD_t *_file, hbool_t rw)
 {
     H5FD_direct_t *file = (H5FD_direct_t *)_file; /* VFD file struct      */
     int            lock_flags;                    /* file locking flags   */
     herr_t         ret_value = SUCCEED;           /* Return value         */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_STATIC
 
     HDassert(file);
 
@@ -1342,10 +1344,10 @@ H5FD_direct_lock(H5FD_t *_file, hbool_t rw)
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5FD_direct_lock() */
+} /* end H5FD__direct_lock() */
 
 /*-------------------------------------------------------------------------
- * Function:    H5FD_direct_unlock
+ * Function:    H5FD__direct_unlock
  *
  * Purpose:     To remove the existing lock on the file
  *
@@ -1356,12 +1358,12 @@ done:
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_direct_unlock(H5FD_t *_file)
+H5FD__direct_unlock(H5FD_t *_file)
 {
     H5FD_direct_t *file      = (H5FD_direct_t *)_file; /* VFD file struct */
     herr_t         ret_value = SUCCEED;                /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_STATIC
 
     HDassert(file);
 
@@ -1378,6 +1380,6 @@ H5FD_direct_unlock(H5FD_t *_file)
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5FD_direct_unlock() */
+} /* end H5FD__direct_unlock() */
 
 #endif /* H5_HAVE_DIRECT */
