@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -113,32 +112,32 @@ H5HF__huge_bt2_create(H5HF_hdr_t *hdr)
     if (hdr->huge_ids_direct) {
         if (hdr->filter_len > 0) {
             bt2_cparam.rrec_size =
-                (size_t)((unsigned)hdr->sizeof_addr     /* Address of object */
-                         + (unsigned)hdr->sizeof_size   /* Length of object */
-                         + (unsigned)4                  /* Filter mask for filtered object */
-                         + (unsigned)hdr->sizeof_size); /* Size of de-filtered object in memory */
+                (uint32_t)((unsigned)hdr->sizeof_addr     /* Address of object */
+                           + (unsigned)hdr->sizeof_size   /* Length of object */
+                           + (unsigned)4                  /* Filter mask for filtered object */
+                           + (unsigned)hdr->sizeof_size); /* Size of de-filtered object in memory */
             bt2_cparam.cls = H5HF_HUGE_BT2_FILT_DIR;
         } /* end if */
         else {
-            bt2_cparam.rrec_size = (size_t)((unsigned)hdr->sizeof_addr     /* Address of object */
-                                            + (unsigned)hdr->sizeof_size); /* Length of object */
+            bt2_cparam.rrec_size = (uint32_t)((unsigned)hdr->sizeof_addr     /* Address of object */
+                                              + (unsigned)hdr->sizeof_size); /* Length of object */
             bt2_cparam.cls       = H5HF_HUGE_BT2_DIR;
         } /* end else */
     }     /* end if */
     else {
         if (hdr->filter_len > 0) {
             bt2_cparam.rrec_size =
-                (size_t)((unsigned)hdr->sizeof_addr     /* Address of filtered object */
-                         + (unsigned)hdr->sizeof_size   /* Length of filtered object */
-                         + (unsigned)4                  /* Filter mask for filtered object */
-                         + (unsigned)hdr->sizeof_size   /* Size of de-filtered object in memory */
-                         + (unsigned)hdr->sizeof_size); /* Unique ID for object */
+                (uint32_t)((unsigned)hdr->sizeof_addr     /* Address of filtered object */
+                           + (unsigned)hdr->sizeof_size   /* Length of filtered object */
+                           + (unsigned)4                  /* Filter mask for filtered object */
+                           + (unsigned)hdr->sizeof_size   /* Size of de-filtered object in memory */
+                           + (unsigned)hdr->sizeof_size); /* Unique ID for object */
             bt2_cparam.cls = H5HF_HUGE_BT2_FILT_INDIR;
         } /* end if */
         else {
-            bt2_cparam.rrec_size = (size_t)((unsigned)hdr->sizeof_addr     /* Address of object */
-                                            + (unsigned)hdr->sizeof_size   /* Length of object */
-                                            + (unsigned)hdr->sizeof_size); /* Unique ID for object */
+            bt2_cparam.rrec_size = (uint32_t)((unsigned)hdr->sizeof_addr     /* Address of object */
+                                              + (unsigned)hdr->sizeof_size   /* Length of object */
+                                              + (unsigned)hdr->sizeof_size); /* Unique ID for object */
             bt2_cparam.cls       = H5HF_HUGE_BT2_INDIR;
         } /* end else */
     }     /* end else */
@@ -160,7 +159,7 @@ done:
 } /* end H5HF__huge_bt2_create() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5HF_huge_init
+ * Function:	H5HF__huge_init
  *
  * Purpose:	Initialize information for tracking 'huge' objects
  *
@@ -172,9 +171,9 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_huge_init(H5HF_hdr_t *hdr)
+H5HF__huge_init(H5HF_hdr_t *hdr)
 {
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /*
      * Check arguments.
@@ -225,7 +224,7 @@ H5HF_huge_init(H5HF_hdr_t *hdr)
     hdr->huge_bt2 = NULL;
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5HF_huge_init() */
+} /* end H5HF__huge_init() */
 
 /*-------------------------------------------------------------------------
  * Function:	H5HF__huge_new_id
@@ -291,7 +290,7 @@ H5HF__huge_insert(H5HF_hdr_t *hdr, size_t obj_size, void *obj, void *_id)
 {
     uint8_t *id = (uint8_t *)_id;   /* Pointer to ID buffer */
     haddr_t  obj_addr;              /* Address of object in the file */
-    void *   write_buf;             /* Pointer to buffer to write */
+    void    *write_buf;             /* Pointer to buffer to write */
     size_t   write_size;            /* Size of [possibly filtered] object written to file */
     unsigned filter_mask = 0;       /* Filter mask for object (only used for filtered objects) */
     herr_t   ret_value   = SUCCEED; /* Return value */
@@ -411,7 +410,7 @@ H5HF__huge_insert(H5HF_hdr_t *hdr, size_t obj_size, void *obj, void *_id)
     else {
         H5HF_huge_bt2_filt_indir_rec_t filt_indir_rec; /* Record for tracking filtered object */
         H5HF_huge_bt2_indir_rec_t      indir_rec;      /* Record for tracking non-filtered object */
-        void *                         ins_rec;        /* Pointer to record to insert */
+        void                          *ins_rec;        /* Pointer to record to insert */
         hsize_t                        new_id;         /* New ID for object */
 
         /* Get new ID for object */
@@ -453,7 +452,7 @@ H5HF__huge_insert(H5HF_hdr_t *hdr, size_t obj_size, void *obj, void *_id)
     hdr->huge_nobjs++;
 
     /* Mark heap header as modified */
-    if (H5HF_hdr_dirty(hdr) < 0)
+    if (H5HF__hdr_dirty(hdr) < 0)
         HGOTO_ERROR(H5E_HEAP, H5E_CANTDIRTY, FAIL, "can't mark heap header as dirty")
 
 done:
@@ -650,7 +649,7 @@ done:
 static herr_t
 H5HF__huge_op_real(H5HF_hdr_t *hdr, const uint8_t *id, hbool_t is_read, H5HF_operator_t op, void *op_data)
 {
-    void *   read_buf = NULL;       /* Pointer to buffer for reading */
+    void    *read_buf = NULL;       /* Pointer to buffer for reading */
     haddr_t  obj_addr;              /* Object's address in the file */
     size_t   obj_size    = 0;       /* Object's size in the file */
     unsigned filter_mask = 0;       /* Filter mask for object (only used for filtered objects) */
@@ -1030,7 +1029,7 @@ H5HF__huge_remove(H5HF_hdr_t *hdr, const uint8_t *id)
     hdr->huge_nobjs--;
 
     /* Mark heap header as modified */
-    if (H5HF_hdr_dirty(hdr) < 0)
+    if (H5HF__hdr_dirty(hdr) < 0)
         HGOTO_ERROR(H5E_HEAP, H5E_CANTDIRTY, FAIL, "can't mark heap header as dirty")
 
 done:
@@ -1090,7 +1089,7 @@ H5HF__huge_term(H5HF_hdr_t *hdr)
         hdr->huge_ids_wrapped = FALSE;
 
         /* Mark heap header as modified */
-        if (H5HF_hdr_dirty(hdr) < 0)
+        if (H5HF__hdr_dirty(hdr) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTDIRTY, FAIL, "can't mark heap header as dirty")
     } /* end if */
 
