@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -30,29 +29,28 @@
  *
  *           When adding types here, add a section to the 'misc19' test in
  *           test/tmisc.c to verify that the H5I{inc|dec|get}_ref() routines
- *           work correctly with it.
- *
- *           NOTE: H5I_REFERENCE is not used by the library and was removed
- *           in HDF5 1.12.0. \endinternal
+ *           work correctly with it. \endinternal
  */
 //! <!-- [H5I_type_t_snip] -->
 typedef enum H5I_type_t {
-    H5I_UNINIT = (-2), /**< uninitialized type                        */
-    H5I_BADID  = (-1), /**< invalid Type                              */
-    H5I_FILE   = 1,    /**< type ID for File objects                  */
-    H5I_GROUP,         /**< type ID for Group objects                 */
-    H5I_DATATYPE,      /**< type ID for Datatype objects              */
-    H5I_DATASPACE,     /**< type ID for Dataspace objects             */
-    H5I_DATASET,       /**< type ID for Dataset objects               */
-    H5I_ATTR,          /**< type ID for Attribute objects             */
-    H5I_REFERENCE,     /**< DEPRECATED* type ID for Reference objects */
-    H5I_VFL,           /**< type ID for virtual file layer            */
-    H5I_GENPROP_CLS,   /**< type ID for generic property list classes */
-    H5I_GENPROP_LST,   /**< type ID for generic property lists        */
-    H5I_ERROR_CLASS,   /**< type ID for error classes                 */
-    H5I_ERROR_MSG,     /**< type ID for error messages                */
-    H5I_ERROR_STACK,   /**< type ID for error stacks                  */
-    H5I_NTYPES         /**< number of library types, MUST BE LAST!    */
+    H5I_UNINIT = (-2),  /**< uninitialized type                        */
+    H5I_BADID  = (-1),  /**< invalid Type                              */
+    H5I_FILE   = 1,     /**< type ID for File objects                  */
+    H5I_GROUP,          /**< type ID for Group objects                 */
+    H5I_DATATYPE,       /**< type ID for Datatype objects              */
+    H5I_DATASPACE,      /**< type ID for Dataspace objects             */
+    H5I_DATASET,        /**< type ID for Dataset objects               */
+    H5I_MAP,            /**< type ID for Map objects                   */
+    H5I_ATTR,           /**< type ID for Attribute objects             */
+    H5I_VFL,            /**< type ID for virtual file layer            */
+    H5I_VOL,            /**< type ID for virtual object layer          */
+    H5I_GENPROP_CLS,    /**< type ID for generic property list classes */
+    H5I_GENPROP_LST,    /**< type ID for generic property lists        */
+    H5I_ERROR_CLASS,    /**< type ID for error classes                 */
+    H5I_ERROR_MSG,      /**< type ID for error messages                */
+    H5I_ERROR_STACK,    /**< type ID for error stacks                  */
+    H5I_SPACE_SEL_ITER, /**< type ID for dataspace selection iterator  */
+    H5I_NTYPES          /**< number of library types, MUST BE LAST!    */
 } H5I_type_t;
 //! <!-- [H5I_type_t_snip] -->
 
@@ -61,6 +59,11 @@ typedef enum H5I_type_t {
  */
 typedef int64_t hid_t;
 
+#define PRIdHID PRId64
+#define PRIxHID PRIx64
+#define PRIXHID PRIX64
+#define PRIoHID PRIo64
+
 /**
  * The size of identifiers
  */
@@ -87,6 +90,13 @@ typedef herr_t (*H5I_free_t)(void *);
 typedef int (*H5I_search_func_t)(void *obj, hid_t id, void *key);
 //! <!-- [H5I_search_func_t_snip] -->
 
+/**
+ * The type of H5Iiterate() callback functions
+ */
+//! <!-- [H5I_iterate_func_t_snip] -->
+typedef herr_t (*H5I_iterate_func_t)(hid_t id, void *udata);
+//! <!-- [H5I_iterate_func_t_snip] -->
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -496,7 +506,7 @@ H5_DLL int H5Idec_type_ref(H5I_type_t type);
  *
  * \brief Retrieves the reference count on an ID type
  *
- * \param[in] type The identifier of the type whose reference count is to be retieved
+ * \param[in] type The identifier of the type whose reference count is to be retrieved
  *
  * \return Returns the current reference count on success, negative on failure.
  *
@@ -551,6 +561,35 @@ H5_DLL int H5Iget_type_ref(H5I_type_t type);
  *
  */
 H5_DLL void *H5Isearch(H5I_type_t type, H5I_search_func_t func, void *key);
+/**
+ * \ingroup H5IUD
+ *
+ * \brief Calls a callback for each member of the identifier type specified
+ *
+ * \param[in] type The identifier type
+ * \param[in] op The callback function
+ * \param[in,out] op_data The data for the callback function
+ *
+ * \return The last value returned by \p op
+ *
+ * \details H5Iiterate() calls the callback function \p op for each member of
+ *          the identifier type \p type. The callback function type for \p op,
+ *          H5I_iterate_func_t, is defined in H5Ipublic.h as:
+ *          \snippet this H5I_iterate_func_t_snip
+ *          \p op takes as parameters the identifier and a pass through of
+ *          \p op_data, and returns an herr_t.
+ *
+ *          A positive return from op will cause the iteration to stop and
+ *          H5Iiterate() will return the value returned by \p op. A negative
+ *          return from \p op will cause the iteration to stop and H5Iiterate()
+ *          will return failure. A zero return from \p op will allow iteration
+ *          to continue, as long as there are other identifiers remaining in
+ *          type.
+ *
+ * \since 1.12.0
+ *
+ */
+H5_DLL herr_t H5Iiterate(H5I_type_t type, H5I_iterate_func_t op, void *op_data);
 /**
  * \ingroup H5IUD
  *
