@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -27,10 +26,11 @@
  */
 
 #include "H5Omodule.h" /* This source code file is part of the H5O module */
+#define H5F_FRIEND     /*suppress error about including H5Fpkg   */
 
 #include "H5private.h"   /* Generic Functions                     */
 #include "H5Eprivate.h"  /* Error handling                        */
-#include "H5Fprivate.h"  /* Files				*/
+#include "H5Fpkg.h"      /* Files                                 */
 #include "H5FLprivate.h" /* Free Lists                            */
 #include "H5Opkg.h"      /* Object headers                        */
 #include "H5MFprivate.h" /* File space management                 */
@@ -39,7 +39,7 @@
 static void *H5O__mdci_decode(H5F_t *f, H5O_t *open_oh, unsigned mesg_flags, unsigned *ioflags, size_t p_size,
                               const uint8_t *p);
 static herr_t H5O__mdci_encode(H5F_t *f, hbool_t disable_shared, uint8_t *p, const void *_mesg);
-static void * H5O__mdci_copy(const void *_mesg, void *_dest);
+static void  *H5O__mdci_copy(const void *_mesg, void *_dest);
 static size_t H5O__mdci_size(const H5F_t *f, hbool_t disable_shared, const void *_mesg);
 static herr_t H5O__mdci_free(void *mesg);
 static herr_t H5O__mdci_delete(H5F_t *f, H5O_t *open_oh, void *_mesg);
@@ -50,7 +50,7 @@ const H5O_msg_class_t H5O_MSG_MDCI[1] = {{
     H5O_MDCI_MSG_ID,    /* message id number              */
     "mdci",             /* message name for debugging     */
     sizeof(H5O_mdci_t), /* native message size            */
-    0,                  /* messages are sharable?         */
+    0,                  /* messages are shareable?         */
     H5O__mdci_decode,   /* decode message                 */
     H5O__mdci_encode,   /* encode message                 */
     H5O__mdci_copy,     /* copy method                    */
@@ -94,7 +94,7 @@ H5O__mdci_decode(H5F_t *f, H5O_t H5_ATTR_UNUSED *open_oh, unsigned H5_ATTR_UNUSE
                  unsigned H5_ATTR_UNUSED *ioflags, size_t H5_ATTR_UNUSED p_size, const uint8_t *p)
 {
     H5O_mdci_t *mesg;             /* Native message        */
-    void *      ret_value = NULL; /* Return value          */
+    void       *ret_value = NULL; /* Return value          */
 
     FUNC_ENTER_STATIC
 
@@ -172,8 +172,8 @@ static void *
 H5O__mdci_copy(const void *_mesg, void *_dest)
 {
     const H5O_mdci_t *mesg      = (const H5O_mdci_t *)_mesg;
-    H5O_mdci_t *      dest      = (H5O_mdci_t *)_dest;
-    void *            ret_value = NULL; /* Return value */
+    H5O_mdci_t       *dest      = (H5O_mdci_t *)_dest;
+    void             *ret_value = NULL; /* Return value */
 
     FUNC_ENTER_STATIC
 
@@ -262,16 +262,16 @@ H5O__mdci_free(void *mesg)
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5O__mdci_delete(H5F_t *f, H5O_t *open_oh, void *_mesg)
+H5O__mdci_delete(H5F_t *f, H5O_t H5_ATTR_UNUSED *open_oh, void *_mesg)
 {
-    H5O_mdci_t *mesg      = (H5O_mdci_t *)_mesg;
+    H5O_mdci_t *mesg = (H5O_mdci_t *)_mesg;
+    haddr_t     final_eoa;           /* For sanity check */
     herr_t      ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_STATIC
 
     /* check args */
     HDassert(f);
-    HDassert(open_oh);
     HDassert(mesg);
 
     /* Free file space for cache image */
@@ -280,45 +280,20 @@ H5O__mdci_delete(H5F_t *f, H5O_t *open_oh, void *_mesg)
          * from the VFD layer at the end of file.  As this was the
          * last file space allocation before shutdown, the cache image
          * should still be the last item in the file.
-         *
-         * If the hack to work around the self referential free space
-         * manager issue is in use, file space for the non-empty self
-         * referential free space managers was also allocated from VFD
-         * layer at the end of file.  Since these allocations directly
-         * preceeded the cache image allocation they should be directly
-         * adjacent to the cache image block at the end of file.
-         *
-         * In this case, just call H5MF_tidy_self_referential_fsm_hack().
-         *
-         * That routine will float the self referential free space
-         * managers, and reduce the eoa to its value just prior to
-         * allocation of space for same.  Since the cache image appears
-         * just after the self referential free space managers, this
-         * will release the file space for the cache image as well.
-         *
-         * Note that in this case, there must not have been any file
-         * space allocations / deallocations prior to the free of the
-         * cache image.  Verify this to the extent possible.
-         *
-         * If the hack to work around the persistent self referential
-         * free space manager issue is NOT in use, just call H5MF_xfree()
-         * to release the cache iamge.  In principle, we should be able
-         * to just reduce the EOA to the base address of the cache
-         * image block, as there shouldn't be any file space allocation
-         * before the first metadata cache access.  However, given
-         * time constraints, I don't want to go there now.
          */
-        if (H5F_FIRST_ALLOC_DEALLOC(f)) {
-            HDassert(HADDR_UNDEF != H5F_EOA_PRE_FSM_FSALLOC(f));
-            HDassert(H5F_addr_ge(mesg->addr, H5F_EOA_PRE_FSM_FSALLOC(f)));
-            if (H5MF_tidy_self_referential_fsm_hack(f) < 0)
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTFREE, FAIL, "tidy of self referential fsm hack failed")
-        } /* end if */
-        else {
-            if (H5MF_xfree(f, H5FD_MEM_SUPER, mesg->addr, mesg->size) < 0)
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTFREE, FAIL, "unable to free file space for cache image block")
-        } /* end else */
-    }     /* end if */
+        if (f->shared->closing) {
+            /* Get the eoa, and verify that it has the expected value */
+            if (HADDR_UNDEF == (final_eoa = H5FD_get_eoa(f->shared->lf, H5FD_MEM_DEFAULT)))
+                HGOTO_ERROR(H5E_CACHE, H5E_CANTGET, FAIL, "unable to get file size")
+
+            HDassert(H5F_addr_eq(final_eoa, mesg->addr + mesg->size));
+
+            if (H5FD_free(f->shared->lf, H5FD_MEM_SUPER, f, mesg->addr, mesg->size) < 0)
+                HGOTO_ERROR(H5E_CACHE, H5E_CANTFREE, FAIL, "can't free MDC image")
+        }
+        else if (H5MF_xfree(f, H5FD_MEM_SUPER, mesg->addr, mesg->size) < 0)
+            HGOTO_ERROR(H5E_OHDR, H5E_CANTFREE, FAIL, "unable to free file space for cache image block")
+    } /* end if */
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
