@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -38,14 +37,14 @@
 /* PRIVATE PROTOTYPES */
 static void *H5O__link_decode(H5F_t *f, H5O_t *open_oh, unsigned mesg_flags, unsigned *ioflags, size_t p_size,
                               const uint8_t *p);
-static herr_t H5O_link_encode(H5F_t *f, hbool_t disable_shared, uint8_t *p, const void *_mesg);
-static void * H5O_link_copy(const void *_mesg, void *_dest);
-static size_t H5O_link_size(const H5F_t *f, hbool_t disable_shared, const void *_mesg);
+static herr_t H5O__link_encode(H5F_t *f, hbool_t disable_shared, uint8_t *p, const void *_mesg);
+static void  *H5O__link_copy(const void *_mesg, void *_dest);
+static size_t H5O__link_size(const H5F_t *f, hbool_t disable_shared, const void *_mesg);
 static herr_t H5O__link_reset(void *_mesg);
 static herr_t H5O__link_free(void *_mesg);
-static herr_t H5O_link_pre_copy_file(H5F_t *file_src, const void *mesg_src, hbool_t *deleted,
-                                     const H5O_copy_t *cpy_info, void *udata);
-static void * H5O__link_copy_file(H5F_t *file_src, void *native_src, H5F_t *file_dst, hbool_t *recompute_size,
+static herr_t H5O__link_pre_copy_file(H5F_t *file_src, const void *mesg_src, hbool_t *deleted,
+                                      const H5O_copy_t *cpy_info, void *udata);
+static void  *H5O__link_copy_file(H5F_t *file_src, void *native_src, H5F_t *file_dst, hbool_t *recompute_size,
                                   unsigned *mesg_flags, H5O_copy_t *cpy_info, void *udata);
 static herr_t H5O__link_post_copy_file(const H5O_loc_t *src_oloc, const void *mesg_src, H5O_loc_t *dst_oloc,
                                        void *mesg_dst, unsigned *mesg_flags, H5O_copy_t *cpy_info);
@@ -56,18 +55,18 @@ const H5O_msg_class_t H5O_MSG_LINK[1] = {{
     H5O_LINK_ID,              /*message id number             */
     "link",                   /*message name for debugging    */
     sizeof(H5O_link_t),       /*native message size           */
-    0,                        /* messages are sharable?       */
+    0,                        /* messages are shareable?       */
     H5O__link_decode,         /*decode message                */
-    H5O_link_encode,          /*encode message                */
-    H5O_link_copy,            /*copy the native value         */
-    H5O_link_size,            /*size of symbol table entry    */
+    H5O__link_encode,         /*encode message                */
+    H5O__link_copy,           /*copy the native value         */
+    H5O__link_size,           /*size of symbol table entry    */
     H5O__link_reset,          /* reset method			*/
     H5O__link_free,           /* free method			*/
     H5O_link_delete,          /* file delete method		*/
     NULL,                     /* link method			*/
     NULL,                     /*set share method		*/
     NULL,                     /*can share method		*/
-    H5O_link_pre_copy_file,   /* pre copy native value to file */
+    H5O__link_pre_copy_file,  /* pre copy native value to file */
     H5O__link_copy_file,      /* copy native value to file    */
     H5O__link_post_copy_file, /* post copy native value to file    */
     NULL,                     /* get creation index		*/
@@ -114,11 +113,11 @@ static void *
 H5O__link_decode(H5F_t *f, H5O_t H5_ATTR_UNUSED *open_oh, unsigned H5_ATTR_UNUSED mesg_flags,
                  unsigned H5_ATTR_UNUSED *ioflags, size_t p_size, const uint8_t *p)
 {
-    H5O_link_t *   lnk = NULL;             /* Pointer to link message */
+    H5O_link_t    *lnk = NULL;             /* Pointer to link message */
     size_t         len = 0;                /* Length of a string in the message */
     unsigned char  link_flags;             /* Flags for encoding link info */
     const uint8_t *p_end     = p + p_size; /* End of the p buffer */
-    void *         ret_value = NULL;       /* Return value */
+    void          *ret_value = NULL;       /* Return value */
 
     FUNC_ENTER_STATIC
 
@@ -275,7 +274,7 @@ done:
 } /* end H5O__link_decode() */
 
 /*-------------------------------------------------------------------------
- * Function:    H5O_link_encode
+ * Function:    H5O__link_encode
  *
  * Purpose:     Encodes a link message.
  *
@@ -287,13 +286,13 @@ done:
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5O_link_encode(H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, uint8_t *p, const void *_mesg)
+H5O__link_encode(H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, uint8_t *p, const void *_mesg)
 {
     const H5O_link_t *lnk = (const H5O_link_t *)_mesg;
     uint64_t          len;        /* Length of a string in the message */
     unsigned char     link_flags; /* Flags for encoding link info */
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_STATIC_NOERR
 
     /* check args */
     HDassert(f);
@@ -393,10 +392,10 @@ H5O_link_encode(H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, uint8_t *p, con
     } /* end switch */
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5O_link_encode() */
+} /* end H5O__link_encode() */
 
 /*-------------------------------------------------------------------------
- * Function:    H5O_link_copy
+ * Function:    H5O__link_copy
  *
  * Purpose:     Copies a message from _MESG to _DEST, allocating _DEST if
  *              necessary.
@@ -411,13 +410,13 @@ H5O_link_encode(H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, uint8_t *p, con
  *-------------------------------------------------------------------------
  */
 static void *
-H5O_link_copy(const void *_mesg, void *_dest)
+H5O__link_copy(const void *_mesg, void *_dest)
 {
     const H5O_link_t *lnk       = (const H5O_link_t *)_mesg;
-    H5O_link_t *      dest      = (H5O_link_t *)_dest;
-    void *            ret_value = NULL; /* Return value */
+    H5O_link_t       *dest      = (H5O_link_t *)_dest;
+    void             *ret_value = NULL; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_STATIC
 
     /* Check args */
     HDassert(lnk);
@@ -458,10 +457,10 @@ done:
         } /* end if */
 
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5O_link_copy() */
+} /* end H5O__link_copy() */
 
 /*-------------------------------------------------------------------------
- * Function:    H5O_link_size
+ * Function:    H5O__link_size
  *
  * Purpose:     Returns the size of the raw message in bytes not counting
  *              the message type or size fields, but only the data fields.
@@ -477,14 +476,14 @@ done:
  *-------------------------------------------------------------------------
  */
 static size_t
-H5O_link_size(const H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, const void *_mesg)
+H5O__link_size(const H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, const void *_mesg)
 {
     const H5O_link_t *lnk = (const H5O_link_t *)_mesg;
     uint64_t          name_len;      /* Length of name */
     size_t            name_size;     /* Size of encoded name length */
     size_t            ret_value = 0; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_STATIC_NOERR
 
     /* Sanity check */
     HDcompile_assert(sizeof(uint64_t) >= sizeof(size_t));
@@ -533,7 +532,7 @@ H5O_link_size(const H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, const void
     } /* end switch */
 
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5O_link_size() */
+} /* end H5O__link_size() */
 
 /*-------------------------------------------------------------------------
  * Function:	H5O__link_reset
@@ -611,6 +610,7 @@ herr_t
 H5O_link_delete(H5F_t *f, H5O_t H5_ATTR_UNUSED *open_oh, void *_mesg)
 {
     H5O_link_t *lnk       = (H5O_link_t *)_mesg;
+    hid_t       file_id   = -1;      /* ID for the file the link is located in (passed to user callback) */
     herr_t      ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
@@ -644,30 +644,26 @@ H5O_link_delete(H5F_t *f, H5O_t H5_ATTR_UNUSED *open_oh, void *_mesg)
 
         /* Check for delete callback */
         if (link_class->del_func) {
-            hid_t file_id; /* ID for the file the link is located in (passed to user callback) */
-
             /* Get a file ID for the file the link is in */
-            if ((file_id = H5F_get_id(f, FALSE)) < 0)
+            if ((file_id = H5F_get_id(f)) < 0)
                 HGOTO_ERROR(H5E_OHDR, H5E_CANTGET, FAIL, "unable to get file ID")
 
             /* Call user-defined link's 'delete' callback */
-            if ((link_class->del_func)(lnk->name, file_id, lnk->u.ud.udata, lnk->u.ud.size) < 0) {
-                H5I_dec_ref(file_id);
+            if ((link_class->del_func)(lnk->name, file_id, lnk->u.ud.udata, lnk->u.ud.size) < 0)
                 HGOTO_ERROR(H5E_OHDR, H5E_CALLBACK, FAIL, "link deletion callback returned failure")
-            } /* end if */
-
-            /* Release the file ID */
-            if (H5I_dec_ref(file_id) < 0)
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTCLOSEFILE, FAIL, "can't close file")
         } /* end if */
     }     /* end if */
 
 done:
+    /* Release the file ID */
+    if (file_id > 0 && H5I_dec_ref(file_id) < 0)
+        HDONE_ERROR(H5E_OHDR, H5E_CANTCLOSEFILE, FAIL, "can't close file")
+
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O_link_delete() */
 
 /*-------------------------------------------------------------------------
- * Function:    H5O_link_pre_copy_file
+ * Function:    H5O__link_pre_copy_file
  *
  * Purpose:     Perform any necessary actions before copying message between
  *              files for link messages.
@@ -682,10 +678,10 @@ done:
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5O_link_pre_copy_file(H5F_t H5_ATTR_UNUSED *file_src, const void H5_ATTR_UNUSED *native_src,
-                       hbool_t *deleted, const H5O_copy_t *cpy_info, void H5_ATTR_UNUSED *udata)
+H5O__link_pre_copy_file(H5F_t H5_ATTR_UNUSED *file_src, const void H5_ATTR_UNUSED *native_src,
+                        hbool_t *deleted, const H5O_copy_t *cpy_info, void H5_ATTR_UNUSED *udata)
 {
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_STATIC_NOERR
 
     /* check args */
     HDassert(deleted);
@@ -700,7 +696,7 @@ H5O_link_pre_copy_file(H5F_t H5_ATTR_UNUSED *file_src, const void H5_ATTR_UNUSED
         *deleted = TRUE;
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5O_link_pre_copy_file() */
+} /* end H5O__link_pre_copy_file() */
 
 /*-------------------------------------------------------------------------
  * Function:    H5O__link_copy_file
@@ -722,7 +718,7 @@ H5O__link_copy_file(H5F_t H5_ATTR_UNUSED *file_src, void *native_src, H5F_t H5_A
                     H5O_copy_t H5_ATTR_UNUSED *cpy_info, void H5_ATTR_UNUSED *udata)
 {
     H5O_link_t *link_src  = (H5O_link_t *)native_src;
-    void *      ret_value = NULL; /* Return value */
+    void       *ret_value = NULL; /* Return value */
 
     FUNC_ENTER_STATIC
 
@@ -761,7 +757,7 @@ H5O__link_post_copy_file(const H5O_loc_t *src_oloc, const void *mesg_src, H5O_lo
                          unsigned H5_ATTR_UNUSED *mesg_flags, H5O_copy_t *cpy_info)
 {
     const H5O_link_t *link_src  = (const H5O_link_t *)mesg_src;
-    H5O_link_t *      link_dst  = (H5O_link_t *)mesg_dst;
+    H5O_link_t       *link_dst  = (H5O_link_t *)mesg_dst;
     herr_t            ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_STATIC
