@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -24,35 +23,35 @@
 #include "H5Spkg.h"      /* Dataspaces 				*/
 
 /* PRIVATE PROTOTYPES */
-static void * H5O__sdspace_decode(H5F_t *f, H5O_t *open_oh, unsigned mesg_flags, unsigned *ioflags,
+static void  *H5O__sdspace_decode(H5F_t *f, H5O_t *open_oh, unsigned mesg_flags, unsigned *ioflags,
                                   size_t p_size, const uint8_t *p);
-static herr_t H5O_sdspace_encode(H5F_t *f, uint8_t *p, const void *_mesg);
-static void * H5O_sdspace_copy(const void *_mesg, void *_dest);
-static size_t H5O_sdspace_size(const H5F_t *f, const void *_mesg);
+static herr_t H5O__sdspace_encode(H5F_t *f, uint8_t *p, const void *_mesg);
+static void  *H5O__sdspace_copy(const void *_mesg, void *_dest);
+static size_t H5O__sdspace_size(const H5F_t *f, const void *_mesg);
 static herr_t H5O__sdspace_reset(void *_mesg);
 static herr_t H5O__sdspace_free(void *_mesg);
-static herr_t H5O_sdspace_pre_copy_file(H5F_t *file_src, const void *mesg_src, hbool_t *deleted,
-                                        const H5O_copy_t *cpy_info, void *_udata);
+static herr_t H5O__sdspace_pre_copy_file(H5F_t *file_src, const void *mesg_src, hbool_t *deleted,
+                                         const H5O_copy_t *cpy_info, void *_udata);
 static herr_t H5O__sdspace_debug(H5F_t *f, const void *_mesg, FILE *stream, int indent, int fwidth);
 
 /* Set up & include shared message "interface" info */
 #define H5O_SHARED_TYPE        H5O_MSG_SDSPACE
-#define H5O_SHARED_DECODE      H5O_sdspace_shared_decode
+#define H5O_SHARED_DECODE      H5O__sdspace_shared_decode
 #define H5O_SHARED_DECODE_REAL H5O__sdspace_decode
-#define H5O_SHARED_ENCODE      H5O_sdspace_shared_encode
-#define H5O_SHARED_ENCODE_REAL H5O_sdspace_encode
-#define H5O_SHARED_SIZE        H5O_sdspace_shared_size
-#define H5O_SHARED_SIZE_REAL   H5O_sdspace_size
+#define H5O_SHARED_ENCODE      H5O__sdspace_shared_encode
+#define H5O_SHARED_ENCODE_REAL H5O__sdspace_encode
+#define H5O_SHARED_SIZE        H5O__sdspace_shared_size
+#define H5O_SHARED_SIZE_REAL   H5O__sdspace_size
 #define H5O_SHARED_DELETE      H5O__sdspace_shared_delete
 #undef H5O_SHARED_DELETE_REAL
 #define H5O_SHARED_LINK H5O__sdspace_shared_link
 #undef H5O_SHARED_LINK_REAL
 #define H5O_SHARED_COPY_FILE H5O__sdspace_shared_copy_file
 #undef H5O_SHARED_COPY_FILE_REAL
-#define H5O_SHARED_POST_COPY_FILE H5O_sdspace_shared_post_copy_file
+#define H5O_SHARED_POST_COPY_FILE H5O__sdspace_shared_post_copy_file
 #undef H5O_SHARED_POST_COPY_FILE_REAL
 #undef H5O_SHARED_POST_COPY_FILE_UPD
-#define H5O_SHARED_DEBUG      H5O_sdspace_shared_debug
+#define H5O_SHARED_DEBUG      H5O__sdspace_shared_debug
 #define H5O_SHARED_DEBUG_REAL H5O__sdspace_debug
 #include "H5Oshared.h" /* Shared Object Header Message Callbacks */
 
@@ -61,23 +60,23 @@ const H5O_msg_class_t H5O_MSG_SDSPACE[1] = {{
     H5O_SDSPACE_ID,                            /* message id number		    	*/
     "dataspace",                               /* message name for debugging	   	*/
     sizeof(H5S_extent_t),                      /* native message size		    	*/
-    H5O_SHARE_IS_SHARABLE | H5O_SHARE_IN_OHDR, /* messages are sharable?       */
-    H5O_sdspace_shared_decode,                 /* decode message			*/
-    H5O_sdspace_shared_encode,                 /* encode message			*/
-    H5O_sdspace_copy,                          /* copy the native value		*/
-    H5O_sdspace_shared_size,                   /* size of symbol table entry	    	*/
+    H5O_SHARE_IS_SHARABLE | H5O_SHARE_IN_OHDR, /* messages are shareable? */
+    H5O__sdspace_shared_decode,                /* decode message			*/
+    H5O__sdspace_shared_encode,                /* encode message			*/
+    H5O__sdspace_copy,                         /* copy the native value		*/
+    H5O__sdspace_shared_size,                  /* size of symbol table entry	    	*/
     H5O__sdspace_reset,                        /* default reset method		    	*/
     H5O__sdspace_free,                         /* free method				*/
-    H5O__sdspace_shared_delete,                /* file delete method		*/
-    H5O__sdspace_shared_link,                  /* link method			*/
-    NULL,                                      /* set share method		*/
-    NULL,                                      /*can share method		*/
-    H5O_sdspace_pre_copy_file,                 /* pre copy native value to file */
-    H5O__sdspace_shared_copy_file,             /* copy native value to file    */
-    H5O_sdspace_shared_post_copy_file,         /* post copy native value to file    */
-    NULL,                                      /* get creation index		*/
-    NULL,                                      /* set creation index		*/
-    H5O_sdspace_shared_debug                   /* debug the message		    	*/
+    H5O__sdspace_shared_delete,                /* file delete method		        */
+    H5O__sdspace_shared_link,                  /* link method			        */
+    NULL,                                      /* set share method		        */
+    NULL,                                      /*can share method		        */
+    H5O__sdspace_pre_copy_file,                /* pre copy native value to file        */
+    H5O__sdspace_shared_copy_file,             /* copy native value to file          */
+    H5O__sdspace_shared_post_copy_file,        /* post copy native value to file*/
+    NULL,                                      /* get creation index		        */
+    NULL,                                      /* set creation index		        */
+    H5O__sdspace_shared_debug                  /* debug the message		    	*/
 }};
 
 /* Declare external the free list for H5S_extent_t's */
@@ -108,11 +107,11 @@ static void *
 H5O__sdspace_decode(H5F_t *f, H5O_t H5_ATTR_UNUSED *open_oh, unsigned H5_ATTR_UNUSED mesg_flags,
                     unsigned H5_ATTR_UNUSED *ioflags, size_t p_size, const uint8_t *p)
 {
-    H5S_extent_t * sdim = NULL; /* New extent dimensionality structure */
+    const uint8_t *p_end = p + p_size - 1; /* End of the p buffer */
+    H5S_extent_t  *sdim  = NULL;           /* New extent dimensionality structure */
     unsigned       flags, version;
-    unsigned       i;                          /* Local counting variable */
-    const uint8_t *p_end     = p + p_size - 1; /* End of the p buffer */
-    void *         ret_value = NULL;           /* Return value */
+    unsigned       i;
+    void          *ret_value = NULL; /* Return value */
 
     FUNC_ENTER_STATIC
 
@@ -122,25 +121,37 @@ H5O__sdspace_decode(H5F_t *f, H5O_t H5_ATTR_UNUSED *open_oh, unsigned H5_ATTR_UN
 
     /* decode */
     if (NULL == (sdim = H5FL_CALLOC(H5S_extent_t)))
-        HGOTO_ERROR(H5E_DATASPACE, H5E_NOSPACE, NULL, "dataspace structure allocation failed")
+        HGOTO_ERROR(H5E_DATASPACE, H5E_CANTALLOC, NULL, "dataspace structure allocation failed")
+    sdim->type = H5S_NO_CLASS;
 
     /* Check version */
+    if (H5_IS_BUFFER_OVERFLOW(p, 1, p_end))
+        HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding")
     version = *p++;
+
     if (version < H5O_SDSPACE_VERSION_1 || version > H5O_SDSPACE_VERSION_2)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, NULL, "wrong version number in dataspace message")
+        HGOTO_ERROR(H5E_OHDR, H5E_BADVALUE, NULL, "wrong version number in dataspace message")
     sdim->version = version;
 
     /* Get rank */
+    if (H5_IS_BUFFER_OVERFLOW(p, 1, p_end))
+        HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding")
     sdim->rank = *p++;
+
     if (sdim->rank > H5S_MAX_RANK)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, NULL, "simple dataspace dimensionality is too large")
+        HGOTO_ERROR(H5E_OHDR, H5E_BADVALUE, NULL, "simple dataspace dimensionality is too large")
 
     /* Get dataspace flags for later */
+    if (H5_IS_BUFFER_OVERFLOW(p, 1, p_end))
+        HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding")
     flags = *p++;
 
     /* Get or determine the type of the extent */
     if (version >= H5O_SDSPACE_VERSION_2) {
+        if (H5_IS_BUFFER_OVERFLOW(p, 1, p_end))
+            HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding")
         sdim->type = (H5S_class_t)*p++;
+
         if (sdim->type != H5S_SIMPLE && sdim->rank > 0)
             HGOTO_ERROR(H5E_OHDR, H5E_BADVALUE, NULL, "invalid rank for scalar or NULL dataspace")
     } /* end if */
@@ -152,36 +163,48 @@ H5O__sdspace_decode(H5F_t *f, H5O_t H5_ATTR_UNUSED *open_oh, unsigned H5_ATTR_UN
             sdim->type = H5S_SCALAR;
 
         /* Increment past reserved byte */
+        if (H5_IS_BUFFER_OVERFLOW(p, 1, p_end))
+            HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding")
         p++;
     } /* end else */
     HDassert(sdim->type != H5S_NULL || sdim->version >= H5O_SDSPACE_VERSION_2);
 
     /* Only Version 1 has these reserved bytes */
-    if (version == H5O_SDSPACE_VERSION_1)
+    if (version == H5O_SDSPACE_VERSION_1) {
+        if (H5_IS_BUFFER_OVERFLOW(p, 4, p_end))
+            HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding")
         p += 4; /*reserved*/
+    }
 
     /* Decode dimension sizes */
     if (sdim->rank > 0) {
-        /* Ensure that rank doesn't cause reading passed buffer's end,
-           due to possible data corruption */
         uint8_t sizeof_size = H5F_SIZEOF_SIZE(f);
-        if (p + (sizeof_size * sdim->rank - 1) > p_end) {
-            HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "rank might cause reading passed buffer's end")
-        }
+
+        /*
+         * Ensure that decoding doesn't cause reading past buffer's end,
+         * due to possible data corruption - check that we have space to
+         * decode a "sdim->rank" number of hsize_t values
+         */
+        if (H5_IS_BUFFER_OVERFLOW(p, (sizeof_size * sdim->rank), p_end))
+            HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding")
 
         if (NULL == (sdim->size = (hsize_t *)H5FL_ARR_MALLOC(hsize_t, (size_t)sdim->rank)))
-            HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
+            HGOTO_ERROR(H5E_RESOURCE, H5E_CANTALLOC, NULL, "memory allocation failed")
 
         for (i = 0; i < sdim->rank; i++)
             H5F_DECODE_LENGTH(f, p, sdim->size[i]);
 
         if (flags & H5S_VALID_MAX) {
             if (NULL == (sdim->max = (hsize_t *)H5FL_ARR_MALLOC(hsize_t, (size_t)sdim->rank)))
-                HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
+                HGOTO_ERROR(H5E_RESOURCE, H5E_CANTALLOC, NULL, "memory allocation failed")
 
-            /* Ensure that rank doesn't cause reading passed buffer's end */
-            if (p + (sizeof_size * sdim->rank - 1) > p_end)
-                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "rank might cause reading passed buffer's end")
+            /*
+             * Ensure that decoding doesn't cause reading past buffer's end,
+             * due to possible data corruption - check that we have space to
+             * decode a "sdim->rank" number of hsize_t values
+             */
+            if (H5_IS_BUFFER_OVERFLOW(p, (sizeof_size * sdim->rank), p_end))
+                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding")
 
             for (i = 0; i < sdim->rank; i++)
                 H5F_DECODE_LENGTH(f, p, sdim->max[i]);
@@ -210,11 +233,11 @@ done:
 
 /*--------------------------------------------------------------------------
  NAME
-    H5O_sdspace_encode
+    H5O__sdspace_encode
  PURPOSE
     Encode a simple dimensionality message
  USAGE
-    herr_t H5O_sdspace_encode(f, raw_size, p, mesg)
+    herr_t H5O__sdspace_encode(f, raw_size, p, mesg)
         H5F_t *f;	        IN: pointer to the HDF5 file struct
         size_t raw_size;	IN: size of the raw information buffer
         const uint8 *p;		IN: the raw information buffer
@@ -225,28 +248,15 @@ done:
         This function encodes the native memory form of the simple
     dimensionality message in the "raw" disk form.
 
- MODIFICATIONS
-        Robb Matzke, 1998-04-09
-        The current and maximum dimensions are now H5F_SIZEOF_SIZET bytes
-        instead of just four bytes.
-
-        Robb Matzke, 1998-07-20
-        Added a version number and reformatted the message for aligment.
-
-        Raymond Lu
-        April 8, 2004
-        Added the type of dataspace into this header message using a reserved
-        byte.
-
 --------------------------------------------------------------------------*/
 static herr_t
-H5O_sdspace_encode(H5F_t *f, uint8_t *p, const void *_mesg)
+H5O__sdspace_encode(H5F_t *f, uint8_t *p, const void *_mesg)
 {
     const H5S_extent_t *sdim  = (const H5S_extent_t *)_mesg;
     unsigned            flags = 0;
     unsigned            u; /* Local counting variable */
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_STATIC_NOERR
 
     /* check args */
     HDassert(f);
@@ -290,15 +300,15 @@ H5O_sdspace_encode(H5F_t *f, uint8_t *p, const void *_mesg)
     }     /* end if */
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5O_sdspace_encode() */
+} /* end H5O__sdspace_encode() */
 
 /*--------------------------------------------------------------------------
  NAME
-    H5O_sdspace_copy
+    H5O__sdspace_copy
  PURPOSE
     Copies a message from MESG to DEST, allocating DEST if necessary.
  USAGE
-    void *H5O_sdspace_copy(_mesg, _dest)
+    void *H5O__sdspace_copy(_mesg, _dest)
         const void *_mesg;	IN: Pointer to the source extent dimensionality struct
         const void *_dest;	IN: Pointer to the destination extent dimensionality struct
  RETURNS
@@ -308,13 +318,13 @@ H5O_sdspace_encode(H5F_t *f, uint8_t *p, const void *_mesg)
     allocating the destination structure if necessary.
 --------------------------------------------------------------------------*/
 static void *
-H5O_sdspace_copy(const void *_mesg, void *_dest)
+H5O__sdspace_copy(const void *_mesg, void *_dest)
 {
     const H5S_extent_t *mesg      = (const H5S_extent_t *)_mesg;
-    H5S_extent_t *      dest      = (H5S_extent_t *)_dest;
-    void *              ret_value = NULL; /* Return value */
+    H5S_extent_t       *dest      = (H5S_extent_t *)_dest;
+    void               *ret_value = NULL; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_STATIC
 
     /* check args */
     HDassert(mesg);
@@ -334,15 +344,15 @@ done:
             dest = H5FL_FREE(H5S_extent_t, dest);
 
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5O_sdspace_copy() */
+} /* end H5O__sdspace_copy() */
 
 /*--------------------------------------------------------------------------
  NAME
-    H5O_sdspace_size
+    H5O__sdspace_size
  PURPOSE
     Return the raw message size in bytes
  USAGE
-    void *H5O_sdspace_size(f, mesg)
+    void *H5O__sdspace_size(f, mesg)
         H5F_t *f;	  IN: pointer to the HDF5 file struct
         const void *mesg;	IN: Pointer to the source extent dimensionality struct
  RETURNS
@@ -352,18 +362,14 @@ done:
     success.  (Not counting the message type or size fields, only the data
     portion of the message).  It doesn't take into account alignment.
 
- MODIFICATIONS
-        Robb Matzke, 1998-04-09
-        The current and maximum dimensions are now H5F_SIZEOF_SIZET bytes
-        instead of just four bytes.
 --------------------------------------------------------------------------*/
 static size_t
-H5O_sdspace_size(const H5F_t *f, const void *_mesg)
+H5O__sdspace_size(const H5F_t *f, const void *_mesg)
 {
     const H5S_extent_t *space     = (const H5S_extent_t *)_mesg;
     size_t              ret_value = 0; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_STATIC_NOERR
 
     /* Basic information for all dataspace messages */
     ret_value = (size_t)(1 +                                                  /* Version */
@@ -379,7 +385,7 @@ H5O_sdspace_size(const H5F_t *f, const void *_mesg)
     ret_value += space->max ? (space->rank * H5F_SIZEOF_SIZE(f)) : 0;
 
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5O_sdspace_size() */
+} /* end H5O__sdspace_size() */
 
 /*-------------------------------------------------------------------------
  * Function:	H5O__sdspace_reset
@@ -431,7 +437,7 @@ H5O__sdspace_free(void *mesg)
 } /* end H5O__sdspace_free() */
 
 /*-------------------------------------------------------------------------
- * Function:    H5O_sdspace_pre_copy_file
+ * Function:    H5O__sdspace_pre_copy_file
  *
  * Purpose:     Perform any necessary actions before copying message between
  *              files
@@ -446,14 +452,14 @@ H5O__sdspace_free(void *mesg)
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5O_sdspace_pre_copy_file(H5F_t H5_ATTR_UNUSED *file_src, const void *mesg_src,
-                          hbool_t H5_ATTR_UNUSED *deleted, const H5O_copy_t *cpy_info, void *_udata)
+H5O__sdspace_pre_copy_file(H5F_t H5_ATTR_UNUSED *file_src, const void *mesg_src,
+                           hbool_t H5_ATTR_UNUSED *deleted, const H5O_copy_t *cpy_info, void *_udata)
 {
     const H5S_extent_t *src_space_extent = (const H5S_extent_t *)mesg_src; /* Source dataspace extent */
     H5D_copy_file_ud_t *udata            = (H5D_copy_file_ud_t *)_udata;   /* Dataset copying user data */
     herr_t              ret_value        = SUCCEED;                        /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_STATIC
 
     /* check args */
     HDassert(file_src);
