@@ -1,67 +1,62 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-
-/* Programmer:  James Laird <jlaird@hdfgroup.org>
+/* Programmer:  James Laird
  *              Monday, January 29, 2007
  *
  * Purpose:	A message holding "implicitly shared object header message"
  *              information in the superblock extension.
  */
 
-#include "H5Omodule.h"          /* This source code file is part of the H5O module */
+#include "H5Omodule.h" /* This source code file is part of the H5O module */
 
+#include "H5private.h"   /* Generic Functions			*/
+#include "H5Eprivate.h"  /* Error handling		  	*/
+#include "H5Opkg.h"      /* Object headers			*/
+#include "H5MMprivate.h" /* Memory management			*/
 
-#include "H5private.h"		/* Generic Functions			*/
-#include "H5Eprivate.h"		/* Error handling		  	*/
-#include "H5Opkg.h"             /* Object headers			*/
-#include "H5MMprivate.h"	/* Memory management			*/
-
-static void  *H5O_shmesg_decode(H5F_t *f, hid_t dxpl_id, H5O_t *open_oh,
-    unsigned mesg_flags, unsigned *ioflags, size_t p_size, const uint8_t *p);
-static herr_t H5O_shmesg_encode(H5F_t *f, hbool_t disable_shared, uint8_t *p, const void *_mesg);
-static void  *H5O_shmesg_copy(const void *_mesg, void *_dest);
-static size_t H5O_shmesg_size(const H5F_t *f, hbool_t disable_shared, const void *_mesg);
-static herr_t H5O_shmesg_debug(H5F_t *f, hid_t dxpl_id, const void *_mesg, FILE *stream,
-			     int indent, int fwidth);
+static void  *H5O__shmesg_decode(H5F_t *f, H5O_t *open_oh, unsigned mesg_flags, unsigned *ioflags,
+                                 size_t p_size, const uint8_t *p);
+static herr_t H5O__shmesg_encode(H5F_t *f, hbool_t disable_shared, uint8_t *p, const void *_mesg);
+static void  *H5O__shmesg_copy(const void *_mesg, void *_dest);
+static size_t H5O__shmesg_size(const H5F_t *f, hbool_t disable_shared, const void *_mesg);
+static herr_t H5O__shmesg_debug(H5F_t *f, const void *_mesg, FILE *stream, int indent, int fwidth);
 
 /* This message derives from H5O message class */
 const H5O_msg_class_t H5O_MSG_SHMESG[1] = {{
     H5O_SHMESG_ID,              /*message id number                     */
     "shared message table",     /*message name for debugging            */
-    sizeof(H5O_shmesg_table_t),	/*native message size                   */
-    0,				/* messages are sharable?       */
-    H5O_shmesg_decode,		/*decode message                        */
-    H5O_shmesg_encode,		/*encode message                        */
-    H5O_shmesg_copy,            /*copy the native value                 */
-    H5O_shmesg_size,		/*raw message size			*/
+    sizeof(H5O_shmesg_table_t), /*native message size                   */
+    0,                          /* messages are shareable?       */
+    H5O__shmesg_decode,         /*decode message                        */
+    H5O__shmesg_encode,         /*encode message                        */
+    H5O__shmesg_copy,           /*copy the native value                 */
+    H5O__shmesg_size,           /*raw message size			*/
     NULL,                       /*free internal memory			*/
     NULL,                       /* free method				*/
-    NULL,			/* file delete method			*/
-    NULL,			/* link method				*/
-    NULL,	                /* set share method			*/
-    NULL,		    	/*can share method		        */
-    NULL,			/* pre copy native value to file	*/
-    NULL,			/* copy native value to file		*/
-    NULL,			/* post copy native value to file	*/
-    NULL,			/* get creation index		        */
-    NULL,			/* set creation index		        */
-    H5O_shmesg_debug              /*debug the message			*/
+    NULL,                       /* file delete method			*/
+    NULL,                       /* link method				*/
+    NULL,                       /* set share method			*/
+    NULL,                       /*can share method		        */
+    NULL,                       /* pre copy native value to file	*/
+    NULL,                       /* copy native value to file		*/
+    NULL,                       /* post copy native value to file	*/
+    NULL,                       /* get creation index		        */
+    NULL,                       /* set creation index		        */
+    H5O__shmesg_debug           /*debug the message			*/
 }};
 
-
 /*-------------------------------------------------------------------------
- * Function:	H5O_shmesg_decode
+ * Function:	H5O__shmesg_decode
  *
  * Purpose:	Decode a shared message table message and return a pointer
  *              to a newly allocated H5O_shmesg_table_t struct.
@@ -75,21 +70,21 @@ const H5O_msg_class_t H5O_MSG_SHMESG[1] = {{
  *-------------------------------------------------------------------------
  */
 static void *
-H5O_shmesg_decode(H5F_t *f, hid_t H5_ATTR_UNUSED dxpl_id, H5O_t H5_ATTR_UNUSED *open_oh,
-    unsigned H5_ATTR_UNUSED mesg_flags, unsigned H5_ATTR_UNUSED *ioflags,
-    size_t H5_ATTR_UNUSED p_size, const uint8_t *p)
+H5O__shmesg_decode(H5F_t *f, H5O_t H5_ATTR_UNUSED *open_oh, unsigned H5_ATTR_UNUSED mesg_flags,
+                   unsigned H5_ATTR_UNUSED *ioflags, size_t H5_ATTR_UNUSED p_size, const uint8_t *p)
 {
-    H5O_shmesg_table_t	*mesg;                  /* Native message */
-    void		*ret_value = NULL;      /* Return value */
+    H5O_shmesg_table_t *mesg;             /* Native message */
+    void               *ret_value = NULL; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_STATIC
 
     /* Sanity check */
     HDassert(f);
     HDassert(p);
 
-    if(NULL == (mesg = (H5O_shmesg_table_t *)H5MM_calloc(sizeof(H5O_shmesg_table_t))))
-	HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed for shared message table message")
+    if (NULL == (mesg = (H5O_shmesg_table_t *)H5MM_calloc(sizeof(H5O_shmesg_table_t))))
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL,
+                    "memory allocation failed for shared message table message")
 
     /* Retrieve version, table address, and number of indexes */
     mesg->version = *p++;
@@ -101,11 +96,10 @@ H5O_shmesg_decode(H5F_t *f, hid_t H5_ATTR_UNUSED dxpl_id, H5O_t H5_ATTR_UNUSED *
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5O_shmesg_decode() */
+} /* end H5O__shmesg_decode() */
 
-
 /*-------------------------------------------------------------------------
- * Function:	H5O_shmesg_encode
+ * Function:	H5O__shmesg_encode
  *
  * Purpose:	Encode a shared message table message.
  *
@@ -117,11 +111,11 @@ done:
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5O_shmesg_encode(H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, uint8_t *p, const void *_mesg)
+H5O__shmesg_encode(H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, uint8_t *p, const void *_mesg)
 {
     const H5O_shmesg_table_t *mesg = (const H5O_shmesg_table_t *)_mesg;
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_STATIC_NOERR
 
     /* Sanity check */
     HDassert(f);
@@ -134,11 +128,10 @@ H5O_shmesg_encode(H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, uint8_t *p, c
     *p++ = (uint8_t)mesg->nindexes;
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5O_shmesg_encode() */
+} /* end H5O__shmesg_encode() */
 
-
 /*-------------------------------------------------------------------------
- * Function:	H5O_shmesg_copy
+ * Function:	H5O__shmesg_copy
  *
  * Purpose:	Copies a message from _MESG to _DEST, allocating _DEST if
  *		necessary.
@@ -152,19 +145,20 @@ H5O_shmesg_encode(H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, uint8_t *p, c
  *-------------------------------------------------------------------------
  */
 static void *
-H5O_shmesg_copy(const void *_mesg, void *_dest)
+H5O__shmesg_copy(const void *_mesg, void *_dest)
 {
-    const H5O_shmesg_table_t	*mesg = (const H5O_shmesg_table_t *)_mesg;
-    H5O_shmesg_table_t		*dest = (H5O_shmesg_table_t *)_dest;
-    void			*ret_value = NULL;      /* Return value */
+    const H5O_shmesg_table_t *mesg      = (const H5O_shmesg_table_t *)_mesg;
+    H5O_shmesg_table_t       *dest      = (H5O_shmesg_table_t *)_dest;
+    void                     *ret_value = NULL; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_STATIC
 
     /* Sanity check */
     HDassert(mesg);
 
-    if(!dest && NULL == (dest = (H5O_shmesg_table_t *)H5MM_malloc(sizeof(H5O_shmesg_table_t))))
-	HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed for shared message table message")
+    if (!dest && NULL == (dest = (H5O_shmesg_table_t *)H5MM_malloc(sizeof(H5O_shmesg_table_t))))
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL,
+                    "memory allocation failed for shared message table message")
 
     /* All this message requires is a shallow copy */
     *dest = *mesg;
@@ -174,11 +168,10 @@ H5O_shmesg_copy(const void *_mesg, void *_dest)
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5O_shmesg_copy() */
+} /* end H5O__shmesg_copy() */
 
-
 /*-------------------------------------------------------------------------
- * Function:	H5O_shmesg_size
+ * Function:	H5O__shmesg_size
  *
  * Purpose:	Returns the size of the raw message in bytes not counting the
  *		message type or size fields, but only the data fields.
@@ -192,25 +185,24 @@ done:
  *-------------------------------------------------------------------------
  */
 static size_t
-H5O_shmesg_size(const H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, const void H5_ATTR_UNUSED *_mesg)
+H5O__shmesg_size(const H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, const void H5_ATTR_UNUSED *_mesg)
 {
-    size_t ret_value = 0;       /* Return value */
+    size_t ret_value = 0; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_STATIC_NOERR
 
     /* Sanity check */
     HDassert(f);
 
-    ret_value = (size_t)(1 +                     /* Version number        */
-		H5F_SIZEOF_ADDR(f) +    /* Table address */
-		1);                      /* Number of indexes */
+    ret_value = (size_t)(1 +                  /* Version number        */
+                         H5F_SIZEOF_ADDR(f) + /* Table address */
+                         1);                  /* Number of indexes */
 
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5O_shmesg_size() */
+} /* end H5O__shmesg_size() */
 
-
 /*-------------------------------------------------------------------------
- * Function:	H5O_shmesg_debug
+ * Function:	H5O__shmesg_debug
  *
  * Purpose:	Prints debugging info for the message.
  *
@@ -222,12 +214,11 @@ H5O_shmesg_size(const H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, const voi
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5O_shmesg_debug(H5F_t H5_ATTR_UNUSED *f, hid_t H5_ATTR_UNUSED dxpl_id, const void *_mesg, FILE *stream,
-    int indent, int fwidth)
+H5O__shmesg_debug(H5F_t H5_ATTR_UNUSED *f, const void *_mesg, FILE *stream, int indent, int fwidth)
 {
     const H5O_shmesg_table_t *mesg = (const H5O_shmesg_table_t *)_mesg;
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_STATIC_NOERR
 
     /* Sanity check */
     HDassert(f);
@@ -236,13 +227,10 @@ H5O_shmesg_debug(H5F_t H5_ATTR_UNUSED *f, hid_t H5_ATTR_UNUSED dxpl_id, const vo
     HDassert(indent >= 0);
     HDassert(fwidth >= 0);
 
-    HDfprintf(stream, "%*s%-*s %u\n", indent, "", fwidth,
-	      "Version:", mesg->version);
-    HDfprintf(stream, "%*s%-*s %a (rel)\n", indent, "", fwidth,
-	      "Shared message table address:", mesg->addr);
-    HDfprintf(stream, "%*s%-*s %u\n", indent, "", fwidth,
-	      "Number of indexes:", mesg->nindexes);
+    HDfprintf(stream, "%*s%-*s %u\n", indent, "", fwidth, "Version:", mesg->version);
+    HDfprintf(stream, "%*s%-*s %" PRIuHADDR " (rel)\n", indent, "", fwidth,
+              "Shared message table address:", mesg->addr);
+    HDfprintf(stream, "%*s%-*s %u\n", indent, "", fwidth, "Number of indexes:", mesg->nindexes);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5O_shmesg_debug() */
-
+} /* end H5O__shmesg_debug() */
