@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -241,7 +240,7 @@ H5S_term_package(void)
  REVISION LOG
 --------------------------------------------------------------------------*/
 herr_t
-H5S_get_validated_dataspace(hid_t space_id, const H5S_t **space)
+H5S_get_validated_dataspace(hid_t space_id, H5S_t **space)
 {
     herr_t ret_value = SUCCEED; /* Return value */
 
@@ -258,7 +257,7 @@ H5S_get_validated_dataspace(hid_t space_id, const H5S_t **space)
         *space = NULL;
     else {
         /* Get the dataspace pointer */
-        if (NULL == (*space = (const H5S_t *)H5I_object_verify(space_id, H5I_DATASPACE)))
+        if (NULL == (*space = H5I_object_verify(space_id, H5I_DATASPACE)))
             HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "space_id is not a dataspace ID")
 
         /* Check for valid selection */
@@ -782,7 +781,7 @@ done:
 hssize_t
 H5Sget_simple_extent_npoints(hid_t space_id)
 {
-    H5S_t *  ds;
+    H5S_t   *ds;
     hssize_t ret_value;
 
     FUNC_ENTER_API(FAIL)
@@ -1533,7 +1532,7 @@ done:
 herr_t
 H5S_encode(H5S_t *obj, unsigned char **p, size_t *nalloc)
 {
-    H5F_t *  f = NULL;            /* Fake file structure*/
+    H5F_t   *f = NULL;            /* Fake file structure*/
     size_t   extent_size;         /* Size of serialized dataspace extent */
     hssize_t sselect_size;        /* Signed size of serialized dataspace selection */
     size_t   select_size;         /* Size of serialized dataspace selection */
@@ -1648,13 +1647,13 @@ done:
 H5S_t *
 H5S_decode(const unsigned char **p)
 {
-    H5F_t *              f = NULL;         /* Fake file structure*/
-    H5S_t *              ds;               /* Decoded dataspace */
-    H5S_extent_t *       extent;           /* Entent of decoded dataspace */
+    H5F_t               *f = NULL;         /* Fake file structure*/
+    H5S_t               *ds;               /* Decoded dataspace */
+    H5S_extent_t        *extent;           /* Extent of decoded dataspace */
     const unsigned char *pp = (*p);        /* Local pointer for decoding */
     size_t               extent_size;      /* size of the extent message*/
     uint8_t              sizeof_size;      /* 'Size of sizes' for file */
-    H5S_t *              ret_value = NULL; /* Return value */
+    H5S_t               *ret_value = NULL; /* Return value */
 
     FUNC_ENTER_NOAPI_NOINIT
 
@@ -1696,9 +1695,10 @@ H5S_decode(const unsigned char **p)
     if (H5S_select_all(ds, FALSE) < 0)
         HGOTO_ERROR(H5E_DATASPACE, H5E_CANTSET, NULL, "unable to set all selection")
 
-    /* Decode the select part of dataspace.  I believe this part always exists. */
+    /* Decode the select part of dataspace.
+     *  Because size of buffer is unknown, assume arbitrarily large buffer to allow decoding. */
     *p = pp;
-    if (H5S_SELECT_DESERIALIZE(&ds, p) < 0)
+    if (H5S_SELECT_DESERIALIZE(&ds, p, SIZE_MAX) < 0)
         HGOTO_ERROR(H5E_DATASPACE, H5E_CANTDECODE, NULL, "can't decode space selection")
 
     /* Set return value */
@@ -1762,7 +1762,7 @@ done:
 H5S_class_t
 H5Sget_simple_extent_type(hid_t sid)
 {
-    H5S_t *     space;
+    H5S_t      *space;
     H5S_class_t ret_value; /* Return value */
 
     FUNC_ENTER_API(H5S_NO_CLASS)
@@ -1985,7 +1985,7 @@ done:
     htri_t H5S_extent_equal(ds1, ds2)
         H5S_t *ds1, *ds2;            IN: Dataspace objects to compare
  RETURNS
-     TRUE if equal, FALSE if unequal on succeess/Negative on failure
+     TRUE if equal, FALSE if unequal on success/Negative on failure
  DESCRIPTION
     Compare two dataspaces if their extents are identical.
 --------------------------------------------------------------------------*/
