@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -30,37 +29,6 @@
 #include "H5Pprivate.h" /* Property lists			*/
 #include "H5Tprivate.h" /* Datatypes				*/
 
-/* Flags for selection iterators */
-#define H5S_SEL_ITER_GET_SEQ_LIST_SORTED                                                                     \
-    0x0001 /* Retrieve elements from iterator                                                                \
-            * in increasing offset order, for                                                                \
-            * each call to retrieve sequences.                                                               \
-            * Currently, this only applies to                                                                \
-            * point selections, as hyperslab                                                                 \
-            * selections are always returned                                                                 \
-            * in increasing offset order.                                                                    \
-            *                                                                                                \
-            * Note that the order is only                                                                    \
-            * increasing for each call to                                                                    \
-            * get_seq_list, the next set of                                                                  \
-            * sequences could start with an                                                                  \
-            * earlier offset than the previous                                                               \
-            * one.                                                                                           \
-            */
-#define H5S_SEL_ITER_SHARE_WITH_DATASPACE                                                                    \
-    0x0002 /* Don't copy the dataspace                                                                       \
-            * selection when creating the                                                                    \
-            * selection iterator.                                                                            \
-            *                                                                                                \
-            * This can improve performance                                                                   \
-            * of creating the iterator, but                                                                  \
-            * the dataspace _MUST_NOT_ be                                                                    \
-            * modified or closed until the                                                                   \
-            * selection iterator is closed                                                                   \
-            * or the iterator's behavior                                                                     \
-            * will be undefined.                                                                             \
-            */
-
 /* Forward references of package typedefs */
 typedef struct H5S_extent_t          H5S_extent_t;
 typedef struct H5S_pnt_node_t        H5S_pnt_node_t;
@@ -104,7 +72,7 @@ typedef struct {
     /* Irregular hyperslab selection fields */
     hsize_t loc_off[H5S_MAX_RANK]; /* Byte offset in buffer, for each dimension's current offset */
     H5S_hyper_span_info_t *spans;  /* Pointer to copy of the span tree */
-    H5S_hyper_span_t *     span[H5S_MAX_RANK]; /* Array of pointers to span nodes */
+    H5S_hyper_span_t      *span[H5S_MAX_RANK]; /* Array of pointers to span nodes */
 } H5S_hyper_iter_t;
 
 /* "All" selection iteration container */
@@ -222,7 +190,7 @@ typedef struct H5S_sel_iter_op_t {
 #define H5S_SELECT_SHAPE_SAME(S1, S2)             (H5S_select_shape_same(S1, S2))
 #define H5S_SELECT_INTERSECT_BLOCK(S, START, END) (H5S_select_intersect_block(S, START, END))
 #define H5S_SELECT_RELEASE(S)                     (H5S_select_release(S))
-#define H5S_SELECT_DESERIALIZE(S, BUF)            (H5S_select_deserialize(S, BUF))
+#define H5S_SELECT_DESERIALIZE(S, BUF, BUF_SIZE)  (H5S_select_deserialize(S, BUF, BUF_SIZE))
 
 /* Forward declaration of structs used below */
 struct H5O_t;
@@ -232,7 +200,7 @@ struct H5O_loc_t;
 typedef struct H5S_t H5S_t;
 
 /* Operations on dataspaces */
-H5_DLL H5S_t *     H5S_copy(const H5S_t *src, hbool_t share_selection, hbool_t copy_max);
+H5_DLL H5S_t      *H5S_copy(const H5S_t *src, hbool_t share_selection, hbool_t copy_max);
 H5_DLL herr_t      H5S_close(H5S_t *ds);
 H5_DLL H5S_class_t H5S_get_simple_extent_type(const H5S_t *ds);
 H5_DLL hssize_t    H5S_get_simple_extent_npoints(const H5S_t *ds);
@@ -247,7 +215,7 @@ H5_DLL htri_t H5S_set_extent(H5S_t *space, const hsize_t *size);
 H5_DLL herr_t H5S_set_extent_real(H5S_t *space, const hsize_t *size);
 H5_DLL herr_t H5S_set_extent_simple(H5S_t *space, unsigned rank, const hsize_t *dims, const hsize_t *max);
 H5_DLL H5S_t *H5S_create(H5S_class_t type);
-H5_DLL herr_t H5S_get_validated_dataspace(hid_t space_id, const H5S_t **space /*out*/);
+H5_DLL herr_t H5S_get_validated_dataspace(hid_t space_id, H5S_t **space /*out*/);
 H5_DLL H5S_t *H5S_create_simple(unsigned rank, const hsize_t dims[/*rank*/], const hsize_t maxdims[/*rank*/]);
 H5_DLL herr_t H5S_set_version(H5F_t *f, H5S_t *ds);
 H5_DLL herr_t H5S_encode(H5S_t *obj, unsigned char **p, size_t *nalloc);
@@ -261,38 +229,37 @@ H5_DLL htri_t  H5S_extent_equal(const H5S_t *ds1, const H5S_t *ds2);
 H5_DLL herr_t  H5S_extent_copy(H5S_t *dst, const H5S_t *src);
 
 /* Operations on selections */
-H5_DLL herr_t       H5S_select_deserialize(H5S_t **space, const uint8_t **p);
+H5_DLL herr_t       H5S_select_deserialize(H5S_t **space, const uint8_t **p, const size_t p_size);
 H5_DLL H5S_sel_type H5S_get_select_type(const H5S_t *space);
-H5_DLL herr_t       H5S_select_iterate(void *buf, const H5T_t *type, const H5S_t *space,
-                                       const H5S_sel_iter_op_t *op, void *op_data);
-H5_DLL herr_t       H5S_select_fill(const void *fill, size_t fill_size, const H5S_t *space, void *buf);
-H5_DLL htri_t       H5S_select_valid(const H5S_t *space);
-H5_DLL hsize_t      H5S_get_select_npoints(const H5S_t *space);
-H5_DLL herr_t       H5S_get_select_bounds(const H5S_t *space, hsize_t *start, hsize_t *end);
-H5_DLL herr_t       H5S_get_select_offset(const H5S_t *space, hsize_t *offset);
-H5_DLL int          H5S_get_select_unlim_dim(const H5S_t *space);
-H5_DLL herr_t       H5S_get_select_num_elem_non_unlim(const H5S_t *space, hsize_t *num_elem_non_unlim);
-H5_DLL herr_t       H5S_select_offset(H5S_t *space, const hssize_t *offset);
-H5_DLL herr_t       H5S_select_copy(H5S_t *dst, const H5S_t *src, hbool_t share_selection);
-H5_DLL htri_t       H5S_select_shape_same(const H5S_t *space1, const H5S_t *space2);
-H5_DLL htri_t       H5S_select_intersect_block(const H5S_t *space, const hsize_t *start, const hsize_t *end);
-H5_DLL herr_t       H5S_select_construct_projection(const H5S_t *base_space, H5S_t **new_space_ptr,
-                                                    unsigned new_space_rank, const void *buf,
-                                                    void const **adj_buf_ptr, hsize_t element_size);
-H5_DLL herr_t       H5S_select_release(H5S_t *ds);
-H5_DLL hssize_t     H5S_select_serial_size(const H5S_t *space);
-H5_DLL herr_t       H5S_select_serialize(const H5S_t *space, uint8_t **p);
-H5_DLL htri_t       H5S_select_is_contiguous(const H5S_t *space);
-H5_DLL htri_t       H5S_select_is_single(const H5S_t *space);
-H5_DLL htri_t       H5S_select_is_regular(const H5S_t *space);
-H5_DLL herr_t       H5S_select_adjust_u(H5S_t *space, const hsize_t *offset);
-H5_DLL herr_t       H5S_select_adjust_s(H5S_t *space, const hssize_t *offset);
-H5_DLL herr_t       H5S_select_project_scalar(const H5S_t *space, hsize_t *offset);
-H5_DLL herr_t       H5S_select_project_simple(const H5S_t *space, H5S_t *new_space, hsize_t *offset);
-H5_DLL herr_t       H5S_select_project_intersection(const H5S_t *src_space, const H5S_t *dst_space,
-                                                    const H5S_t *src_intersect_space, H5S_t **new_space_ptr,
-                                                    hbool_t share_space);
-H5_DLL herr_t       H5S_select_subtract(H5S_t *space, H5S_t *subtract_space);
+H5_DLL herr_t   H5S_select_iterate(void *buf, const H5T_t *type, H5S_t *space, const H5S_sel_iter_op_t *op,
+                                   void *op_data);
+H5_DLL herr_t   H5S_select_fill(const void *fill, size_t fill_size, H5S_t *space, void *buf);
+H5_DLL htri_t   H5S_select_valid(const H5S_t *space);
+H5_DLL hsize_t  H5S_get_select_npoints(const H5S_t *space);
+H5_DLL herr_t   H5S_get_select_bounds(const H5S_t *space, hsize_t *start, hsize_t *end);
+H5_DLL herr_t   H5S_get_select_offset(const H5S_t *space, hsize_t *offset);
+H5_DLL int      H5S_get_select_unlim_dim(const H5S_t *space);
+H5_DLL herr_t   H5S_get_select_num_elem_non_unlim(const H5S_t *space, hsize_t *num_elem_non_unlim);
+H5_DLL herr_t   H5S_select_offset(H5S_t *space, const hssize_t *offset);
+H5_DLL herr_t   H5S_select_copy(H5S_t *dst, const H5S_t *src, hbool_t share_selection);
+H5_DLL htri_t   H5S_select_shape_same(H5S_t *space1, H5S_t *space2);
+H5_DLL htri_t   H5S_select_intersect_block(H5S_t *space, const hsize_t *start, const hsize_t *end);
+H5_DLL herr_t   H5S_select_construct_projection(H5S_t *base_space, H5S_t **new_space_ptr,
+                                                unsigned new_space_rank, hsize_t element_size,
+                                                ptrdiff_t *buf_adj);
+H5_DLL herr_t   H5S_select_release(H5S_t *ds);
+H5_DLL hssize_t H5S_select_serial_size(H5S_t *space);
+H5_DLL herr_t   H5S_select_serialize(H5S_t *space, uint8_t **p);
+H5_DLL htri_t   H5S_select_is_contiguous(const H5S_t *space);
+H5_DLL htri_t   H5S_select_is_single(const H5S_t *space);
+H5_DLL htri_t   H5S_select_is_regular(H5S_t *space);
+H5_DLL herr_t   H5S_select_adjust_u(H5S_t *space, const hsize_t *offset);
+H5_DLL herr_t   H5S_select_adjust_s(H5S_t *space, const hssize_t *offset);
+H5_DLL herr_t   H5S_select_project_scalar(const H5S_t *space, hsize_t *offset);
+H5_DLL herr_t   H5S_select_project_simple(const H5S_t *space, H5S_t *new_space, hsize_t *offset);
+H5_DLL herr_t H5S_select_project_intersection(H5S_t *src_space, H5S_t *dst_space, H5S_t *src_intersect_space,
+                                              H5S_t **new_space_ptr, hbool_t share_space);
+H5_DLL herr_t H5S_select_subtract(H5S_t *space, H5S_t *subtract_space);
 
 /* Operations on all selections */
 H5_DLL herr_t H5S_select_all(H5S_t *space, hbool_t rel_prev);
@@ -317,12 +284,11 @@ H5_DLL hsize_t H5S_hyper_get_clip_extent(const H5S_t *clip_space, const H5S_t *m
                                          hbool_t incl_trail);
 H5_DLL hsize_t H5S_hyper_get_clip_extent_match(const H5S_t *clip_space, const H5S_t *match_space,
                                                hsize_t match_clip_size, hbool_t incl_trail);
-H5_DLL H5S_t * H5S_hyper_get_unlim_block(const H5S_t *space, hsize_t block_index);
+H5_DLL H5S_t  *H5S_hyper_get_unlim_block(const H5S_t *space, hsize_t block_index);
 H5_DLL hsize_t H5S_hyper_get_first_inc_block(const H5S_t *space, hsize_t clip_size, hbool_t *partial);
 
 /* Operations on selection iterators */
-H5_DLL herr_t  H5S_select_iter_init(H5S_sel_iter_t *iter, const H5S_t *space, size_t elmt_size,
-                                    unsigned flags);
+H5_DLL herr_t  H5S_select_iter_init(H5S_sel_iter_t *iter, H5S_t *space, size_t elmt_size, unsigned flags);
 H5_DLL herr_t  H5S_select_iter_coords(const H5S_sel_iter_t *sel_iter, hsize_t *coords);
 H5_DLL hsize_t H5S_select_iter_nelmts(const H5S_sel_iter_t *sel_iter);
 H5_DLL herr_t  H5S_select_iter_next(H5S_sel_iter_t *sel_iter, size_t nelem);
@@ -332,7 +298,7 @@ H5_DLL herr_t H5S_select_iter_release(H5S_sel_iter_t *sel_iter);
 H5_DLL herr_t H5S_sel_iter_close(H5S_sel_iter_t *sel_iter);
 
 #ifdef H5_HAVE_PARALLEL
-H5_DLL herr_t H5S_mpio_space_type(const H5S_t *space, size_t elmt_size,
+H5_DLL herr_t H5S_mpio_space_type(H5S_t *space, size_t elmt_size,
                                   /* out: */ MPI_Datatype *new_type, int *count, hbool_t *is_derived_type,
                                   hbool_t do_permute, hsize_t **permute_map, hbool_t *is_permuted);
 #endif /* H5_HAVE_PARALLEL */
