@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -40,6 +39,7 @@
 #include "H5Fprivate.h"  /* Files				*/
 #include "H5FLprivate.h" /* Free Lists				*/
 #include "H5Oprivate.h"  /* Object headers		  	*/
+#include "H5VLprivate.h" /* Virtual Object Layer                     */
 
 /* Other public headers needed by this file */
 #include "H5Spublic.h" /* Dataspace functions			*/
@@ -48,7 +48,8 @@
 #define H5T_NAMELEN 32
 
 /* Macro to ease detecting "complex" datatypes (i.e. those with base types or fields) */
-#define H5T_IS_COMPLEX(t) ((t) == H5T_COMPOUND || (t) == H5T_ENUM || (t) == H5T_VLEN || (t) == H5T_ARRAY)
+#define H5T_IS_COMPLEX(t)                                                                                    \
+    ((t) == H5T_COMPOUND || (t) == H5T_ENUM || (t) == H5T_VLEN || (t) == H5T_ARRAY || (t) == H5T_REFERENCE)
 
 /* Macro to ease detecting fixed "string" datatypes */
 #define H5T_IS_FIXED_STRING(dt) (H5T_STRING == (dt)->type)
@@ -95,9 +96,14 @@
 /* This version also encodes array types more efficiently */
 #define H5O_DTYPE_VERSION_3 3
 
+/* This is the version that adds support for new reference types and prevents
+ * older versions of the library to attempt reading unknown types.
+ */
+#define H5O_DTYPE_VERSION_4 4
+
 /* The latest version of the format.  Look through the 'encode helper' routine
  *      and 'size' callback for places to change when updating this. */
-#define H5O_DTYPE_VERSION_LATEST H5O_DTYPE_VERSION_3
+#define H5O_DTYPE_VERSION_LATEST H5O_DTYPE_VERSION_4
 
 /* Flags for visiting datatype */
 #define H5T_VISIT_COMPLEX_FIRST 0x01 /* Visit complex datatype before visiting member/parent datatypes */
@@ -116,7 +122,7 @@
 #endif
 
 /* Define an internal macro for converting unsigned long long to long double.  SGI compilers give
- * some incorect conversion.  64-bit Solaris does different rounding.   Windows Visual Studio 6 does
+ * some incorrect conversion.  64-bit Solaris does different rounding.   Windows Visual Studio 6 does
  * not support unsigned long long.  For FreeBSD(sleipnir), the last 2 bytes of mantissa are lost when
  * compiler tries to do the conversion.  For Cygwin, compiler doesn't do rounding correctly.
  * Mac OS 10.4 gives some incorrect result. */
@@ -163,8 +169,8 @@ typedef struct H5T_conv_func_t {
 /* The datatype conversion database */
 struct H5T_path_t {
     char            name[H5T_NAMELEN]; /*name for debugging only	     */
-    H5T_t *         src;               /*source datatype 		     */
-    H5T_t *         dst;               /*destination datatype		     */
+    H5T_t          *src;               /*source datatype 		     */
+    H5T_t          *dst;               /*destination datatype		     */
     H5T_conv_func_t conv;              /* Conversion function  */
     hbool_t         is_hard;           /*is it a hard function?	     */
     hbool_t         is_noop;           /*is it the noop conversion?	     */
@@ -173,6 +179,25 @@ struct H5T_path_t {
     H5T_cdata_t     cdata;             /*data for this function	     */
 };
 
+/* Reference function pointers */
+typedef herr_t (*H5T_ref_isnullfunc_t)(const H5VL_object_t *file, const void *src_buf, hbool_t *isnull);
+typedef herr_t (*H5T_ref_setnullfunc_t)(H5VL_object_t *file, void *dst_buf, void *bg_buf);
+typedef size_t (*H5T_ref_getsizefunc_t)(H5VL_object_t *src_file, const void *src_buf, size_t src_size,
+                                        H5VL_object_t *dst_file, hbool_t *dst_copy);
+typedef herr_t (*H5T_ref_readfunc_t)(H5VL_object_t *src_file, const void *src_buf, size_t src_size,
+                                     H5VL_object_t *dst_file, void *dst_buf, size_t dst_size);
+typedef herr_t (*H5T_ref_writefunc_t)(H5VL_object_t *src_file, const void *src_buf, size_t src_size,
+                                      H5R_type_t src_type, H5VL_object_t *dst_file, void *dst_buf,
+                                      size_t dst_size, void *bg_buf);
+
+typedef struct H5T_ref_class_t {
+    H5T_ref_isnullfunc_t  isnull;  /* check if reference value is NIL */
+    H5T_ref_setnullfunc_t setnull; /* set a reference value to NIL */
+    H5T_ref_getsizefunc_t getsize; /* get reference size (bytes)   */
+    H5T_ref_readfunc_t    read;    /* read reference into buffer   */
+    H5T_ref_writefunc_t   write;   /* write reference from buffer  */
+} H5T_ref_class_t;
+
 typedef struct H5T_atomic_t {
     H5T_order_t order;   /* byte order                           */
     size_t      prec;    /* precision in bits                    */
@@ -201,9 +226,13 @@ typedef struct H5T_atomic_t {
         } s;                 /* string types */
 
         struct {
-            H5R_type_t rtype; /* type of reference stored             */
-            H5T_loc_t  loc;   /* location of data in buffer           */
-        } r;                  /* reference types */
+            H5R_type_t             rtype;   /* type of reference stored             */
+            unsigned               version; /* version of encoded reference         */
+            hbool_t                opaque;  /* opaque reference type                */
+            H5T_loc_t              loc;     /* location of data in buffer           */
+            H5VL_object_t         *file;    /* file VOL pointer (if data is on disk) */
+            const H5T_ref_class_t *cls;     /* Pointer to ref class callbacks */
+        } r;                                /* reference types */
     } u;
 } H5T_atomic_t;
 
@@ -216,7 +245,7 @@ typedef enum H5T_sort_t {
 
 /* A compound datatype member */
 typedef struct H5T_cmemb_t {
-    char *        name;   /*name of this member		     */
+    char         *name;   /*name of this member		     */
     size_t        offset; /*offset from beginning of struct    */
     size_t        size;   /*size of this member		     */
     struct H5T_t *type;   /*type of this member		     */
@@ -237,19 +266,10 @@ typedef struct H5T_enum_t {
     unsigned   nalloc; /*num entries allocated		     */
     unsigned   nmembs; /*number of members defined in enum  */
     H5T_sort_t sorted; /*how are members sorted?	     */
-    uint8_t *  value;  /*array of values		     */
-    char **    name;   /*array of symbol names		     */
+    void      *value;  /*array of values		     */
+    char     **name;   /*array of symbol names		     */
 } H5T_enum_t;
 
-/* VL function pointers */
-typedef ssize_t (*H5T_vlen_getlenfunc_t)(const void *vl_addr);
-typedef void *(*H5T_vlen_getptrfunc_t)(void *vl_addr);
-typedef htri_t (*H5T_vlen_isnullfunc_t)(const H5F_t *f, void *vl_addr);
-typedef herr_t (*H5T_vlen_readfunc_t)(H5F_t *f, void *_vl, void *buf, size_t len);
-typedef herr_t (*H5T_vlen_writefunc_t)(H5F_t *f, const H5T_vlen_alloc_info_t *vl_alloc_info, void *_vl,
-                                       void *buf, void *_bg, size_t seq_len, size_t base_size);
-typedef herr_t (*H5T_vlen_setnullfunc_t)(H5F_t *f, void *_vl, void *_bg);
-
 /* VL types */
 typedef enum {
     H5T_VLEN_BADTYPE  = -1, /* invalid VL Type */
@@ -258,20 +278,36 @@ typedef enum {
     H5T_VLEN_MAXTYPE        /* highest type (Invalid as true type) */
 } H5T_vlen_type_t;
 
+/* VL function pointers */
+typedef herr_t (*H5T_vlen_getlen_func_t)(H5VL_object_t *file, const void *vl_addr, size_t *len);
+typedef void *(*H5T_vlen_getptr_func_t)(void *vl_addr);
+typedef herr_t (*H5T_vlen_isnull_func_t)(const H5VL_object_t *file, void *vl_addr, hbool_t *isnull);
+typedef herr_t (*H5T_vlen_setnull_func_t)(H5VL_object_t *file, void *_vl, void *_bg);
+typedef herr_t (*H5T_vlen_read_func_t)(H5VL_object_t *file, void *_vl, void *buf, size_t len);
+typedef herr_t (*H5T_vlen_write_func_t)(H5VL_object_t *file, const H5T_vlen_alloc_info_t *vl_alloc_info,
+                                        void *_vl, void *buf, void *_bg, size_t seq_len, size_t base_size);
+typedef herr_t (*H5T_vlen_delete_func_t)(H5VL_object_t *file, void *_vl);
+
+/* VL datatype callbacks */
+typedef struct H5T_vlen_class_t {
+    H5T_vlen_getlen_func_t  getlen;  /* Function to get VL sequence size (in element units, not bytes) */
+    H5T_vlen_getptr_func_t  getptr;  /* Function to get VL sequence pointer */
+    H5T_vlen_isnull_func_t  isnull;  /* Function to check if VL value is NIL */
+    H5T_vlen_setnull_func_t setnull; /* Function to set a VL value to NIL */
+    H5T_vlen_read_func_t    read;    /* Function to read VL sequence into buffer */
+    H5T_vlen_write_func_t   write;   /* Function to write VL sequence from buffer */
+    H5T_vlen_delete_func_t  del;     /* Function to delete VL sequence */
+} H5T_vlen_class_t;
+
 /* A VL datatype */
 typedef struct H5T_vlen_t {
-    H5T_vlen_type_t type;           /* Type of VL data in buffer */
-    H5T_loc_t       loc;            /* Location of VL data in buffer */
-    H5T_cset_t      cset;           /* For VL string: character set */
-    H5T_str_t       pad;            /* For VL string:  space or null padding of
-                                     * extra bytes */
-    H5F_t *                f;       /* File ID (if VL data is on disk) */
-    H5T_vlen_getptrfunc_t  getptr;  /* Function to get VL sequence pointer */
-    H5T_vlen_getlenfunc_t  getlen;  /* Function to get VL sequence size (in element units, not bytes) */
-    H5T_vlen_isnullfunc_t  isnull;  /* Function to check if VL value is NIL */
-    H5T_vlen_readfunc_t    read;    /* Function to read VL sequence into buffer */
-    H5T_vlen_writefunc_t   write;   /* Function to write VL sequence from buffer */
-    H5T_vlen_setnullfunc_t setnull; /* Function to set a VL value to NIL */
+    H5T_vlen_type_t type;         /* Type of VL data in buffer */
+    H5T_loc_t       loc;          /* Location of VL data in buffer */
+    H5T_cset_t      cset;         /* For VL string: character set */
+    H5T_str_t       pad;          /* For VL string: space or null padding of
+                                   * extra bytes */
+    H5VL_object_t          *file; /* File object (if VL data is on disk) */
+    const H5T_vlen_class_t *cls;  /* Pointer to VL class callbacks */
 } H5T_vlen_t;
 
 /* An opaque datatype */
@@ -302,8 +338,9 @@ typedef struct H5T_shared_t {
     size_t      size;     /*total size of an instance of this type     */
     unsigned    version;  /* Version of object header message to encode this object with */
     hbool_t
-                  force_conv; /* Set if this type always needs to be converted and H5T__conv_noop cannot be called */
-    struct H5T_t *parent; /*parent type for derived datatypes	     */
+        force_conv; /* Set if this type always needs to be converted and H5T__conv_noop cannot be called */
+    struct H5T_t  *parent;        /*parent type for derived datatypes	     */
+    H5VL_object_t *owned_vol_obj; /* Vol object owned by this type (free on close) */
     union {
         H5T_atomic_t atomic; /* an atomic datatype              */
         H5T_compnd_t compnd; /* a compound datatype (struct)    */
@@ -317,9 +354,10 @@ typedef struct H5T_shared_t {
 struct H5T_t {
     H5O_shared_t sh_loc; /* Shared message info (must be first) */
 
-    H5T_shared_t *shared; /* all other information */
-    H5O_loc_t     oloc;   /* Object location, if the type is a named type */
-    H5G_name_t    path;   /* group hier. path if the type is a named type */
+    H5T_shared_t  *shared;  /* all other information */
+    H5O_loc_t      oloc;    /* Object location, if the type is a named type */
+    H5G_name_t     path;    /* group hier. path if the type is a named type */
+    H5VL_object_t *vol_obj; /* pointer to VOL object when working with committed datatypes */
 };
 
 /* The master list of soft conversion functions */
@@ -362,14 +400,13 @@ H5_DLLVAR size_t H5T_NATIVE_LONG_COMP_ALIGN_g;
 H5_DLLVAR size_t H5T_NATIVE_LLONG_COMP_ALIGN_g;
 H5_DLLVAR size_t H5T_NATIVE_FLOAT_COMP_ALIGN_g;
 H5_DLLVAR size_t H5T_NATIVE_DOUBLE_COMP_ALIGN_g;
-#if H5_SIZEOF_LONG_DOUBLE != 0
 H5_DLLVAR size_t H5T_NATIVE_LDOUBLE_COMP_ALIGN_g;
-#endif
 
 H5_DLLVAR size_t H5T_POINTER_COMP_ALIGN_g;
 H5_DLLVAR size_t H5T_HVL_COMP_ALIGN_g;
 H5_DLLVAR size_t H5T_HOBJREF_COMP_ALIGN_g;
 H5_DLLVAR size_t H5T_HDSETREGREF_COMP_ALIGN_g;
+H5_DLLVAR size_t H5T_REF_COMP_ALIGN_g;
 
 /*
  * Alignment information for native types. A value of N indicates that the
@@ -389,9 +426,7 @@ H5_DLLVAR size_t H5T_NATIVE_LLONG_ALIGN_g;
 H5_DLLVAR size_t H5T_NATIVE_ULLONG_ALIGN_g;
 H5_DLLVAR size_t H5T_NATIVE_FLOAT_ALIGN_g;
 H5_DLLVAR size_t H5T_NATIVE_DOUBLE_ALIGN_g;
-#if H5_SIZEOF_LONG_DOUBLE != 0
 H5_DLLVAR size_t H5T_NATIVE_LDOUBLE_ALIGN_g;
-#endif
 
 /* C9x alignment constraints */
 H5_DLLVAR size_t H5T_NATIVE_INT8_ALIGN_g;
@@ -428,10 +463,8 @@ H5_DLLVAR float  H5T_NATIVE_FLOAT_POS_INF_g;
 H5_DLLVAR float  H5T_NATIVE_FLOAT_NEG_INF_g;
 H5_DLLVAR double H5T_NATIVE_DOUBLE_POS_INF_g;
 H5_DLLVAR double H5T_NATIVE_DOUBLE_NEG_INF_g;
-#if H5_SIZEOF_LONG_DOUBLE != 0
 H5_DLLVAR double H5T_NATIVE_LDOUBLE_POS_INF_g;
 H5_DLLVAR double H5T_NATIVE_LDOUBLE_NEG_INF_g;
-#endif
 
 /* Declare extern the free lists for H5T_t's and H5T_shared_t's */
 H5FL_EXTERN(H5T_t);
@@ -446,10 +479,12 @@ H5_DLL herr_t H5T__visit(H5T_t *dt, unsigned visit_flags, H5T_operator_t op, voi
 H5_DLL herr_t H5T__upgrade_version(H5T_t *dt, unsigned new_version);
 
 /* Committed / named datatype routines */
+H5_DLL herr_t H5T__commit_anon(H5F_t *file, H5T_t *type, hid_t tcpl_id);
 H5_DLL herr_t H5T__commit(H5F_t *file, H5T_t *type, hid_t tcpl_id);
 H5_DLL herr_t H5T__commit_named(const H5G_loc_t *loc, const char *name, H5T_t *dt, hid_t lcpl_id,
                                 hid_t tcpl_id);
 H5_DLL H5T_t *H5T__open_name(const H5G_loc_t *loc, const char *name);
+H5_DLL hid_t  H5T__get_create_plist(const H5T_t *type);
 
 /* Conversion functions */
 H5_DLL herr_t H5T__conv_noop(hid_t src_id, hid_t dst_id, H5T_cdata_t *cdata, size_t nelmts, size_t buf_stride,
@@ -471,6 +506,8 @@ H5_DLL herr_t H5T__conv_vlen(hid_t src_id, hid_t dst_id, H5T_cdata_t *cdata, siz
                              size_t bkg_stride, void *buf, void *bkg);
 H5_DLL herr_t H5T__conv_array(hid_t src_id, hid_t dst_id, H5T_cdata_t *cdata, size_t nelmts,
                               size_t buf_stride, size_t bkg_stride, void *buf, void *bkg);
+H5_DLL herr_t H5T__conv_ref(hid_t src_id, hid_t dst_id, H5T_cdata_t *cdata, size_t nelmts, size_t buf_stride,
+                            size_t bkg_stride, void *buf, void *bkg);
 H5_DLL herr_t H5T__conv_i_i(hid_t src_id, hid_t dst_id, H5T_cdata_t *cdata, size_t nelmts, size_t buf_stride,
                             size_t bkg_stride, void *_buf, void *bkg);
 H5_DLL herr_t H5T__conv_f_f(hid_t src_id, hid_t dst_id, H5T_cdata_t *cdata, size_t nelmts, size_t buf_stride,
@@ -816,17 +853,22 @@ H5_DLL void     H5T__bit_neg(uint8_t *buf, size_t start, size_t size);
 
 /* VL functions */
 H5_DLL H5T_t *H5T__vlen_create(const H5T_t *base);
-H5_DLL htri_t H5T__vlen_set_loc(const H5T_t *dt, H5F_t *f, H5T_loc_t loc);
+H5_DLL herr_t H5T__vlen_reclaim(void *elem, const H5T_t *dt, H5T_vlen_alloc_info_t *alloc_info);
+H5_DLL htri_t H5T__vlen_set_loc(H5T_t *dt, H5VL_object_t *file, H5T_loc_t loc);
 
 /* Array functions */
 H5_DLL H5T_t *H5T__array_create(H5T_t *base, unsigned ndims, const hsize_t dim[/* ndims */]);
 H5_DLL int    H5T__get_array_ndims(const H5T_t *dt);
 H5_DLL int    H5T__get_array_dims(const H5T_t *dt, hsize_t dims[]);
 
+/* Reference functions */
+H5_DLL herr_t H5T__ref_reclaim(void *elem, const H5T_t *dt);
+H5_DLL htri_t H5T__ref_set_loc(H5T_t *dt, H5VL_object_t *file, H5T_loc_t loc);
+
 /* Compound functions */
-H5_DLL herr_t H5T__insert(H5T_t *parent, const char *name, size_t offset, const H5T_t *member);
-H5_DLL size_t H5T__get_member_size(const H5T_t *dt, unsigned membno);
-H5_DLL void   H5T__update_packed(const H5T_t *dt);
+H5_DLL herr_t             H5T__insert(H5T_t *parent, const char *name, size_t offset, const H5T_t *member);
+H5_DLL size_t             H5T__get_member_size(const H5T_t *dt, unsigned membno);
+H5_DLL void               H5T__update_packed(const H5T_t *dt);
 H5_DLL H5T_subset_info_t *H5T__conv_struct_subset(const H5T_cdata_t *cdata);
 
 /* Enumerated type functions */
@@ -835,7 +877,7 @@ H5_DLL herr_t H5T__enum_insert(const H5T_t *dt, const char *name, const void *va
 H5_DLL herr_t H5T__get_member_value(const H5T_t *dt, unsigned membno, void *value);
 
 /* Field functions (for both compound & enumerated types) */
-H5_DLL char * H5T__get_member_name(H5T_t const *dt, unsigned membno);
+H5_DLL char  *H5T__get_member_name(H5T_t const *dt, unsigned membno);
 H5_DLL herr_t H5T__sort_value(const H5T_t *dt, int *map);
 H5_DLL herr_t H5T__sort_name(const H5T_t *dt, int *map);
 
