@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -603,7 +602,7 @@ static unsigned
 test_create(hid_t fapl, H5EA_create_t *cparam, earray_test_param_t H5_ATTR_UNUSED *tparam)
 {
     hid_t   file    = -1;          /* File ID */
-    H5F_t * f       = NULL;        /* Internal file object pointer */
+    H5F_t  *f       = NULL;        /* Internal file object pointer */
     H5EA_t *ea      = NULL;        /* Extensible array wrapper */
     haddr_t ea_addr = HADDR_UNDEF; /* Array address in file */
 
@@ -848,7 +847,7 @@ static unsigned
 test_reopen(hid_t fapl, H5EA_create_t *cparam, earray_test_param_t *tparam)
 {
     hid_t   file    = -1;          /* File ID */
-    H5F_t * f       = NULL;        /* Internal file object pointer */
+    H5F_t  *f       = NULL;        /* Internal file object pointer */
     H5EA_t *ea      = NULL;        /* Extensible array wrapper */
     haddr_t ea_addr = HADDR_UNDEF; /* Array address in file */
 
@@ -920,8 +919,8 @@ test_open_twice(hid_t fapl, H5EA_create_t *cparam, earray_test_param_t *tparam)
 {
     hid_t   file    = -1;          /* File ID */
     hid_t   file2   = -1;          /* File ID */
-    H5F_t * f       = NULL;        /* Internal file object pointer */
-    H5F_t * f2      = NULL;        /* Internal file object pointer */
+    H5F_t  *f       = NULL;        /* Internal file object pointer */
+    H5F_t  *f2      = NULL;        /* Internal file object pointer */
     H5EA_t *ea      = NULL;        /* Extensible array wrapper */
     H5EA_t *ea2     = NULL;        /* Extensible array wrapper */
     haddr_t ea_addr = HADDR_UNDEF; /* Array address in file */
@@ -1033,8 +1032,8 @@ test_open_twice_diff(hid_t fapl, H5EA_create_t *cparam, earray_test_param_t *tpa
     hid_t   file2   = -1;                      /* File ID */
     hid_t   file0   = -1;                      /* File ID */
     hid_t   file00  = -1;                      /* File ID */
-    H5F_t * f       = NULL;                    /* Internal file object pointer */
-    H5F_t * f2      = NULL;                    /* Internal file object pointer */
+    H5F_t  *f       = NULL;                    /* Internal file object pointer */
+    H5F_t  *f2      = NULL;                    /* Internal file object pointer */
     H5EA_t *ea      = NULL;                    /* Extensible array wrapper */
     H5EA_t *ea2     = NULL;                    /* Extensible array wrapper */
     haddr_t ea_addr = HADDR_UNDEF;             /* Array address in file */
@@ -1169,9 +1168,9 @@ static unsigned
 test_delete_open(hid_t fapl, H5EA_create_t *cparam, earray_test_param_t *tparam)
 {
     hid_t          file    = -1;          /* File ID */
-    H5F_t *        f       = NULL;        /* Internal file object pointer */
-    H5EA_t *       ea      = NULL;        /* Extensible array wrapper */
-    H5EA_t *       ea2     = NULL;        /* Extensible array wrapper */
+    H5F_t         *f       = NULL;        /* Internal file object pointer */
+    H5EA_t        *ea      = NULL;        /* Extensible array wrapper */
+    H5EA_t        *ea2     = NULL;        /* Extensible array wrapper */
     haddr_t        ea_addr = HADDR_UNDEF; /* Array address in file */
     h5_stat_size_t file_size;             /* File size, after deleting array */
 
@@ -1284,7 +1283,7 @@ typedef struct eiter_fw_t {
 /*-------------------------------------------------------------------------
  * Function:    eiter_fw_init
  *
- * Purpose:    Initialize element interator (forward iteration)
+ * Purpose:    Initialize element iterator (forward iteration)
  *
  * Return:    Success:    Pointer to iteration status object
  *        Failure:    NULL
@@ -1428,7 +1427,7 @@ eiter_fw_state(void *in_eiter, const H5EA_create_t *cparam, const earray_test_pa
 /*-------------------------------------------------------------------------
  * Function:    eiter_fw_term
  *
- * Purpose:    Shut down element interator (forward iteration)
+ * Purpose:    Shut down element iterator (forward iteration)
  *
  * Return:    Success:    0
  *        Failure:    -1
@@ -1472,7 +1471,7 @@ typedef struct eiter_rv_t {
 /*-------------------------------------------------------------------------
  * Function:    eiter_rv_init
  *
- * Purpose:    Initialize element interator (reverse iteration)
+ * Purpose:    Initialize element iterator (reverse iteration)
  *
  * Return:    Success:    Pointer to iteration status object
  *        Failure:    NULL
@@ -1653,7 +1652,7 @@ eiter_rv_state(void *in_eiter, const H5EA_create_t *cparam, const earray_test_pa
 /*-------------------------------------------------------------------------
  * Function:    eiter_rv_term
  *
- * Purpose:    Shut down element interator (reverse iteration)
+ * Purpose:    Shut down element iterator (reverse iteration)
  *
  * Return:    Success:    0
  *        Failure:    -1
@@ -1694,7 +1693,7 @@ typedef struct eiter_rnd_t {
 /*-------------------------------------------------------------------------
  * Function:    eiter_rnd_init
  *
- * Purpose:    Initialize element interator (random iteration)
+ * Purpose:    Initialize element iterator (random iteration)
  *
  * Return:    Success:    Pointer to iteration status object
  *        Failure:    NULL
@@ -1803,7 +1802,7 @@ eiter_rnd_max(const void *in_eiter)
 /*-------------------------------------------------------------------------
  * Function:    eiter_rnd_term
  *
- * Purpose:    Shut down element interator (random iteration)
+ * Purpose:    Shut down element iterator (random iteration)
  *
  * Return:    Success:    0
  *        Failure:    -1
@@ -1843,7 +1842,7 @@ static const earray_iter_t ea_iter_rnd = {
 /*-------------------------------------------------------------------------
  * Function:    eiter_rnd2_init
  *
- * Purpose:    Initialize element interator (random #2 iteration)
+ * Purpose:    Initialize element iterator (random #2 iteration)
  *
  * Return:    Success:    Pointer to iteration status object
  *        Failure:    NULL
@@ -1926,7 +1925,7 @@ typedef struct eiter_cyc_t {
 /*-------------------------------------------------------------------------
  * Function:    eiter_cyc_init
  *
- * Purpose:    Initialize element interator (cyclic iteration)
+ * Purpose:    Initialize element iterator (cyclic iteration)
  *
  * Return:    Success:    Pointer to iteration status object
  *        Failure:    NULL
@@ -2019,7 +2018,7 @@ eiter_cyc_max(const void *in_eiter)
 /*-------------------------------------------------------------------------
  * Function:    eiter_cyc_term
  *
- * Purpose:    Shut down element interator (cyclic iteration)
+ * Purpose:    Shut down element iterator (cyclic iteration)
  *
  * Return:    Success:    0
  *        Failure:    -1
@@ -2070,9 +2069,9 @@ test_set_elmts(hid_t fapl, H5EA_create_t *cparam, earray_test_param_t *tparam, h
                const char *test_str)
 {
     hid_t          file = -1;             /* File ID */
-    H5F_t *        f    = NULL;           /* Internal file object pointer */
-    H5EA_t *       ea   = NULL;           /* Extensible array wrapper */
-    void *         eiter_info;            /* Extensible array iterator info */
+    H5F_t         *f    = NULL;           /* Internal file object pointer */
+    H5EA_t        *ea   = NULL;           /* Extensible array wrapper */
+    void          *eiter_info;            /* Extensible array iterator info */
     earray_state_t state;                 /* State of extensible array */
     uint64_t       welmt;                 /* Element to write */
     uint64_t       relmt;                 /* Element to read */
@@ -2248,8 +2247,8 @@ test_skip_elmts(hid_t fapl, H5EA_create_t *cparam, earray_test_param_t *tparam,
                 const char *test_str)
 {
     hid_t          file = -1;             /* File ID */
-    H5F_t *        f    = NULL;           /* Internal file object pointer */
-    H5EA_t *       ea   = NULL;           /* Extensible array wrapper */
+    H5F_t         *f    = NULL;           /* Internal file object pointer */
+    H5EA_t        *ea   = NULL;           /* Extensible array wrapper */
     earray_state_t state;                 /* State of extensible array */
     uint64_t       welmt;                 /* Element to write */
     uint64_t       relmt;                 /* Element to read */
@@ -2543,15 +2542,16 @@ main(void)
                     /* Test first element in data block */
                     nelmts = (hsize_t)((hsize_t)1 + cparam.idx_blk_elmts + tparam.sblk_info[sblk].start_idx +
                                        (tparam.sblk_info[sblk].dblk_nelmts * dblk));
-                    HDsprintf(test_str, "setting first element of array's data block #%llu",
-                              (unsigned long long)ndblks);
+                    HDsnprintf(test_str, sizeof(test_str),
+                               "setting first element of array's data block #%llu",
+                               (unsigned long long)ndblks);
                     nerrors += test_set_elmts(fapl, &cparam, &tparam, nelmts, test_str);
 
                     /* Test all elements in data block */
                     nelmts = (hsize_t)(cparam.idx_blk_elmts + tparam.sblk_info[sblk].start_idx +
                                        (tparam.sblk_info[sblk].dblk_nelmts * (dblk + 1)));
-                    HDsprintf(test_str, "setting all elements of array's data block #%llu",
-                              (unsigned long long)ndblks);
+                    HDsnprintf(test_str, sizeof(test_str), "setting all elements of array's data block #%llu",
+                               (unsigned long long)ndblks);
                     nerrors += test_set_elmts(fapl, &cparam, &tparam, nelmts, test_str);
 
                     /* Increment data block being tested */
