@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -23,13 +22,12 @@
 #define SRC_DSET  "src_dset"
 
 static int
-test_encode_decode(hid_t orig_pl, H5F_libver_t low, H5F_libver_t high, hbool_t support_virtual)
+test_encode_decode(hid_t orig_pl, H5F_libver_t low, H5F_libver_t high)
 {
     hid_t  pl        = (-1); /* Decoded property list */
     hid_t  fapl      = -1;   /* File access property list */
-    void * temp_buf  = NULL; /* Pointer to encoding buffer */
+    void  *temp_buf  = NULL; /* Pointer to encoding buffer */
     size_t temp_size = 0;    /* Size of encoding buffer */
-    herr_t ret;              /* Return value */
 
     /* Create file access property list */
     if ((fapl = H5Pcreate(H5P_FILE_ACCESS)) < 0)
@@ -39,68 +37,58 @@ test_encode_decode(hid_t orig_pl, H5F_libver_t low, H5F_libver_t high, hbool_t s
     if (H5Pset_libver_bounds(fapl, low, high) < 0)
         TEST_ERROR
 
-    H5E_BEGIN_TRY
-    {
-        ret = H5Pencode2(orig_pl, NULL, &temp_size, fapl);
-    }
-    H5E_END_TRY;
+    if (H5Pencode2(orig_pl, NULL, &temp_size, fapl) < 0)
+        TEST_ERROR;
 
-    if (support_virtual && high < H5F_LIBVER_V110)
-        VERIFY(ret, FAIL, "H5Pencode2");
-    else {
+    /* Allocate the buffer for encoding */
+    if (NULL == (temp_buf = (void *)HDmalloc(temp_size)))
+        TEST_ERROR;
 
-        VERIFY(ret, SUCCEED, "H5Pencode2");
+    /* Encode the property list to the buffer */
+    if (H5Pencode2(orig_pl, temp_buf, &temp_size, fapl) < 0)
+        TEST_ERROR;
 
-        /* Allocate the buffer for encoding */
-        if (NULL == (temp_buf = (void *)HDmalloc(temp_size)))
-            TEST_ERROR
+    /* Decode the buffer */
+    if ((pl = H5Pdecode(temp_buf)) < 0)
+        STACK_ERROR;
 
-        /* Encode the property list to the buffer */
-        if (H5Pencode2(orig_pl, temp_buf, &temp_size, fapl) < 0)
-            TEST_ERROR
+    /* Check if the original and the decoded property lists are equal */
+    if (!H5Pequal(orig_pl, pl))
+        PUTS_ERROR("encoding-decoding cycle failed\n");
 
-        /* Decode the buffer */
-        if ((pl = H5Pdecode(temp_buf)) < 0)
-            STACK_ERROR
+    /* Close the decoded property list */
+    if ((H5Pclose(pl)) < 0)
+        TEST_ERROR;
 
-        /* Check if the original and the decoded property lists are equal */
-        if (!H5Pequal(orig_pl, pl))
-            PUTS_ERROR("encoding-decoding cycle failed\n")
-
-        /* Close the decoded property list */
-        if ((H5Pclose(pl)) < 0)
-            TEST_ERROR
-
-        /* Free the buffer */
-        if (temp_buf)
-            HDfree(temp_buf);
+    /* Free the buffer */
+    if (temp_buf)
+        HDfree(temp_buf);
 
 #ifndef H5_NO_DEPRECATED_SYMBOLS
-        /* Test H5Pencode1() */
+    /* Test H5Pencode1() */
 
-        /* first call to encode returns only the size of the buffer needed */
-        if (H5Pencode1(orig_pl, NULL, &temp_size) < 0)
-            STACK_ERROR
+    /* first call to encode returns only the size of the buffer needed */
+    if (H5Pencode1(orig_pl, NULL, &temp_size) < 0)
+        STACK_ERROR;
 
-        if (NULL == (temp_buf = (void *)HDmalloc(temp_size)))
-            TEST_ERROR
+    if (NULL == (temp_buf = (void *)HDmalloc(temp_size)))
+        TEST_ERROR;
 
-        if (H5Pencode1(orig_pl, temp_buf, &temp_size) < 0)
-            STACK_ERROR
+    if (H5Pencode1(orig_pl, temp_buf, &temp_size) < 0)
+        STACK_ERROR;
 
-        if ((pl = H5Pdecode(temp_buf)) < 0)
-            STACK_ERROR
+    if ((pl = H5Pdecode(temp_buf)) < 0)
+        STACK_ERROR;
 
-        if (!H5Pequal(orig_pl, pl))
-            PUTS_ERROR("encoding-decoding cycle failed\n")
+    if (!H5Pequal(orig_pl, pl))
+        PUTS_ERROR("encoding-decoding cycle failed\n");
 
-        if ((H5Pclose(pl)) < 0)
-            STACK_ERROR
+    if ((H5Pclose(pl)) < 0)
+        STACK_ERROR;
 
-        if (temp_buf)
-            HDfree(temp_buf);
+    if (temp_buf)
+        HDfree(temp_buf);
 #endif /* H5_NO_DEPRECATED_SYMBOLS */
-    }
 
     if ((H5Pclose(fapl)) < 0)
         TEST_ERROR
@@ -148,7 +136,7 @@ main(void)
     double       w0     = 0.5;
     unsigned     max_compact;
     unsigned     min_dense;
-    const char * c_to_f = "x+32";
+    const char  *c_to_f = "x+32";
     H5F_libver_t low, high; /* Low and high bounds */
 
     H5AC_cache_config_t my_cache_config = {H5AC__CURR_CACHE_CONFIG_VERSION,
@@ -199,8 +187,8 @@ main(void)
             /* Display testing info */
             low_string  = h5_get_version_string(low);
             high_string = h5_get_version_string(high);
-            HDsprintf(msg, "Testing ENCODE/DECODE with file version bounds: (%s, %s):", low_string,
-                      high_string);
+            HDsnprintf(msg, sizeof(msg),
+                       "Testing ENCODE/DECODE with file version bounds: (%s, %s):", low_string, high_string);
             HDputs(msg);
 
             if (VERBOSE_MED)
@@ -212,8 +200,8 @@ main(void)
                 FAIL_STACK_ERROR
 
             /* Test encoding & decoding default property list */
-            if (test_encode_decode(dcpl, low, high, FALSE) < 0)
-                FAIL_PUTS_ERROR("Default DCPL encoding/decoding failed\n")
+            if (test_encode_decode(dcpl, low, high) < 0)
+                FAIL_PUTS_ERROR("Default DCPL encoding/decoding failed\n");
 
             PASSED();
 
@@ -242,8 +230,8 @@ main(void)
                 FAIL_STACK_ERROR
 
             /* Test encoding & decoding property list */
-            if (test_encode_decode(dcpl, low, high, FALSE) < 0)
-                FAIL_PUTS_ERROR("DCPL encoding/decoding failed\n")
+            if (test_encode_decode(dcpl, low, high) < 0)
+                FAIL_PUTS_ERROR("DCPL encoding/decoding failed\n");
 
             /* release resource */
             if ((H5Pclose(dcpl)) < 0)
@@ -253,31 +241,38 @@ main(void)
 
             /******* ENCODE/DECODE DCPLS *****/
             TESTING("DCPL Encoding/Decoding for virtual layout");
-            if ((dcpl = H5Pcreate(H5P_DATASET_CREATE)) < 0)
-                FAIL_STACK_ERROR
+            if (high < H5F_LIBVER_V110)
+                HDprintf(" SKIPPED: virtual layout not supported yet\n");
 
-            /* Set virtual layout */
-            if (H5Pset_layout(dcpl, H5D_VIRTUAL) < 0)
-                TEST_ERROR
+            else {
+                if ((dcpl = H5Pcreate(H5P_DATASET_CREATE)) < 0)
+                    FAIL_STACK_ERROR;
 
-            /* Create source dataspace */
-            if ((srcspace = H5Screate_simple(1, dims, NULL)) < 0)
-                TEST_ERROR
+                /* Set virtual layout */
+                if (H5Pset_layout(dcpl, H5D_VIRTUAL) < 0)
+                    TEST_ERROR;
 
-            /* Create virtual dataspace */
-            if ((vspace = H5Screate_simple(1, dims, NULL)) < 0)
-                TEST_ERROR
+                /* Create source dataspace */
+                if ((srcspace = H5Screate_simple(1, dims, NULL)) < 0)
+                    TEST_ERROR;
 
-            /* Add virtual layout mapping */
-            if (H5Pset_virtual(dcpl, vspace, SRC_FNAME, SRC_DSET, srcspace) < 0)
-                TEST_ERROR
+                /* Create virtual dataspace */
+                if ((vspace = H5Screate_simple(1, dims, NULL)) < 0)
+                    TEST_ERROR;
 
-            if (test_encode_decode(dcpl, low, high, TRUE) < 0)
-                FAIL_PUTS_ERROR("DCPL encoding/decoding failed\n")
+                /* Add virtual layout mapping */
+                if (H5Pset_virtual(dcpl, vspace, SRC_FNAME, SRC_DSET, srcspace) < 0)
+                    TEST_ERROR;
 
-            /* release resource */
-            if ((H5Pclose(dcpl)) < 0)
-                FAIL_STACK_ERROR
+                if (test_encode_decode(dcpl, low, high) < 0)
+                    FAIL_PUTS_ERROR("DCPL encoding/decoding failed\n");
+
+                /* release resource */
+                if ((H5Pclose(dcpl)) < 0)
+                    FAIL_STACK_ERROR;
+
+                PASSED();
+            }
 
             /******* ENCODE/DECODE DAPLS *****/
             TESTING("Default DAPL Encoding/Decoding");
@@ -285,8 +280,8 @@ main(void)
                 FAIL_STACK_ERROR
 
             /* Test encoding & decoding default property list */
-            if (test_encode_decode(dapl, low, high, FALSE) < 0)
-                FAIL_PUTS_ERROR("Default DAPL encoding/decoding failed\n")
+            if (test_encode_decode(dapl, low, high) < 0)
+                FAIL_PUTS_ERROR("Default DAPL encoding/decoding failed\n");
 
             PASSED();
 
@@ -296,8 +291,8 @@ main(void)
                 FAIL_STACK_ERROR
 
             /* Test encoding & decoding property list */
-            if (test_encode_decode(dapl, low, high, FALSE) < 0)
-                FAIL_PUTS_ERROR("DAPL encoding/decoding failed\n")
+            if (test_encode_decode(dapl, low, high) < 0)
+                FAIL_PUTS_ERROR("DAPL encoding/decoding failed\n");
 
             /* release resource */
             if ((H5Pclose(dapl)) < 0)
@@ -311,8 +306,8 @@ main(void)
                 FAIL_STACK_ERROR
 
             /* Test encoding & decoding default property list */
-            if (test_encode_decode(ocpl, low, high, FALSE) < 0)
-                FAIL_PUTS_ERROR("Default OCPL encoding/decoding failed\n")
+            if (test_encode_decode(ocpl, low, high) < 0)
+                FAIL_PUTS_ERROR("Default OCPL encoding/decoding failed\n");
 
             PASSED();
 
@@ -328,8 +323,8 @@ main(void)
                 FAIL_STACK_ERROR
 
             /* Test encoding & decoding property list */
-            if (test_encode_decode(ocpl, low, high, FALSE) < 0)
-                FAIL_PUTS_ERROR("OCPL encoding/decoding failed\n")
+            if (test_encode_decode(ocpl, low, high) < 0)
+                FAIL_PUTS_ERROR("OCPL encoding/decoding failed\n");
 
             /* release resource */
             if ((H5Pclose(ocpl)) < 0)
@@ -343,14 +338,14 @@ main(void)
                 FAIL_STACK_ERROR
 
             /* Test encoding & decoding default property list */
-            if (test_encode_decode(dxpl, low, high, FALSE) < 0)
-                FAIL_PUTS_ERROR("Default DXPL encoding/decoding failed\n")
+            if (test_encode_decode(dxpl, low, high) < 0)
+                FAIL_PUTS_ERROR("Default DXPL encoding/decoding failed\n");
 
             PASSED();
 
             TESTING("DXPL Encoding/Decoding");
 
-            if ((H5Pset_btree_ratios(dxpl, 0.2f, 0.6f, 0.2f)) < 0)
+            if ((H5Pset_btree_ratios(dxpl, 0.2, 0.6, 0.2)) < 0)
                 FAIL_STACK_ERROR
             if ((H5Pset_hyper_vector_size(dxpl, 5)) < 0)
                 FAIL_STACK_ERROR
@@ -373,8 +368,8 @@ main(void)
                 FAIL_STACK_ERROR
 
             /* Test encoding & decoding property list */
-            if (test_encode_decode(dxpl, low, high, FALSE) < 0)
-                FAIL_PUTS_ERROR("DXPL encoding/decoding failed\n")
+            if (test_encode_decode(dxpl, low, high) < 0)
+                FAIL_PUTS_ERROR("DXPL encoding/decoding failed\n");
 
             /* release resource */
             if ((H5Pclose(dxpl)) < 0)
@@ -388,8 +383,8 @@ main(void)
                 FAIL_STACK_ERROR
 
             /* Test encoding & decoding default property list */
-            if (test_encode_decode(gcpl, low, high, FALSE) < 0)
-                FAIL_PUTS_ERROR("Default GCPL encoding/decoding failed\n")
+            if (test_encode_decode(gcpl, low, high) < 0)
+                FAIL_PUTS_ERROR("Default GCPL encoding/decoding failed\n");
 
             PASSED();
 
@@ -412,8 +407,8 @@ main(void)
                 FAIL_STACK_ERROR
 
             /* Test encoding & decoding property list */
-            if (test_encode_decode(gcpl, low, high, FALSE) < 0)
-                FAIL_PUTS_ERROR("GCPL encoding/decoding failed\n")
+            if (test_encode_decode(gcpl, low, high) < 0)
+                FAIL_PUTS_ERROR("GCPL encoding/decoding failed\n");
 
             /* release resource */
             if ((H5Pclose(gcpl)) < 0)
@@ -427,8 +422,8 @@ main(void)
                 FAIL_STACK_ERROR
 
             /* Test encoding & decoding default property list */
-            if (test_encode_decode(lcpl, low, high, FALSE) < 0)
-                FAIL_PUTS_ERROR("Default LCPL encoding/decoding failed\n")
+            if (test_encode_decode(lcpl, low, high) < 0)
+                FAIL_PUTS_ERROR("Default LCPL encoding/decoding failed\n");
 
             PASSED();
 
@@ -438,8 +433,8 @@ main(void)
                 FAIL_STACK_ERROR
 
             /* Test encoding & decoding property list */
-            if (test_encode_decode(lcpl, low, high, FALSE) < 0)
-                FAIL_PUTS_ERROR("LCPL encoding/decoding failed\n")
+            if (test_encode_decode(lcpl, low, high) < 0)
+                FAIL_PUTS_ERROR("LCPL encoding/decoding failed\n");
 
             /* release resource */
             if ((H5Pclose(lcpl)) < 0)
@@ -453,8 +448,8 @@ main(void)
                 FAIL_STACK_ERROR
 
             /* Test encoding & decoding default property list */
-            if (test_encode_decode(lapl, low, high, FALSE) < 0)
-                FAIL_PUTS_ERROR("Default LAPL encoding/decoding failed\n")
+            if (test_encode_decode(lapl, low, high) < 0)
+                FAIL_PUTS_ERROR("Default LAPL encoding/decoding failed\n");
 
             PASSED();
 
@@ -483,8 +478,8 @@ main(void)
                 FAIL_STACK_ERROR
 
             /* Test encoding & decoding property list */
-            if (test_encode_decode(lapl, low, high, FALSE) < 0)
-                FAIL_PUTS_ERROR("LAPL encoding/decoding failed\n")
+            if (test_encode_decode(lapl, low, high) < 0)
+                FAIL_PUTS_ERROR("LAPL encoding/decoding failed\n");
 
             /* release resource */
             if ((H5Pclose(lapl)) < 0)
@@ -498,8 +493,8 @@ main(void)
                 FAIL_STACK_ERROR
 
             /* Test encoding & decoding default property list */
-            if (test_encode_decode(ocpypl, low, high, FALSE) < 0)
-                FAIL_PUTS_ERROR("Default OCPYPL encoding/decoding failed\n")
+            if (test_encode_decode(ocpypl, low, high) < 0)
+                FAIL_PUTS_ERROR("Default OCPYPL encoding/decoding failed\n");
 
             PASSED();
 
@@ -514,8 +509,8 @@ main(void)
                 FAIL_STACK_ERROR
 
             /* Test encoding & decoding property list */
-            if (test_encode_decode(ocpypl, low, high, FALSE) < 0)
-                FAIL_PUTS_ERROR("OCPYPL encoding/decoding failed\n")
+            if (test_encode_decode(ocpypl, low, high) < 0)
+                FAIL_PUTS_ERROR("OCPYPL encoding/decoding failed\n");
 
             /* release resource */
             if ((H5Pclose(ocpypl)) < 0)
@@ -529,8 +524,8 @@ main(void)
                 FAIL_STACK_ERROR
 
             /* Test encoding & decoding default property list */
-            if (test_encode_decode(fapl, low, high, FALSE) < 0)
-                FAIL_PUTS_ERROR("Default FAPL encoding/decoding failed\n")
+            if (test_encode_decode(fapl, low, high) < 0)
+                FAIL_PUTS_ERROR("Default FAPL encoding/decoding failed\n");
 
             PASSED();
 
@@ -544,7 +539,7 @@ main(void)
                 FAIL_STACK_ERROR
             if ((H5Pset_alignment(fapl, 2, 1024)) < 0)
                 FAIL_STACK_ERROR
-            if ((H5Pset_cache(fapl, 1024, 128, 10485760, 0.3f)) < 0)
+            if ((H5Pset_cache(fapl, 1024, 128, 10485760, 0.3)) < 0)
                 FAIL_STACK_ERROR
             if ((H5Pset_elink_file_cache_size(fapl, 10485760)) < 0)
                 FAIL_STACK_ERROR
@@ -564,8 +559,8 @@ main(void)
                 FAIL_STACK_ERROR
 
             /* Test encoding & decoding property list */
-            if (test_encode_decode(fapl, low, high, FALSE) < 0)
-                FAIL_PUTS_ERROR("FAPL encoding/decoding failed\n")
+            if (test_encode_decode(fapl, low, high) < 0)
+                FAIL_PUTS_ERROR("FAPL encoding/decoding failed\n");
 
             /* release resource */
             if ((H5Pclose(fapl)) < 0)
@@ -580,8 +575,8 @@ main(void)
                 FAIL_STACK_ERROR
 
             /* Test encoding & decoding default property list */
-            if (test_encode_decode(fcpl, low, high, FALSE) < 0)
-                FAIL_PUTS_ERROR("Default FCPL encoding/decoding failed\n")
+            if (test_encode_decode(fcpl, low, high) < 0)
+                FAIL_PUTS_ERROR("Default FCPL encoding/decoding failed\n");
 
             PASSED();
 
@@ -609,8 +604,8 @@ main(void)
                 FAIL_STACK_ERROR
 
             /* Test encoding & decoding property list */
-            if (test_encode_decode(fcpl, low, high, FALSE) < 0)
-                FAIL_PUTS_ERROR("FCPL encoding/decoding failed\n")
+            if (test_encode_decode(fcpl, low, high) < 0)
+                FAIL_PUTS_ERROR("FCPL encoding/decoding failed\n");
 
             /* release resource */
             if ((H5Pclose(fcpl)) < 0)
@@ -625,8 +620,8 @@ main(void)
                 FAIL_STACK_ERROR
 
             /* Test encoding & decoding default property list */
-            if (test_encode_decode(strcpl, low, high, FALSE) < 0)
-                FAIL_PUTS_ERROR("Default STRCPL encoding/decoding failed\n")
+            if (test_encode_decode(strcpl, low, high) < 0)
+                FAIL_PUTS_ERROR("Default STRCPL encoding/decoding failed\n");
 
             PASSED();
 
@@ -636,8 +631,8 @@ main(void)
                 FAIL_STACK_ERROR
 
             /* Test encoding & decoding property list */
-            if (test_encode_decode(strcpl, low, high, FALSE) < 0)
-                FAIL_PUTS_ERROR("STRCPL encoding/decoding failed\n")
+            if (test_encode_decode(strcpl, low, high) < 0)
+                FAIL_PUTS_ERROR("STRCPL encoding/decoding failed\n");
 
             /* release resource */
             if ((H5Pclose(strcpl)) < 0)
@@ -652,8 +647,8 @@ main(void)
                 FAIL_STACK_ERROR
 
             /* Test encoding & decoding default property list */
-            if (test_encode_decode(acpl, low, high, FALSE) < 0)
-                FAIL_PUTS_ERROR("Default ACPL encoding/decoding failed\n")
+            if (test_encode_decode(acpl, low, high) < 0)
+                FAIL_PUTS_ERROR("Default ACPL encoding/decoding failed\n");
 
             PASSED();
 
@@ -663,8 +658,8 @@ main(void)
                 FAIL_STACK_ERROR
 
             /* Test encoding & decoding property list */
-            if (test_encode_decode(acpl, low, high, FALSE) < 0)
-                FAIL_PUTS_ERROR("ACPL encoding/decoding failed\n")
+            if (test_encode_decode(acpl, low, high) < 0)
+                FAIL_PUTS_ERROR("ACPL encoding/decoding failed\n");
 
             /* release resource */
             if ((H5Pclose(acpl)) < 0)
