@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -69,7 +68,7 @@ static int
 test_1(hid_t fapl)
 {
     hid_t   file = H5I_INVALID_HID;
-    H5F_t * f    = NULL;
+    H5F_t  *f    = NULL;
     H5HG_t *obj  = NULL;
     uint8_t out[GHEAP_TEST_NOBJS];
     uint8_t in[GHEAP_TEST_NOBJS];
@@ -178,7 +177,7 @@ static int
 test_2(hid_t fapl)
 {
     hid_t   file = H5I_INVALID_HID;
-    H5F_t * f    = NULL;
+    H5F_t  *f    = NULL;
     H5HG_t *obj  = NULL;
     uint8_t out[GHEAP_TEST_NOBJS];
     uint8_t in[GHEAP_TEST_NOBJS];
@@ -278,7 +277,7 @@ static int
 test_3(hid_t fapl)
 {
     hid_t   file = H5I_INVALID_HID;
-    H5F_t * f    = NULL;
+    H5F_t  *f    = NULL;
     H5HG_t *obj  = NULL;
     uint8_t out[GHEAP_TEST_NOBJS];
     size_t  u;
@@ -353,7 +352,7 @@ error:
  * Function:    test_4
  *
  * Purpose:     Tests the H5HG_remove() feature by writing lots of objects
- *              and occassionally removing some.  When we're done they're all
+ *              and occasionally removing some.  When we're done they're all
  *              removed.
  *
  * Return:      Success:    0
@@ -369,7 +368,7 @@ static int
 test_4(hid_t fapl)
 {
     hid_t   file = H5I_INVALID_HID;
-    H5F_t * f    = NULL;
+    H5F_t  *f    = NULL;
     H5HG_t *obj  = NULL;
     uint8_t out[GHEAP_TEST_NOBJS];
     size_t  u;
@@ -466,9 +465,9 @@ static int
 test_ooo_indices(hid_t fapl)
 {
     hid_t    file = H5I_INVALID_HID;
-    H5F_t *  f    = NULL;
+    H5F_t   *f    = NULL;
     unsigned i, j;
-    H5HG_t * obj = NULL;
+    H5HG_t  *obj = NULL;
     herr_t   status;
     int      nerrors = 0;
     char     filename[1024];
@@ -503,7 +502,7 @@ test_ooo_indices(hid_t fapl)
                 GHEAP_REPEATED_ERR("    Unable to insert object into global heap")
 
             /* Check that the index is as expected */
-            if (obj[j].idx != ((1000 * i) + j - (1000 * ((~i & 1)))) % ((1u << 16) - 1) + 1)
+            if (obj[j].idx != ((1000 * i) + j - (1000 * ((~i & 1)))) % ((1U << 16) - 1) + 1)
                 GHEAP_REPEATED_ERR("    Unexpected global heap index");
         }
 
