@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -26,10 +25,6 @@ const char *FILENAME[] = {"ntypes", NULL};
 #define DIM1 200
 #define DIM3 20
 
-int   ipoints2[DIM0][DIM1], icheck2[DIM0][DIM1];
-short spoints2[DIM0][DIM1], scheck2[DIM0][DIM1];
-int   ipoints3[DIM0][DIM1][5], icheck3[DIM0][DIM1][5];
-
 #define DSET_ATOMIC_NAME_1   "atomic_type_1"
 #define DSET_ATOMIC_NAME_2   "atomic_type_2"
 #define DSET_ATOMIC_NAME_3   "atomic_type_3"
@@ -79,14 +74,25 @@ test_atomic_dtype(hid_t file)
     hid_t   dtype = -1, native_type = -1;
     int     i, j, n;
     hsize_t dims[2];
-    void *  tmp = NULL;
+    void   *tmp = NULL;
+    struct {
+        int arr[DIM0][DIM1];
+    } *ipoints2 = NULL;
+    struct {
+        int arr[DIM0][DIM1];
+    } *icheck2 = NULL;
 
     TESTING("atomic datatype");
 
+    if (NULL == (ipoints2 = HDcalloc(1, sizeof(*ipoints2))))
+        TEST_ERROR;
+    if (NULL == (icheck2 = HDcalloc(1, sizeof(*icheck2))))
+        TEST_ERROR;
+
     /* Initialize the dataset */
     for (i = n = 0; i < DIM0; i++)
         for (j = 0; j < DIM1; j++)
-            ipoints2[i][j] = n++;
+            ipoints2->arr[i][j] = n++;
 
     /* Create the data space */
     dims[0] = DIM0;
@@ -146,7 +152,7 @@ test_atomic_dtype(hid_t file)
     /* Check that the values read are the same as the values written */
     for (i = 0; i < DIM0; i++)
         for (j = 0; j < DIM1; j++)
-            if (ipoints2[i][j] != icheck2[i][j]) {
+            if (ipoints2->arr[i][j] != icheck2->arr[i][j]) {
                 H5_FAILED();
                 HDprintf("    Read different values than written.\n");
                 HDprintf("    At index %d,%d\n", i, j);
@@ -270,6 +276,9 @@ test_atomic_dtype(hid_t file)
     if (H5Sclose(space) < 0)
         TEST_ERROR;
 
+    HDfree(ipoints2);
+    HDfree(icheck2);
+
     PASSED();
 
     return 0;
@@ -287,6 +296,9 @@ error:
     }
     H5E_END_TRY;
 
+    HDfree(ipoints2);
+    HDfree(icheck2);
+
     return -1;
 }
 
@@ -325,9 +337,9 @@ test_compound_dtype2(hid_t file)
           nest_mem_id = -1;
     int     i, j, n;
     hsize_t dims[2];
-    s1 *    temp_point = NULL, *temp_check = NULL;
-    s1 *    points = NULL, *check = NULL;
-    void *  tmp = NULL, *bkg = NULL;
+    s1     *temp_point = NULL, *temp_check = NULL;
+    s1     *points = NULL, *check = NULL;
+    void   *tmp = NULL, *bkg = NULL;
 
     TESTING("nested compound datatype");
 
@@ -648,12 +660,12 @@ test_compound_dtype(hid_t file)
     hid_t   dtype = -1, native_type = -1, tid = -1, tid2 = -1, mem_id = -1;
     int     i, j, n;
     hsize_t dims[2];
-    s1 *    temp_point = NULL;
-    s1 *    temp_check = NULL;
-    s1 *    points     = NULL;
-    s1 *    check      = NULL;
-    void *  tmp        = NULL;
-    void *  bkg        = NULL;
+    s1     *temp_point = NULL;
+    s1     *temp_check = NULL;
+    s1     *points     = NULL;
+    s1     *check      = NULL;
+    void   *tmp        = NULL;
+    void   *bkg        = NULL;
 
     TESTING("compound datatype");
 
@@ -863,9 +875,9 @@ test_compound_dtype3(hid_t file)
     hsize_t array_dims[1] = {5};
     int     i, j, k, n;
     hsize_t dims[2];
-    s1 *    temp_point = NULL, *temp_check = NULL;
-    s1 *    points = NULL, *check = NULL;
-    void *  tmp = NULL, *bkg = NULL;
+    s1     *temp_point = NULL, *temp_check = NULL;
+    s1     *points = NULL, *check = NULL;
+    void   *tmp = NULL, *bkg = NULL;
 
     TESTING("compound datatype with array as field");
 
@@ -1102,9 +1114,9 @@ test_compound_opaque(hid_t file)
     hid_t   dtype = -1, native_type = -1, tid = -1, tid2 = -1, tid_m = -1, mem_id = -1;
     int     i, j, k, n;
     hsize_t dims[2];
-    s1 *    temp_point = NULL, *temp_check = NULL;
-    s1 *    points = NULL, *check = NULL;
-    void *  tmp = NULL, *bkg = NULL;
+    s1     *temp_point = NULL, *temp_check = NULL;
+    s1     *points = NULL, *check = NULL;
+    void   *tmp = NULL, *bkg = NULL;
 
     TESTING("compound datatype with opaque field");
 
@@ -1324,17 +1336,28 @@ test_enum_dtype(hid_t file)
     hid_t         tid = -1, tid_m = -1, dtype = -1, native_type = -1;
     int           i, j, n;
     hsize_t       dims[2];
-    void *        tmp = NULL;
+    void         *tmp = NULL;
     short         colors[8];
     unsigned char sub_colors[16];
-    const char *  mname[] = {"RED", "GREEN", "BLUE", "YELLOW", "PINK", "PURPLE", "ORANGE", "WHITE"};
+    const char   *mname[] = {"RED", "GREEN", "BLUE", "YELLOW", "PINK", "PURPLE", "ORANGE", "WHITE"};
+    struct {
+        short arr[DIM0][DIM1];
+    } *spoints2 = NULL;
+    struct {
+        short arr[DIM0][DIM1];
+    } *scheck2 = NULL;
 
     TESTING("enum datatype");
 
+    if (NULL == (spoints2 = HDcalloc(1, sizeof(*spoints2))))
+        TEST_ERROR;
+    if (NULL == (scheck2 = HDcalloc(1, sizeof(*scheck2))))
+        TEST_ERROR;
+
     /* Initialize the dataset */
     for (i = 0; i < DIM0; i++)
         for (j = 0, n = 0; j < DIM1; j++, n++)
-            spoints2[i][j] = (short)((i * 10 + j * 100 + n) % 8);
+            spoints2->arr[i][j] = (short)((i * 10 + j * 100 + n) % 8);
 
     /* Create the data space */
     dims[0] = DIM0;
@@ -1402,8 +1425,6 @@ test_enum_dtype(hid_t file)
         TEST_ERROR;
 
     HDmemcpy(scheck2, tmp, DIM0 * DIM1 * H5Tget_size(native_type));
-    HDfree(tmp);
-    tmp = NULL;
 
     if (H5Tconvert(native_type, tid_m, (DIM0 * DIM1), scheck2, NULL, H5P_DEFAULT) < 0)
         TEST_ERROR;
@@ -1411,11 +1432,11 @@ test_enum_dtype(hid_t file)
     /* Check that the values read are the same as the values written */
     for (i = 0; i < DIM0; i++)
         for (j = 0; j < DIM1; j++)
-            if (spoints2[i][j] != scheck2[i][j]) {
+            if (spoints2->arr[i][j] != scheck2->arr[i][j]) {
                 H5_FAILED();
                 HDprintf("    Read different values than written.\n");
                 HDprintf("    At index %d,%d\n", i, j);
-                HDprintf(" spoints2[i][j]=%hd, scheck2[i][j]=%hd\n", spoints2[i][j], scheck2[i][j]);
+                HDprintf(" spoints2[i][j]=%hd, scheck2[i][j]=%hd\n", spoints2->arr[i][j], scheck2->arr[i][j]);
                 goto error;
             } /* end if */
 
@@ -1423,13 +1444,19 @@ test_enum_dtype(hid_t file)
     H5Tclose(dtype);
     H5Tclose(native_type);
     H5Tclose(tid_m);
+
+    HDfree(tmp);
+    HDfree(spoints2);
+    HDfree(scheck2);
+
     PASSED();
     return 0;
 
 error:
     /* Free memory for test data */
-    if (tmp)
-        HDfree(tmp);
+    HDfree(tmp);
+    HDfree(spoints2);
+    HDfree(scheck2);
 
     H5E_BEGIN_TRY
     {
@@ -1473,9 +1500,9 @@ test_array_dtype(hid_t file)
     hid_t   dtype = -1, native_type = -1, tid = -1, tid2 = -1, tid3 = -1, tid_m = -1;
     int     i, j, k, n;
     hsize_t space_dims[2], array_dims[1] = {5};
-    s1 *    temp_point = NULL, *temp_check = NULL;
-    s1 *    points = NULL, *check = NULL;
-    void *  tmp = NULL;
+    s1     *temp_point = NULL, *temp_check = NULL;
+    s1     *points = NULL, *check = NULL;
+    void   *tmp = NULL;
 
     TESTING("array of compound datatype");
 
@@ -1656,15 +1683,26 @@ test_array_dtype2(hid_t file)
     hid_t   dtype = -1, native_type = -1, tid = -1, tid_m = -1;
     int     i, j, k, n;
     hsize_t space_dims[2], array_dims[1] = {5};
-    void *  tmp = NULL;
+    void   *tmp = NULL;
+    struct {
+        int arr[DIM0][DIM1][5];
+    } *ipoints3 = NULL;
+    struct {
+        int arr[DIM0][DIM1][5];
+    } *icheck3 = NULL;
 
     TESTING("array of atomic datatype");
 
+    if (NULL == (ipoints3 = HDcalloc(1, sizeof(*ipoints3))))
+        goto error;
+    if (NULL == (icheck3 = HDcalloc(1, sizeof(*icheck3))))
+        goto error;
+
     /* Initialize the dataset */
     for (i = n = 0; i < DIM0; i++)
         for (j = 0; j < DIM1; j++)
             for (k = 0; k < 5; k++)
-                ipoints3[i][j][k] = n++;
+                ipoints3->arr[i][j][k] = n++;
 
     /* Create the data space */
     space_dims[0] = DIM0;
@@ -1729,7 +1767,7 @@ test_array_dtype2(hid_t file)
     for (i = 0; i < DIM0; i++)
         for (j = 0; j < DIM1; j++)
             for (k = 0; k < 5; k++)
-                if (icheck3[i][j][k] != ipoints3[i][j][k]) {
+                if (icheck3->arr[i][j][k] != ipoints3->arr[i][j][k]) {
                     H5_FAILED();
                     HDprintf("    Read different values than written.\n");
                     HDprintf("    At index %d,%d\n", i, j);
@@ -1746,6 +1784,9 @@ test_array_dtype2(hid_t file)
     if (H5Tclose(tid_m) < 0)
         TEST_ERROR;
 
+    HDfree(ipoints3);
+    HDfree(icheck3);
+
     PASSED();
     return 0;
 
@@ -1765,6 +1806,9 @@ error:
     }
     H5E_END_TRY;
 
+    HDfree(ipoints3);
+    HDfree(icheck3);
+
     return -1;
 }
 
@@ -1789,12 +1833,12 @@ test_vl_dtype(hid_t file)
 {
     hvl_t   wdata[SPACE1_DIM1]; /* Information to write */
     hvl_t   rdata[SPACE1_DIM1]; /* Information read in */
-    hvl_t * t1, *t2;            /* Temporary pointer to VL information */
+    hvl_t  *t1, *t2;            /* Temporary pointer to VL information */
     hsize_t dims1[] = {SPACE1_DIM1};
     hid_t   dataset = -1, space = -1;
     hid_t   dtype = -1, native_type = -1, nat_super_type = -1, tid = -1, tid2 = -1, tid_m = -1, tid_m2 = -1;
     size_t  i, j, k;
-    void ** tmp = NULL;
+    void  **tmp = NULL;
 
     TESTING("variable length datatype");
 
@@ -1999,7 +2043,7 @@ test_vlstr_dtype(hid_t file)
         "conceived in liberty and dedicated to the proposition that all men are created equal.",
         "Now we are engaged in a great civil war,",
         "testing whether that nation or any nation so conceived and so dedicated can long endure."};
-    char *   rdata[SPACE1_DIM1];                      /* Information read in */
+    char    *rdata[SPACE1_DIM1];                      /* Information read in */
     hbool_t  rdata_alloc = FALSE;                     /* Whether the read data is allocated */
     hid_t    dataset     = -1;                        /* Dataset ID            */
     hid_t    sid1        = -1;                        /* Dataspace ID            */
@@ -2442,7 +2486,7 @@ test_refer_dtype2(hid_t file)
         rbuf;                            /* buffer read from disk */
     uint8_t *dwbuf = NULL,               /* Buffer for writing numeric data to disk */
         *drbuf     = NULL;               /* Buffer for reading numeric data from disk */
-    uint8_t *  tu8 = NULL;               /* Temporary pointer to uint8 data */
+    uint8_t   *tu8 = NULL;               /* Temporary pointer to uint8 data */
     H5O_type_t obj_type;                 /* Object type */
     int        i;                        /* counting variables */
 
@@ -2749,7 +2793,7 @@ test_bitfield_dtype(hid_t file)
     size_t         ntype_size, i;
     unsigned char  wbuf[BITFIELD_ENUMB * sizeof(int)];
     unsigned char *p    = NULL;
-    void *         rbuf = NULL;
+    void          *rbuf = NULL;
     unsigned int   intw[BITFIELD_ENUMB], intr[BITFIELD_ENUMB];
     hsize_t        nelmts;
 
