@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -479,7 +478,7 @@ error:
 int
 main(void)
 {
-    /* This test is currently not working properly; it should be revisted
+    /* This test is currently not working properly; it should be revisited
      * when we have time.
      *
      * (Also, we should try to make this test work with all the VFDs)
@@ -509,8 +508,7 @@ main(void)
         return num_errs;
     }
     else {
-        HDputs(
-            "All address space reservation tests skippped - Incompatible with current Virtual File Driver");
+        HDputs("All address space reservation tests skipped - Incompatible with current Virtual File Driver");
     }
 #endif /* BROKEN */
 
