@@ -56,7 +56,7 @@
  *     4) Configurable expected-actual order in generated comparison strings.
  *        Some prefer `VERIFY(expected, actual)`, others
  *        `VERIFY(actual, expected)`. Provide preprocessor ifdef switch
- *        to satifsy both parties, assuming one paradigm per test file.
+ *        to satisfy both parties, assuming one paradigm per test file.
  *        (One could #undef and redefine the flag through the file as desired,
  *         but _why_.)
  *
@@ -442,7 +442,7 @@ test_fapl_config_validation(void)
      *************************/
 
     struct testcase {
-        const char *     msg;
+        const char      *msg;
         herr_t           expected;
         H5FD_ros3_fapl_t config;
     };
@@ -830,7 +830,7 @@ test_vfd_open(void)
             0,
         },
     };
-    H5FD_t * fd               = NULL;
+    H5FD_t  *fd               = NULL;
     hbool_t  curl_ready       = FALSE;
     hid_t    fapl_id          = -1;
     hid_t    fapl_file_access = -1;
@@ -1088,7 +1088,7 @@ test_H5FDread_without_eoa_set_fails(void)
 {
     char         buffer[256];
     unsigned int i                = 0;
-    H5FD_t *     file_shakespeare = NULL;
+    H5FD_t      *file_shakespeare = NULL;
     hid_t        fapl_id          = -1;
 
     TESTING("ROS3 VFD read-eoa temporal coupling library limitation ");
@@ -1262,7 +1262,7 @@ test_read(void)
     herr_t          open_return = FAIL;
     char            buffer[S3_TEST_MAX_URL_SIZE];
     unsigned int    i          = 0;
-    H5FD_t *        file_raven = NULL;
+    H5FD_t         *file_raven = NULL;
     hid_t           fapl_id    = -1;
 
     TESTING("ROS3 VFD read/range-gets");
@@ -1406,7 +1406,7 @@ test_noops_and_autofails(void)
 
     hbool_t    curl_ready = FALSE;
     hid_t      fapl_id    = -1;
-    H5FD_t *   file       = NULL;
+    H5FD_t    *file       = NULL;
     const char data[36]   = "The Force shall be with you, always";
 
     TESTING("ROS3 VFD always-fail and no-op routines");
@@ -1456,7 +1456,7 @@ test_noops_and_autofails(void)
     JSVERIFY(SUCCEED, H5FDlock(file, FALSE), NULL)
     JSVERIFY(SUCCEED, H5FDunlock(file), NULL)
     /* Lock/unlock with null file or similar error crashes tests.
-     * HDassert in calling heirarchy, `H5FD[un]lock()` and `H5FD_[un]lock()`
+     * HDassert in calling hierarchy, `H5FD[un]lock()` and `H5FD_[un]lock()`
      */
 
     /************
@@ -1772,7 +1772,7 @@ main(void)
 
     bucket_url_env = HDgetenv("HDF5_ROS3_TEST_BUCKET_URL");
     if (bucket_url_env == NULL || bucket_url_env[0] == '\0') {
-        HDprintf("WARNING: S3 bucket url is not defined in enviornment "
+        HDprintf("WARNING: S3 bucket url is not defined in environment "
                  "variable 'HDF5_ROS3_TEST_BUCKET_URL'!\n");
     }
     else {
