@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -36,7 +35,7 @@ typedef struct {
  */
 /* linked list to keep exclude path list */
 struct exclude_path_list {
-    const char *              obj_path;
+    const char               *obj_path;
     h5trav_type_t             obj_type;
     struct exclude_path_list *next;
 };
@@ -52,29 +51,30 @@ typedef struct {
     int                       mode_quiet;   /* quiet mode: no output at all */
     int                       mode_report;  /* report mode: print the data */
     int                       mode_verbose; /* verbose mode: print the data, list of objcets, warnings */
-    int                       mode_verbose_level; /* control verbose details */
-    int                       mode_list_not_cmp;  /* list not comparable messages */
-    int                       print_header;       /* print header */
-    int                       print_percentage;   /* print percentage */
-    int                       print_dims;         /* print dimension index */
-    int                       delta_bool;         /* delta, absolute value to compare */
-    double                    delta;              /* delta value */
-    int                       use_system_epsilon; /* flag to use system epsilon (1 or 0) */
-    int                       percent_bool;       /* relative error to compare*/
-    double                    percent;            /* relative error value */
-    hbool_t                   follow_links;       /* follow symbolic links */
-    int                       no_dangle_links;    /* return error when find dangling link */
-    int                       cmn_objs;           /* do we have common objects */
-    int                       not_cmp;            /* are the objects comparable */
-    int                       contents;           /* equal contents */
-    int                       do_nans;            /* consider Nans while diffing floats */
-    int                       exclude_path;       /* exclude path to an object */
-    int                       exclude_attr_path;  /* exclude path to an object */
-    struct exclude_path_list *exclude;            /* keep exclude path list */
-    struct exclude_path_list *exclude_attr;       /* keep exclude attribute list */
-    int                       count_bool;         /* count, compare up to count */
-    hsize_t                   count;              /* count value */
-    diff_err_t                err_stat;  /* an error ocurred (2, error, 1, differences, 0, no error) */
+    int                       mode_verbose_level;     /* control verbose details */
+    int                       mode_list_not_cmp;      /* list not comparable messages */
+    int                       print_header;           /* print header */
+    int                       print_percentage;       /* print percentage */
+    int                       print_dims;             /* print dimension index */
+    int                       delta_bool;             /* delta, absolute value to compare */
+    double                    delta;                  /* delta value */
+    int                       use_system_epsilon;     /* flag to use system epsilon (1 or 0) */
+    int                       percent_bool;           /* relative error to compare*/
+    double                    percent;                /* relative error value */
+    hbool_t                   follow_links;           /* follow symbolic links */
+    int                       no_dangle_links;        /* return error when find dangling link */
+    int                       cmn_objs;               /* do we have common objects */
+    int                       not_cmp;                /* are the objects comparable */
+    int                       contents;               /* equal contents */
+    int                       do_nans;                /* consider Nans while diffing floats */
+    int                       disable_compact_subset; /* disable compact form of subset notation */
+    int                       exclude_path;           /* exclude path to an object */
+    int                       exclude_attr_path;      /* exclude path to an object */
+    struct exclude_path_list *exclude;                /* keep exclude path list */
+    struct exclude_path_list *exclude_attr;           /* keep exclude attribute list */
+    int                       count_bool;             /* count, compare up to count */
+    hsize_t                   count;                  /* count value */
+    diff_err_t                err_stat;  /* an error occurred (2, error, 1, differences, 0, no error) */
     hsize_t                   nelmts;    /* total number of elements */
     hsize_t                   hs_nelmts; /* number of elements to read at a time*/
     int                       rank;      /* dimensionality */
@@ -86,8 +86,8 @@ typedef struct {
     hsize_t                   acc[H5S_MAX_RANK];       /* accumulator position */
     hsize_t                   pos[H5S_MAX_RANK];       /* matrix position */
     hsize_t                   sm_pos[H5S_MAX_RANK];    /* stripmine position */
-    char *                    obj_name[2];             /* name for object */
-    struct subset_t *         sset[2];                 /* subsetting parameters */
+    char                     *obj_name[2];             /* name for object */
+    struct subset_t          *sset[2];                 /* subsetting parameters */
     h5tools_vol_info_t        vol_info[2];             /* VOL information for input file, output file */
     hbool_t                   custom_vol[2];           /* Using a custom input, output VOL? */
 } diff_opt_t;
