@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -30,8 +29,8 @@ int H5tools_INDENT_g = 0;
 /* global variables */
 H5E_auto2_t lib_func;
 H5E_auto2_t tools_func;
-void *      lib_edata;
-void *      tools_edata;
+void       *lib_edata;
+void       *tools_edata;
 
 hid_t H5tools_ERR_STACK_g     = H5I_INVALID_HID;
 hid_t H5tools_ERR_CLS_g       = H5I_INVALID_HID;
@@ -590,7 +589,7 @@ h5tools_set_fapl_vol(hid_t fapl_id, h5tools_vol_info_t *vol_info)
 {
     htri_t connector_is_registered;
     hid_t  connector_id   = H5I_INVALID_HID;
-    void * connector_info = NULL;
+    void  *connector_info = NULL;
     herr_t ret_value      = SUCCEED;
 
     switch (vol_info->type) {
@@ -903,7 +902,7 @@ h5tools_fopen(const char *fname, unsigned flags, hid_t fapl_id, hbool_t use_spec
      * as TRUE, we should return failure now since the file couldn't be opened with
      * the VFL driver/VOL connector that was set on the FAPL by the caller.
      */
-    if (fid < 0 && use_specific_driver)
+    if (use_specific_driver)
         H5TOOLS_GOTO_ERROR(H5I_INVALID_HID, "failed to open file using specified FAPL");
 
     /*
@@ -1005,7 +1004,7 @@ done:
 H5_ATTR_PURE static size_t
 h5tools_count_ncols(const char *s)
 {
-    register size_t i;
+    size_t i;
 
     for (i = 0; *s; s++)
         if (*s >= ' ')
@@ -1315,8 +1314,8 @@ h5tools_render_element(FILE *stream, const h5tool_format_t *info, h5tools_contex
                        hsize_t elmt_counter)
 {
     hbool_t dimension_break = TRUE;
-    char *  s               = NULL;
-    char *  section         = NULL; /* a section of output */
+    char   *s               = NULL;
+    char   *section         = NULL; /* a section of output */
     int     secnum;                 /* section sequence number */
     int     multiline;              /* datum was multiline */
 
@@ -1480,8 +1479,8 @@ h5tools_render_region_element(FILE *stream, const h5tool_format_t *info, h5tools
                               hsize_t local_elmt_counter, hsize_t elmt_counter)
 {
     hbool_t dimension_break = TRUE;
-    char *  s               = NULL;
-    char *  section         = NULL; /* a section of output */
+    char   *s               = NULL;
+    char   *section         = NULL; /* a section of output */
     int     secnum;                 /* section sequence number */
     int     multiline;              /* datum was multiline */
 
@@ -1724,7 +1723,7 @@ render_bin_output(FILE *stream, hid_t container, hid_t tid, void *_mem, hsize_t
         case H5T_STRING: {
             unsigned int  i;
             H5T_str_t     pad;
-            char *        s = NULL;
+            char         *s = NULL;
             unsigned char tempuchar;
 
             H5TOOLS_DEBUG("H5T_STRING");
@@ -1843,15 +1842,21 @@ render_bin_output(FILE *stream, hid_t container, hid_t tid, void *_mem, hsize_t
                     hid_t        region_id    = H5I_INVALID_HID;
                     hid_t        region_space = H5I_INVALID_HID;
                     H5S_sel_type region_type;
+                    H5R_ref_t    tref;
+
+                    if (size > sizeof(tref))
+                        H5TOOLS_THROW((-1), "unexpectedly large ref");
+
+                    HDmemset(&tref, 0, sizeof(tref));
 
                     for (block_index = 0; block_index < block_nelmts; block_index++) {
                         mem = ((unsigned char *)_mem) + block_index * size;
-                        if ((region_id = H5Ropen_object((H5R_ref_t *)mem, H5P_DEFAULT, H5P_DEFAULT)) < 0)
+                        HDmemcpy(&tref, mem, size);
+                        if ((region_id = H5Ropen_object(&tref, H5P_DEFAULT, H5P_DEFAULT)) < 0)
                             H5TOOLS_INFO("H5Ropen_object H5T_STD_REF failed");
                         else {
-                            if ((region_space = H5Ropen_region((H5R_ref_t *)mem, H5P_DEFAULT, H5P_DEFAULT)) >=
-                                0) {
-                                if (!h5tools_is_zero(mem, H5Tget_size(H5T_STD_REF))) {
+                            if ((region_space = H5Ropen_region(&tref, H5P_DEFAULT, H5P_DEFAULT)) >= 0) {
+                                if (!h5tools_is_zero(&tref, H5Tget_size(H5T_STD_REF))) {
                                     region_type = H5Sget_select_type(region_space);
                                     if (region_type == H5S_SEL_POINTS)
                                         render_bin_output_region_points(region_space, region_id, stream,
@@ -1926,7 +1931,7 @@ render_bin_output_region_data_blocks(hid_t region_id, FILE *stream, hid_t contai
     unsigned jndx;
     size_t   type_size;
     hid_t    mem_space  = H5I_INVALID_HID;
-    void *   region_buf = NULL;
+    void    *region_buf = NULL;
     hbool_t  past_catch = FALSE;
     hsize_t  blkndx;
     hid_t    sid1      = H5I_INVALID_HID;
@@ -2090,7 +2095,7 @@ render_bin_output_region_data_points(hid_t region_space, hid_t region_id, FILE *
     hsize_t *dims1 = NULL;
     size_t   type_size;
     hid_t    mem_space  = H5I_INVALID_HID;
-    void *   region_buf = NULL;
+    void    *region_buf = NULL;
     int      ret_value  = 0;
 
     H5TOOLS_START_DEBUG(" ");
