@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -240,7 +239,7 @@ typedef struct h5tool_format_t {
      *
      *   fmt_schar:  The printf() format to use when rendering data which is
      *               typed `signed char'. The default is `%d'. This format is
-     *               used ony if the `ascii' field is zero.
+     *               used only if the `ascii' field is zero.
      *
      *   fmt_uchar:  The printf() format to use when rendering data which is
      *               typed `unsigned char'. The default is `%u'. This format
@@ -353,11 +352,11 @@ typedef struct h5tool_format_t {
      *
      *   listv:    h5watch: vector containing info about the list of compound fields to be printed.
      */
-    const char *                     cmpd_name;
-    const char *                     cmpd_sep;
-    const char *                     cmpd_pre;
-    const char *                     cmpd_suf;
-    const char *                     cmpd_end;
+    const char                      *cmpd_name;
+    const char                      *cmpd_sep;
+    const char                      *cmpd_pre;
+    const char                      *cmpd_suf;
+    const char                      *cmpd_end;
     const struct H5LD_memb_t *const *cmpd_listv;
 
     /*
@@ -411,9 +410,9 @@ typedef struct h5tool_format_t {
      *   sep:       Each integer in the index list will be separated from the
      *              others by this string, which defaults to a comma.
      *
-     *   fmt:       After the index values are formated individually and
+     *   fmt:       After the index values are formatted individually and
      *              separated from one another by some string, the entire
-     *              resulting string will be formated according to this
+     *              resulting string will be formatted according to this
      *              printf(3c) format which should include a format for a
      *              character string.  The default is "%s".
      */
@@ -483,7 +482,7 @@ typedef struct h5tool_format_t {
     const char *line_suf;       /*string to append to each line */
     const char *line_sep;       /*separates lines               */
     int         line_multi_new; /*split multi-line outputs?     */
-    const char *line_indent;    /*for extra identation if we need it*/
+    const char *line_indent;    /*for extra indentation if we need it*/
 
     /*used to skip the first set of checks for line length*/
     int skip_first;
@@ -513,7 +512,7 @@ typedef struct h5tool_format_t {
 } h5tool_format_t;
 
 typedef struct subset_d {
-    hsize_t *    data;
+    hsize_t     *data;
     unsigned int len;
 } subset_d;
 
@@ -562,7 +561,7 @@ typedef struct h5tools_vol_info_t {
 
     /* Field specifying either the connector's name or value (ID) */
     union {
-        const char *       name;
+        const char        *name;
         H5VL_class_value_t value;
     } u;
 } h5tools_vol_info_t;
@@ -601,7 +600,7 @@ typedef enum {
 } driver_idx;
 
 /* The following include, h5tools_str.h, must be after the
- * above stucts are defined. There is a dependency in the following
+ * above structs are defined. There is a dependency in the following
  * include that hasn't been identified yet. */
 
 #include "h5tools_str.h"
@@ -613,29 +612,29 @@ extern "C" {
 H5TOOLS_DLLVAR const char *volnames[];
 H5TOOLS_DLLVAR const char *drivernames[];
 
-H5TOOLS_DLLVAR h5tool_format_t             h5tools_dataformat;
-H5TOOLS_DLLVAR const h5tools_dump_header_t h5tools_standardformat;
+H5TOOLS_DLLVAR h5tool_format_t              h5tools_dataformat;
+H5TOOLS_DLLVAR const h5tools_dump_header_t  h5tools_standardformat;
 H5TOOLS_DLLVAR const h5tools_dump_header_t *h5tools_dump_header_format;
 H5TOOLS_DLLVAR H5E_auto2_t                  lib_func;
 H5TOOLS_DLLVAR H5E_auto2_t                  tools_func;
-H5TOOLS_DLLVAR void *                       lib_edata;
-H5TOOLS_DLLVAR void *                       tools_edata;
+H5TOOLS_DLLVAR void                        *lib_edata;
+H5TOOLS_DLLVAR void                        *tools_edata;
 
 H5TOOLS_DLLVAR unsigned           packed_bits_num;    /* number of packed bits to display */
 H5TOOLS_DLLVAR unsigned           packed_data_offset; /* offset of packed bits to display */
 H5TOOLS_DLLVAR unsigned           packed_data_length; /* length of packed bits to display */
 H5TOOLS_DLLVAR unsigned long long packed_data_mask;   /* mask in which packed bits to display */
-H5TOOLS_DLLVAR FILE *rawattrstream;                   /* output stream for raw attribute data */
-H5TOOLS_DLLVAR FILE *rawdatastream;                   /* output stream for raw data */
-H5TOOLS_DLLVAR FILE *rawinstream;                     /* input stream for raw input */
-H5TOOLS_DLLVAR FILE *rawoutstream;                    /* output stream for raw output */
-H5TOOLS_DLLVAR FILE *rawerrorstream;                  /* output stream for raw error */
-H5TOOLS_DLLVAR int   bin_output;                      /* binary output */
-H5TOOLS_DLLVAR int   bin_form;                        /* binary form */
-H5TOOLS_DLLVAR int   region_output;                   /* region output */
-H5TOOLS_DLLVAR int   oid_output;                      /* oid output */
-H5TOOLS_DLLVAR int   data_output;                     /* data output */
-H5TOOLS_DLLVAR int   attr_data_output;                /* attribute data output */
+H5TOOLS_DLLVAR FILE              *rawattrstream;      /* output stream for raw attribute data */
+H5TOOLS_DLLVAR FILE              *rawdatastream;      /* output stream for raw data */
+H5TOOLS_DLLVAR FILE              *rawinstream;        /* input stream for raw input */
+H5TOOLS_DLLVAR FILE              *rawoutstream;       /* output stream for raw output */
+H5TOOLS_DLLVAR FILE              *rawerrorstream;     /* output stream for raw error */
+H5TOOLS_DLLVAR int                bin_output;         /* binary output */
+H5TOOLS_DLLVAR int                bin_form;           /* binary form */
+H5TOOLS_DLLVAR int                region_output;      /* region output */
+H5TOOLS_DLLVAR int                oid_output;         /* oid output */
+H5TOOLS_DLLVAR int                data_output;        /* data output */
+H5TOOLS_DLLVAR int                attr_data_output;   /* attribute data output */
 
 /* sort parameters */
 H5TOOLS_DLLVAR H5_index_t      sort_by;    /* sort_by [creation_order | name]  */
