@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -44,7 +43,7 @@ typedef struct H5LD_memb_t {
 /* Variable length string datatype */
 #define STR_INIT_LEN 4096 /*initial length            */
 
-static char *  h5tools_escape(char *s, size_t size);
+static char   *h5tools_escape(char *s, size_t size);
 static hbool_t h5tools_str_is_zero(const void *_mem, size_t size);
 static void    h5tools_print_char(h5tools_str_t *str, const h5tool_format_t *info, char ch);
 void           h5tools_str_indent(h5tools_str_t *str, const h5tool_format_t *info, h5tools_context_t *ctx);
@@ -129,7 +128,7 @@ h5tools_str_append(h5tools_str_t *str /*in,out*/, const char *fmt, ...)
 
         /* Note: HDvsnprintf() behaves differently on Windows as Unix, when
          * buffer is smaller than source string. On Unix, this function
-         * returns length of the source string and copy string upto the
+         * returns length of the source string and copy string up to the
          * buffer size with NULL at the end of the buffer. However on
          * Windows with the same condition, this function returns -1 and
          * doesn't add NULL at the end of the buffer.
@@ -147,7 +146,7 @@ h5tools_str_append(h5tools_str_t *str /*in,out*/, const char *fmt, ...)
              * following conditions, each of which indicates that the proper C99 return value probably
              *  should have been positive when the format string is
              *  something other than "%s"
-             * Alocate at least twice as much space and try again.
+             * Allocate at least twice as much space and try again.
              */
             size_t newsize = MAX(str->len + (size_t)nchars + 1, 2 * str->nalloc);
             HDassert(newsize > str->nalloc); /*overflow*/
@@ -258,7 +257,8 @@ h5tools_str_fmt(h5tools_str_t *str /*in,out*/, size_t start, const char *fmt)
             HDassert(temp);
         }
 
-        HDstrncpy(temp, str->s + start, n);
+        HDstrncpy(temp, str->s + start, n - 1);
+        temp[n - 1] = '\0';
     }
 
     /* Reset the output string and append a formatted version */
@@ -647,15 +647,15 @@ h5tools_str_sprint(h5tools_str_t *str, const h5tool_format_t *info, hid_t contai
 {
     size_t         nsize, offset, size = 0, nelmts, start;
     H5T_sign_t     nsign;
-    char *         name   = NULL;
+    char          *name   = NULL;
     unsigned char *ucp_vp = (unsigned char *)vp;
-    char *         cp_vp  = (char *)vp;
+    char          *cp_vp  = (char *)vp;
     hid_t          memb   = H5I_INVALID_HID;
     hid_t          obj    = H5I_INVALID_HID;
     static char    fmt_llong[8], fmt_ullong[8];
     H5T_str_t      pad;
     H5T_class_t    type_class;
-    char *         ret_value = NULL;
+    char          *ret_value = NULL;
 
     H5TOOLS_START_DEBUG(" ");
     /* Build default formats for long long types */
@@ -704,7 +704,6 @@ h5tools_str_sprint(h5tools_str_t *str, const h5tool_format_t *info, hid_t contai
 
                     HDmemcpy(&tempdouble, vp, sizeof(double));
                     h5tools_str_append(str, OPT(info->fmt_double, "%g"), tempdouble);
-#if H5_SIZEOF_LONG_DOUBLE != 0
                 }
                 else if (sizeof(long double) == nsize) {
                     /* if (H5Tequal(type, H5T_NATIVE_LDOUBLE)) */
@@ -712,7 +711,6 @@ h5tools_str_sprint(h5tools_str_t *str, const h5tool_format_t *info, hid_t contai
 
                     HDmemcpy(&templdouble, vp, sizeof(long double));
                     h5tools_str_append(str, "%Lg", templdouble);
-#endif
                 }
                 else {
                     size_t i;
@@ -728,7 +726,7 @@ h5tools_str_sprint(h5tools_str_t *str, const h5tool_format_t *info, hid_t contai
             case H5T_STRING: {
                 unsigned int i;
                 char         quote = '\0';
-                char *       s;
+                char        *s;
 
                 H5TOOLS_DEBUG("H5T_STRING");
                 quote = '\0';
@@ -1053,7 +1051,7 @@ h5tools_str_sprint(h5tools_str_t *str, const h5tool_format_t *info, hid_t contai
 
                 H5TOOLS_DEBUG("H5T_ENUM");
                 if (H5Tenum_nameof(type, vp, enum_name, sizeof enum_name) >= 0)
-                    h5tools_str_append(str, h5tools_escape(enum_name, sizeof(enum_name)));
+                    h5tools_str_append(str, "%s", h5tools_escape(enum_name, sizeof(enum_name)));
                 else {
                     size_t i;
                     if (1 == nsize)
@@ -1081,7 +1079,7 @@ h5tools_str_sprint(h5tools_str_t *str, const h5tool_format_t *info, hid_t contai
                             case H5R_OBJECT1: {
                                 /* Object references -- show the type and OID of the referenced object. */
                                 H5O_info2_t oi;
-                                char *      obj_tok_str = NULL;
+                                char       *obj_tok_str = NULL;
 
                                 H5TOOLS_DEBUG("ref_type is H5R_OBJECT1");
                                 if ((obj = H5Ropen_object(ref_vp, H5P_DEFAULT, H5P_DEFAULT)) >= 0) {
@@ -1176,16 +1174,63 @@ h5tools_str_sprint(h5tools_str_t *str, const h5tool_format_t *info, hid_t contai
                             case H5R_MAXTYPE:
                             default:
                                 break;
-                        } /* end switch */
+                        }
                         H5TOOLS_DEBUG("H5T_REFERENCE:H5T_STD_REF end");
                     }
                     else if (H5Tequal(type, H5T_STD_REF_DSETREG)) {
                         /* if(nsize == H5R_DSET_REG_REF_BUF_SIZE) */
                         H5TOOLS_DEBUG("H5T_REFERENCE:H5T_STD_REF_DSETREG");
+                        h5tools_str_append(str, H5_TOOLS_DATASET);
+                        h5tools_str_sprint_old_reference(str, container, H5R_DATASET_REGION, vp);
                     }
                     else if (H5Tequal(type, H5T_STD_REF_OBJ)) {
                         /* if (nsize == H5R_OBJ_REF_BUF_SIZE) */
+                        /*
+                         * Object references -- show the type and OID of the referenced object.
+                         */
+                        H5O_info2_t oi;
+                        char       *obj_tok_str = NULL;
+
                         H5TOOLS_DEBUG("H5T_REFERENCE:H5T_STD_REF_OBJ");
+                        obj = H5Rdereference2(container, H5P_DEFAULT, H5R_OBJECT, vp);
+                        H5Oget_info3(obj, &oi, H5O_INFO_BASIC);
+
+                        /* Print object type and close object */
+                        switch (oi.type) {
+                            case H5O_TYPE_GROUP:
+                                h5tools_str_append(str, H5_TOOLS_GROUP);
+                                break;
+
+                            case H5O_TYPE_DATASET:
+                                h5tools_str_append(str, H5_TOOLS_DATASET);
+                                break;
+
+                            case H5O_TYPE_NAMED_DATATYPE:
+                                h5tools_str_append(str, H5_TOOLS_DATATYPE);
+                                break;
+
+                            case H5O_TYPE_UNKNOWN:
+                            case H5O_TYPE_NTYPES:
+                            default:
+                                h5tools_str_append(str, "%u-", (unsigned)oi.type);
+                                break;
+                        }
+                        H5Oclose(obj);
+
+                        /* Print OID */
+                        H5Otoken_to_str(obj, &oi.token, &obj_tok_str);
+
+                        if (info->obj_hidefileno)
+                            h5tools_str_append(str, info->obj_format, obj_tok_str);
+                        else
+                            h5tools_str_append(str, info->obj_format, oi.fileno, obj_tok_str);
+
+                        if (obj_tok_str) {
+                            H5free_memory(obj_tok_str);
+                            obj_tok_str = NULL;
+                        }
+
+                        h5tools_str_sprint_old_reference(str, container, H5R_OBJECT, vp);
                     } /* end else if (H5Tequal(type, H5T_STD_REF_OBJ)) */
                 }
                 break;
@@ -1247,7 +1292,7 @@ h5tools_str_sprint(h5tools_str_t *str, const h5tool_format_t *info, hid_t contai
 
                 /* Print the closing bracket */
                 h5tools_str_append(str, "%s", OPT(info->arr_suf, "]"));
-                is_next_arry_elmt = 1; /* set for begining of next array element */
+                is_next_arry_elmt = 1; /* set for beginning of next array element */
                 H5Tclose(memb);
             } break;
 
@@ -1266,6 +1311,7 @@ h5tools_str_sprint(h5tools_str_t *str, const h5tool_format_t *info, hid_t contai
                 nelmts = ((hvl_t *)((void *)cp_vp))->len;
 
                 for (i = 0; i < nelmts; i++) {
+                    H5TOOLS_DEBUG("H5T_VLEN %d of %ld", i, nelmts);
                     if (i)
                         h5tools_str_append(str, "%s", OPT(info->vlen_sep, "," OPTIONAL_LINE_BREAK));
 
@@ -1326,6 +1372,50 @@ h5tools_str_sprint(h5tools_str_t *str, const h5tool_format_t *info, hid_t contai
     return ret_value;
 }
 
+/*-------------------------------------------------------------------------
+ * Function:    h5tools_str_sprint_old_reference
+ *
+ * Purpose: Object reference -- show the name of the old referenced object.
+ *
+ * Return:  Nothing
+ *-------------------------------------------------------------------------
+ */
+void
+h5tools_str_sprint_old_reference(h5tools_str_t *str, hid_t container, H5R_type_t ref_type, void *vp)
+{
+    hid_t obj    = H5I_INVALID_HID;
+    hid_t region = H5I_INVALID_HID;
+    char  ref_name[1024];
+
+    H5TOOLS_START_DEBUG(" ");
+
+    h5tools_str_append(str, " \"");
+    if (ref_type == H5R_DATASET_REGION) {
+        obj = H5Rdereference2(container, H5P_DEFAULT, ref_type, vp);
+        if (obj >= 0) {
+            region = H5Rget_region(container, ref_type, vp);
+            if (region >= 0) {
+                H5Rget_name(obj, ref_type, vp, (char *)ref_name, 1024);
+                h5tools_str_append(str, "%s", ref_name);
+
+                H5Sclose(region);
+            } /* end if (region >= 0) */
+            H5Dclose(obj);
+        } /* end if (obj >= 0) */
+    }
+    else if (ref_type == H5R_OBJECT) {
+        obj = H5Rdereference2(container, H5P_DEFAULT, ref_type, vp);
+        if (obj >= 0) {
+            H5Rget_name(obj, ref_type, vp, (char *)ref_name, 1024);
+            h5tools_str_append(str, "%s", ref_name);
+            H5Dclose(obj);
+        }
+    }
+    h5tools_str_append(str, "\"");
+
+    H5TOOLS_ENDDEBUG(" ");
+}
+
 /*-------------------------------------------------------------------------
  * Function:    h5tools_str_sprint_reference
  *
@@ -1403,10 +1493,10 @@ h5tools_str_sprint_reference(h5tools_str_t *str, H5R_ref_t *ref_vp)
 static char *
 h5tools_escape(char *s /*in,out*/, size_t size)
 {
-    register size_t i;
-    const char *    escape;
-    char            octal[8];
-    size_t          n = HDstrlen(s);
+    size_t      i;
+    const char *escape;
+    char        octal[8];
+    size_t      n = HDstrlen(s);
 
     for (i = 0; i < n; i++) {
         switch (s[i]) {
@@ -1505,7 +1595,7 @@ h5tools_str_is_zero(const void *_mem, size_t size)
  *              March 8, 2012
  *
  * Notes:
- *   Applications need to call free() to free the memoery allocated for
+ *   Applications need to call free() to free the memory allocated for
  *   the return string
  *
  *-------------------------------------------------------------------------
