@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -25,14 +24,14 @@
 #include "H5FDros3.h"
 #endif
 
-/* global variables */
-unsigned h5tools_nCols = 80;
-/* ``get_option'' variables */
-int                opt_err = 1; /*get_option prints errors if this is on */
-int                opt_ind = 1; /*token pointer                          */
-const char *       opt_arg;     /*flag argument (or value)               */
+/* Global variables */
+unsigned           h5tools_nCols    = 80;
 static int         h5tools_d_status = 0;
 static const char *h5tools_progname = "h5tools";
+/* ``get_option'' variables */
+int         opt_err = 1; /*get_option prints errors if this is on */
+int         opt_ind = 1; /*token pointer                          */
+const char *opt_arg;     /*flag argument (or value)               */
 
 /*
  * The output functions need a temporary buffer to hold a piece of the
@@ -49,7 +48,7 @@ hsize_t H5TOOLS_BUFSIZE = (32 * 1024 * 1024); /* 32 MB */
 unsigned char g_Parallel = 0; /*0 for serial, 1 for parallel */
 char          outBuff[OUTBUFF_SIZE];
 unsigned      outBuffOffset;
-FILE *        overflow_file = NULL;
+FILE         *overflow_file = NULL;
 
 /* local functions */
 static void init_table(hid_t fid, table_t **tbl);
@@ -162,6 +161,128 @@ help_ref_msg(FILE *output)
     HDfprintf(output, "see the <%s> entry in the 'HDF5 Reference Manual'.\n", h5tools_getprogname());
 }
 
+/*-------------------------------------------------------------------------
+ * Function:    parse_hsize_list
+ *
+ * Purpose:     Parse a list of comma or space separated integers and return
+ *              them in a list. The string being passed into this function
+ *              should be at the start of the list you want to parse. You are
+ *              responsible for freeing the array returned from here.
+ *
+ *              Lists in the so-called "terse" syntax are separated by
+ *              semicolons (;). The lists themselves can be separated by
+ *              either commas (,) or white spaces.
+ *
+ * Return:      <none>
+ *-------------------------------------------------------------------------
+ */
+void
+parse_hsize_list(const char *h_list, subset_d *d)
+{
+    hsize_t     *p_list;
+    const char  *ptr;
+    unsigned int size_count = 0;
+    unsigned int i          = 0;
+    unsigned int last_digit = 0;
+
+    if (!h_list || !*h_list || *h_list == ';')
+        return;
+
+    H5TOOLS_START_DEBUG(" - h_list:%s", h_list);
+    /* count how many integers do we have */
+    for (ptr = h_list; ptr && *ptr && *ptr != ';' && *ptr != ']'; ptr++)
+        if (HDisdigit(*ptr)) {
+            if (!last_digit)
+                /* the last read character wasn't a digit */
+                size_count++;
+
+            last_digit = 1;
+        }
+        else
+            last_digit = 0;
+
+    if (size_count == 0) {
+        /* there aren't any integers to read */
+        H5TOOLS_ENDDEBUG("No integers to read");
+        return;
+    }
+    H5TOOLS_DEBUG("Number integers to read=%ld", size_count);
+
+    /* allocate an array for the integers in the list */
+    if ((p_list = (hsize_t *)HDcalloc(size_count, sizeof(hsize_t))) == NULL)
+        H5TOOLS_INFO("Unable to allocate space for subset data");
+
+    for (ptr = h_list; i < size_count && ptr && *ptr && *ptr != ';' && *ptr != ']'; ptr++)
+        if (HDisdigit(*ptr)) {
+            /* we should have an integer now */
+            p_list[i++] = (hsize_t)HDstrtoull(ptr, NULL, 0);
+
+            while (HDisdigit(*ptr))
+                /* scroll to end of integer */
+                ptr++;
+        }
+    d->data = p_list;
+    d->len  = size_count;
+    H5TOOLS_ENDDEBUG(" ");
+}
+
+/*-------------------------------------------------------------------------
+ * Function:    parse_subset_params
+ *
+ * Purpose:     Parse the so-called "terse" syntax for specifying subsetting parameters.
+ *
+ * Return:      Success:    struct subset_t object
+ *              Failure:    NULL
+ *-------------------------------------------------------------------------
+ */
+struct subset_t *
+parse_subset_params(const char *dset)
+{
+    struct subset_t *s = NULL;
+    char            *brace;
+    const char      *q_dset;
+
+    H5TOOLS_START_DEBUG(" - dset:%s", dset);
+    /* if dset name is quoted wait till after second quote to look for subset brackets */
+    if (*dset == '"')
+        q_dset = HDstrchr(dset, '"');
+    else
+        q_dset = dset;
+    if ((brace = HDstrrchr(q_dset, '[')) != NULL) {
+        *brace++ = '\0';
+
+        s = (struct subset_t *)HDcalloc(1, sizeof(struct subset_t));
+        parse_hsize_list(brace, &s->start);
+
+        while (*brace && *brace != ';')
+            brace++;
+
+        if (*brace)
+            brace++;
+
+        parse_hsize_list(brace, &s->stride);
+
+        while (*brace && *brace != ';')
+            brace++;
+
+        if (*brace)
+            brace++;
+
+        parse_hsize_list(brace, &s->count);
+
+        while (*brace && *brace != ';')
+            brace++;
+
+        if (*brace)
+            brace++;
+
+        parse_hsize_list(brace, &s->block);
+    }
+    H5TOOLS_ENDDEBUG(" ");
+
+    return s;
+}
+
 /*-------------------------------------------------------------------------
  * Function: get_option
  *
@@ -169,17 +290,17 @@ help_ref_msg(FILE *output)
  *           accept both short and long type command-lines.
  *
  * Return:  Success:    The short valued "name" of the command line
- *              parameter or EOF if there are no more
- *              parameters to process.
+ *                      parameter or EOF if there are no more
+ *                      parameters to process.
  *
  *          Failure:    A question mark.
  *-------------------------------------------------------------------------
  */
 int
-get_option(int argc, const char **argv, const char *opts, const struct long_options *l_opts)
+get_option(int argc, const char *const *argv, const char *opts, const struct long_options *l_opts)
 {
     static int sp      = 1;   /* character index in current token */
-    int        opt_opt = '?'; /* option character passed back to user */
+    int        optchar = '?'; /* option character passed back to user */
 
     if (sp == 1) {
         /* check for more flag-like tokens */
@@ -196,7 +317,7 @@ get_option(int argc, const char **argv, const char *opts, const struct long_opti
         /* long command line option */
         int        i;
         const char ch      = '=';
-        char *     arg     = HDstrdup(&argv[opt_ind][2]);
+        char      *arg     = HDstrdup(&argv[opt_ind][2]);
         size_t     arg_len = 0;
 
         opt_arg = strchr(&argv[opt_ind][2], ch);
@@ -210,7 +331,7 @@ get_option(int argc, const char **argv, const char *opts, const struct long_opti
         for (i = 0; l_opts && l_opts[i].name; i++) {
             if (HDstrcmp(arg, l_opts[i].name) == 0) {
                 /* we've found a matching long command line flag */
-                opt_opt = l_opts[i].shortval;
+                optchar = l_opts[i].shortval;
 
                 if (l_opts[i].has_arg != no_arg) {
                     if (opt_arg == NULL) {
@@ -224,7 +345,7 @@ get_option(int argc, const char **argv, const char *opts, const struct long_opti
                                 HDfprintf(rawerrorstream, "%s: option required for \"--%s\" flag\n", argv[0],
                                           arg);
 
-                            opt_opt = '?';
+                            optchar = '?';
                         }
                     }
                 }
@@ -234,7 +355,7 @@ get_option(int argc, const char **argv, const char *opts, const struct long_opti
                             HDfprintf(rawerrorstream, "%s: no option required for \"%s\" flag\n", argv[0],
                                       arg);
 
-                        opt_opt = '?';
+                        optchar = '?';
                     }
                 }
                 break;
@@ -246,7 +367,7 @@ get_option(int argc, const char **argv, const char *opts, const struct long_opti
             if (opt_err)
                 HDfprintf(rawerrorstream, "%s: unknown option \"%s\"\n", argv[0], arg);
 
-            opt_opt = '?';
+            optchar = '?';
         }
 
         opt_ind++;
@@ -255,14 +376,14 @@ get_option(int argc, const char **argv, const char *opts, const struct long_opti
         HDfree(arg);
     }
     else {
-        register char *cp; /* pointer into current token */
+        char *cp; /* pointer into current token */
 
         /* short command line option */
-        opt_opt = argv[opt_ind][sp];
+        optchar = argv[opt_ind][sp];
 
-        if (opt_opt == ':' || (cp = HDstrchr(opts, opt_opt)) == 0) {
+        if (optchar == ':' || (cp = HDstrchr(opts, optchar)) == 0) {
             if (opt_err)
-                HDfprintf(rawerrorstream, "%s: unknown option \"%c\"\n", argv[0], opt_opt);
+                HDfprintf(rawerrorstream, "%s: unknown option \"%c\"\n", argv[0], optchar);
 
             /* if no chars left in this token, move to next token */
             if (argv[opt_ind][++sp] == '\0') {
@@ -280,9 +401,9 @@ get_option(int argc, const char **argv, const char *opts, const struct long_opti
             }
             else if (++opt_ind >= argc) {
                 if (opt_err)
-                    HDfprintf(rawerrorstream, "%s: value expected for option \"%c\"\n", argv[0], opt_opt);
+                    HDfprintf(rawerrorstream, "%s: value expected for option \"%c\"\n", argv[0], optchar);
 
-                opt_opt = '?';
+                optchar = '?';
             }
             else {
                 /* flag value is next token */
@@ -320,7 +441,7 @@ get_option(int argc, const char **argv, const char *opts, const struct long_opti
     }
 
     /* return the current flag character found */
-    return opt_opt;
+    return optchar;
 }
 
 /*****************************************************************************
@@ -345,7 +466,7 @@ get_option(int argc, const char **argv, const char *opts, const struct long_opti
  *     * Last two characters in the string MUST be ")\0".
  *
  *     * Generates a copy of the input string `start`, (src..")\0"), replacing
- *       separators and close-paren with null charaters.
+ *       separators and close-paren with null characters.
  *         * This string is allocated at runtime and should be freed when done.
  *     * Generates array of char pointers, and directs start of each element
  *       (each pointer) into this copy.
@@ -389,12 +510,12 @@ get_option(int argc, const char **argv, const char *opts, const struct long_opti
 herr_t
 parse_tuple(const char *start, int sep, char **cpy_out, unsigned *nelems, char ***ptrs_out)
 {
-    char *   elem_ptr    = NULL;
-    char *   dest_ptr    = NULL;
+    char    *elem_ptr    = NULL;
+    char    *dest_ptr    = NULL;
     unsigned elems_count = 0;
-    char **  elems       = NULL; /* more like *elems[], but complier... */
-    char **  elems_re    = NULL; /* temporary pointer, for realloc */
-    char *   cpy         = NULL;
+    char   **elems       = NULL; /* more like *elems[], but compiler... */
+    char   **elems_re    = NULL; /* temporary pointer, for realloc */
+    char    *cpy         = NULL;
     herr_t   ret_value   = SUCCEED;
     unsigned init_slots  = 2;
 
@@ -502,7 +623,7 @@ parse_tuple(const char *start, int sep, char **cpy_out, unsigned *nelems, char *
             /* Found terminal, non-escaped close-paren. Last element.
              * Write null terminator to copy.
              * Advance source pointer to gently break from loop.
-             * Requred to prevent ")" from always being added to last element.
+             * Required to prevent ")" from always being added to last element.
              */
             start++;
         }
@@ -615,6 +736,7 @@ free_table(table_t *table)
             HDfree(table->objs[u].objname);
 
     HDfree(table->objs);
+    HDfree(table);
 }
 
 #ifdef H5DUMP_DEBUG
@@ -631,7 +753,7 @@ static void
 dump_table(hid_t fid, char *tablename, table_t *table)
 {
     unsigned u;
-    char *   obj_tok_str = NULL;
+    char    *obj_tok_str = NULL;
 
     PRINTSTREAM(rawoutstream, "%s: # of entries = %d\n", tablename, table->nobjs);
     for (u = 0; u < table->nobjs; u++) {
@@ -672,7 +794,7 @@ dump_tables(find_objs_t *info)
  *-------------------------------------------------------------------------
  */
 H5_ATTR_PURE obj_t *
-             search_obj(table_t *table, const H5O_token_t *obj_token)
+search_obj(table_t *table, const H5O_token_t *obj_token)
 {
     unsigned u;
     int      token_cmp;
@@ -861,7 +983,7 @@ tmpfile(void)
  * Purpose: Get symbolic link (soft, external) info and its target object type
             (dataset, group, named datatype) and path, if exist
  *
- * Patameters:
+ * Parameters:
  *  - [IN]  fileid : link file id
  *  - [IN]  linkpath : link path
  *  - [OUT] link_info: returning target object info (h5tool_link_info_t)
@@ -1075,8 +1197,8 @@ h5tools_parse_ros3_fapl_tuple(const char *tuple_str, int delim, H5FD_ros3_fapl_t
 {
     const char *ccred[3];
     unsigned    nelems     = 0;
-    char *      s3cred_src = NULL;
-    char **     s3cred     = NULL;
+    char       *s3cred_src = NULL;
+    char      **s3cred     = NULL;
     herr_t      ret_value  = SUCCEED;
 
     /* Attempt to parse S3 credentials tuple */
@@ -1294,8 +1416,8 @@ h5tools_parse_hdfs_fapl_tuple(const char *tuple_str, int delim, H5FD_hdfs_fapl_t
 {
     unsigned long k         = 0;
     unsigned      nelems    = 0;
-    char *        props_src = NULL;
-    char **       props     = NULL;
+    char         *props_src = NULL;
+    char        **props     = NULL;
     herr_t        ret_value = SUCCEED;
 
     /* Attempt to parse HDFS configuration tuple */
