@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -19,7 +18,7 @@
 #define PROGRAMNAME "h5copy"
 
 /* command-line options: short and long-named parameters */
-static const char *        s_opts    = "d:f:hi:o:ps:vVE";
+static const char         *s_opts    = "d:f:hi:o:ps:vVE*";
 static struct long_options l_opts[]  = {{"destination", require_arg, 'd'},
                                        {"flag", require_arg, 'f'},
                                        {"help", no_arg, 'h'},
@@ -29,13 +28,13 @@ static struct long_options l_opts[]  = {{"destination", require_arg, 'd'},
                                        {"source", require_arg, 's'},
                                        {"verbose", no_arg, 'v'},
                                        {"version", no_arg, 'V'},
-                                       {"enable-error-stack", no_arg, 'E'},
+                                       {"enable-error-stack", optional_arg, 'E'},
                                        {NULL, 0, '\0'}};
-char *                     fname_src = NULL;
-char *                     fname_dst = NULL;
-char *                     oname_src = NULL;
-char *                     oname_dst = NULL;
-char *                     str_flag  = NULL;
+char                      *fname_src = NULL;
+char                      *fname_dst = NULL;
+char                      *oname_src = NULL;
+char                      *oname_dst = NULL;
+char                      *str_flag  = NULL;
 
 /*-------------------------------------------------------------------------
  * Function:    leave
@@ -47,8 +46,6 @@ char *                     str_flag  = NULL;
  * Programmer:  Quincey Koziol
  *              Saturday, 31. January 2004
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static void
@@ -78,8 +75,6 @@ leave(int ret)
  *
  * Programmer: Pedro Vicente Nunes, 7/8/2006
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static void
@@ -93,15 +88,17 @@ usage(void)
     PRINTVALSTREAM(rawoutstream, "      -o, --output       output file name\n");
     PRINTVALSTREAM(rawoutstream, "      -s, --source       source object name\n");
     PRINTVALSTREAM(rawoutstream, "      -d, --destination  destination object name\n");
+    PRINTVALSTREAM(rawoutstream, "   ERROR\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "     --enable-error-stack Prints messages from the HDF5 error stack as they occur.\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "                          Optional value 2 also prints file open errors.\n");
     PRINTVALSTREAM(rawoutstream, "   OPTIONS\n");
     PRINTVALSTREAM(rawoutstream, "      -h, --help         Print a usage message and exit\n");
     PRINTVALSTREAM(rawoutstream,
                    "      -p, --parents      No error if existing, make parent groups as needed\n");
     PRINTVALSTREAM(rawoutstream, "      -v, --verbose      Print information about OBJECTS and OPTIONS\n");
     PRINTVALSTREAM(rawoutstream, "      -V, --version      Print version number and exit\n");
-    PRINTVALSTREAM(rawoutstream, "      --enable-error-stack\n");
-    PRINTVALSTREAM(rawoutstream,
-                   "                  Prints messages from the HDF5 error stack as they occur.\n");
     PRINTVALSTREAM(rawoutstream, "      -f, --flag         Flag type\n\n");
     PRINTVALSTREAM(rawoutstream, "      Flag type is one of the following strings:\n\n");
     PRINTVALSTREAM(rawoutstream, "      shallow     Copy only immediate members for groups\n\n");
@@ -158,8 +155,6 @@ usage(void)
  *
  * Programmer: Pedro Vicente Nunes, 7/8/2006
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 
@@ -206,13 +201,11 @@ parse_flag(const char *s_flag, unsigned *flag)
  *
  * Programmer: Pedro Vicente Nunes
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 
 int
-main(int argc, const char *argv[])
+main(int argc, char *argv[])
 {
     hid_t              fid_src = H5I_INVALID_HID;
     hid_t              fid_dst = H5I_INVALID_HID;
@@ -242,7 +235,7 @@ main(int argc, const char *argv[])
     } /* end if */
 
     /* parse command line options */
-    while ((opt = get_option(argc, argv, s_opts, l_opts)) != EOF) {
+    while ((opt = get_option(argc, (const char *const *)argv, s_opts, l_opts)) != EOF) {
         switch ((char)opt) {
             case 'd':
                 oname_dst = HDstrdup(opt_arg);
@@ -288,7 +281,10 @@ main(int argc, const char *argv[])
                 break;
 
             case 'E':
-                enable_error_stack = 1;
+                if (opt_arg != NULL)
+                    enable_error_stack = HDatoi(opt_arg);
+                else
+                    enable_error_stack = 1;
                 break;
 
             default:
