@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -19,7 +18,7 @@
 #define PROGRAMNAME "h5dump"
 
 static const char *driver_name_g = NULL; /* The driver to open the file with. */
-const char *       outfname_g    = NULL;
+const char        *outfname_g    = NULL;
 static hbool_t     doxml_g       = FALSE;
 static hbool_t     useschema_g   = TRUE;
 static const char *xml_dtd_uri_g = NULL;
@@ -69,7 +68,7 @@ static void init_prefix(char **prfx, size_t prfx_len);
 /* a structure for handling the order command-line parameters come in */
 struct handler_t {
     void (*func)(hid_t, const char *, void *, int, const char *);
-    char *           obj;
+    char            *obj;
     struct subset_t *subset_info;
 };
 
@@ -80,126 +79,48 @@ struct handler_t {
  */
 /* The following initialization makes use of C language concatenating */
 /* "xxx" "yyy" into "xxxyyy". */
-static const char *        s_opts   = "a:b*c:d:ef:g:hik:l:m:n*o*pq:rs:t:uvw:xyz:A*BCD:E*F:G:HM:N:O*RS:VX:";
+static const char         *s_opts   = "a:b*c:d:ef:g:hik:l:m:n*o*pq:rs:t:uvw:xyz:A*BCD:E*F:G:HM:N:O*RS:VX:";
 static struct long_options l_opts[] = {{"attribute", require_arg, 'a'},
-                                       {"attribut", require_arg, 'a'},
-                                       {"attribu", require_arg, 'a'},
-                                       {"attrib", require_arg, 'a'},
-                                       {"attri", require_arg, 'a'},
-                                       {"attr", require_arg, 'a'},
-                                       {"att", require_arg, 'a'},
-                                       {"at", require_arg, 'a'},
                                        {"binary", optional_arg, 'b'},
                                        {"count", require_arg, 'c'},
-                                       {"coun", require_arg, 'c'},
-                                       {"cou", require_arg, 'c'},
-                                       {"co", require_arg, 'c'},
                                        {"dataset", require_arg, 'd'},
-                                       {"datase", require_arg, 'd'},
-                                       {"datas", require_arg, 'd'},
                                        {"escape", no_arg, 'e'},
                                        {"filedriver", require_arg, 'f'},
-                                       {"filedrive", require_arg, 'f'},
-                                       {"filedriv", require_arg, 'f'},
-                                       {"filedri", require_arg, 'f'},
-                                       {"filedr", require_arg, 'f'},
-                                       {"filed", require_arg, 'f'},
-                                       {"file", require_arg, 'f'},
-                                       {"fil", require_arg, 'f'},
-                                       {"fi", require_arg, 'f'},
                                        {"group", require_arg, 'g'},
-                                       {"grou", require_arg, 'g'},
-                                       {"gro", require_arg, 'g'},
-                                       {"gr", require_arg, 'g'},
                                        {"help", no_arg, 'h'},
-                                       {"hel", no_arg, 'h'},
                                        {"object-ids", no_arg, 'i'},
-                                       {"object-id", no_arg, 'i'},
-                                       {"object-i", no_arg, 'i'},
-                                       {"object", no_arg, 'i'},
-                                       {"objec", no_arg, 'i'},
-                                       {"obje", no_arg, 'i'},
-                                       {"obj", no_arg, 'i'},
-                                       {"ob", no_arg, 'i'},
                                        {"block", require_arg, 'k'},
-                                       {"bloc", require_arg, 'k'},
-                                       {"blo", require_arg, 'k'},
-                                       {"bl", require_arg, 'k'},
                                        {"soft-link", require_arg, 'l'},
-                                       {"soft-lin", require_arg, 'l'},
-                                       {"soft-li", require_arg, 'l'},
-                                       {"soft-l", require_arg, 'l'},
-                                       {"soft", require_arg, 'l'},
-                                       {"sof", require_arg, 'l'},
                                        {"format", require_arg, 'm'},
                                        {"contents", optional_arg, 'n'},
                                        {"output", optional_arg, 'o'},
-                                       {"outpu", optional_arg, 'o'},
-                                       {"outp", optional_arg, 'o'},
-                                       {"out", optional_arg, 'o'},
-                                       {"ou", optional_arg, 'o'},
                                        {"properties", no_arg, 'p'},
                                        {"sort_by", require_arg, 'q'},
                                        {"string", no_arg, 'r'},
-                                       {"strin", no_arg, 'r'},
                                        {"start", require_arg, 's'},
-                                       {"star", require_arg, 's'},
-                                       {"sta", require_arg, 's'},
                                        {"datatype", require_arg, 't'},
-                                       {"datatyp", require_arg, 't'},
-                                       {"dataty", require_arg, 't'},
-                                       {"datat", require_arg, 't'},
                                        {"use-dtd", no_arg, 'u'},
-                                       {"use-dt", no_arg, 'u'},
-                                       {"use-d", no_arg, 'u'},
-                                       {"use-", no_arg, 'u'},
-                                       {"use", no_arg, 'u'},
-                                       {"us", no_arg, 'u'},
-                                       {"u", no_arg, 'u'},
                                        {"vds-view-first-missing", no_arg, 'v'},
                                        {"width", require_arg, 'w'},
-                                       {"widt", require_arg, 'w'},
-                                       {"wid", require_arg, 'w'},
-                                       {"wi", require_arg, 'w'},
                                        {"xml", no_arg, 'x'},
-                                       {"xm", no_arg, 'x'},
                                        {"noindex", no_arg, 'y'},
                                        {"sort_order", require_arg, 'z'},
                                        {"onlyattr", optional_arg, 'A'},
                                        {"superblock", no_arg, 'B'},
                                        {"boot-block", no_arg, 'B'},
-                                       {"boot-bloc", no_arg, 'B'},
-                                       {"boot-blo", no_arg, 'B'},
-                                       {"boot-bl", no_arg, 'B'},
-                                       {"boot-b", no_arg, 'B'},
-                                       {"boot", no_arg, 'B'},
-                                       {"boo", no_arg, 'B'},
-                                       {"bo", no_arg, 'B'},
                                        {"no-compact-subset", no_arg, 'C'},
                                        {"xml-dtd", require_arg, 'D'},
-                                       {"xml-dt", require_arg, 'D'},
-                                       {"xml-d", require_arg, 'D'},
                                        {"enable-error-stack", optional_arg, 'E'},
                                        {"form", require_arg, 'F'},
                                        {"vds-gap-size", require_arg, 'G'},
                                        {"header", no_arg, 'H'},
-                                       {"heade", no_arg, 'H'},
-                                       {"head", no_arg, 'H'},
-                                       {"hea", no_arg, 'H'},
                                        {"packed-bits", require_arg, 'M'},
                                        {"any_path", require_arg, 'N'},
                                        {"ddl", optional_arg, 'O'},
                                        {"region", no_arg, 'R'},
                                        {"stride", require_arg, 'S'},
-                                       {"strid", require_arg, 'S'},
                                        {"version", no_arg, 'V'},
-                                       {"versio", no_arg, 'V'},
-                                       {"versi", no_arg, 'V'},
-                                       {"vers", no_arg, 'V'},
-                                       {"ver", no_arg, 'V'},
-                                       {"ve", no_arg, 'V'},
                                        {"xml-ns", require_arg, 'X'},
-                                       {"xml-n", require_arg, 'X'},
                                        {"s3-cred", require_arg, '$'},
                                        {"hdfs-attrs", require_arg, '#'},
                                        {"vol-value", require_arg, '1'},
@@ -239,6 +160,12 @@ usage(const char *prog)
     PRINTVALSTREAM(rawoutstream, "  OPTIONS\n");
     PRINTVALSTREAM(rawoutstream, "     -h,   --help         Print a usage message and exit\n");
     PRINTVALSTREAM(rawoutstream, "     -V,   --version      Print version number and exit\n");
+    PRINTVALSTREAM(rawoutstream, "--------------- Error Options ---------------\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "     --enable-error-stack Prints messages from the HDF5 error stack as they occur.\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "                          Optional value 2 also prints file open errors.\n");
+    PRINTVALSTREAM(rawoutstream, "                          Default setting disables any error reporting.\n");
     PRINTVALSTREAM(rawoutstream, "--------------- File Options ---------------\n");
     PRINTVALSTREAM(rawoutstream, "     -n,   --contents     Print a list of the file contents and exit\n");
     PRINTVALSTREAM(rawoutstream, "                          Optional value 1 also prints attributes.\n");
@@ -319,10 +246,6 @@ usage(const char *prog)
     PRINTVALSTREAM(rawoutstream, "     -m T, --format=T     Set the floating point output format\n");
     PRINTVALSTREAM(rawoutstream, "     -q Q, --sort_by=Q    Sort groups and attributes by index Q\n");
     PRINTVALSTREAM(rawoutstream, "     -z Z, --sort_order=Z Sort groups and attributes by order Z\n");
-    PRINTVALSTREAM(rawoutstream,
-                   "     --enable-error-stack Prints messages from the HDF5 error stack as they occur.\n");
-    PRINTVALSTREAM(rawoutstream,
-                   "                          Optional value 2 also prints file open errors.\n");
     PRINTVALSTREAM(rawoutstream,
                    "     --no-compact-subset  Disable compact form of subsetting and allow the use\n");
     PRINTVALSTREAM(rawoutstream, "                          of \"[\" in dataset names.\n");
@@ -531,11 +454,8 @@ table_list_free(void)
 
         /* Free each table */
         free_table(table_list.tables[u].group_table);
-        HDfree(table_list.tables[u].group_table);
         free_table(table_list.tables[u].dset_table);
-        HDfree(table_list.tables[u].dset_table);
         free_table(table_list.tables[u].type_table);
-        HDfree(table_list.tables[u].type_table);
     }
 
     /* Free the table list */
@@ -618,114 +538,6 @@ set_sort_order(const char *form)
     return iter_order;
 }
 
-/*-------------------------------------------------------------------------
- * Function:    parse_hsize_list
- *
- * Purpose:     Parse a list of comma or space separated integers and return
- *              them in a list. The string being passed into this function
- *              should be at the start of the list you want to parse. You are
- *              responsible for freeing the array returned from here.
- *
- *              Lists in the so-called "terse" syntax are separated by
- *              semicolons (;). The lists themselves can be separated by
- *              either commas (,) or white spaces.
- *
- * Return:      <none>
- *-------------------------------------------------------------------------
- */
-static void
-parse_hsize_list(const char *h_list, subset_d *d)
-{
-    hsize_t *    p_list;
-    const char * ptr;
-    unsigned int size_count = 0;
-    unsigned int i          = 0;
-    unsigned int last_digit = 0;
-
-    if (!h_list || !*h_list || *h_list == ';')
-        return;
-
-    /* count how many integers do we have */
-    for (ptr = h_list; ptr && *ptr && *ptr != ';' && *ptr != ']'; ptr++)
-        if (HDisdigit(*ptr)) {
-            if (!last_digit)
-                /* the last read character wasn't a digit */
-                size_count++;
-
-            last_digit = 1;
-        }
-        else
-            last_digit = 0;
-
-    if (size_count == 0)
-        /* there aren't any integers to read */
-        return;
-
-    /* allocate an array for the integers in the list */
-    p_list = (hsize_t *)HDcalloc(size_count, sizeof(hsize_t));
-
-    for (ptr = h_list; i < size_count && ptr && *ptr && *ptr != ';' && *ptr != ']'; ptr++)
-        if (HDisdigit(*ptr)) {
-            /* we should have an integer now */
-            p_list[i++] = (hsize_t)HDstrtoull(ptr, NULL, 0);
-
-            while (HDisdigit(*ptr))
-                /* scroll to end of integer */
-                ptr++;
-        }
-    d->data = p_list;
-    d->len  = size_count;
-}
-
-/*-------------------------------------------------------------------------
- * Function:    parse_subset_params
- *
- * Purpose:     Parse the so-called "terse" syntax for specifying subsetting parameters.
- *
- * Return:      Success:    struct subset_t object
- *              Failure:    NULL
- *-------------------------------------------------------------------------
- */
-static struct subset_t *
-parse_subset_params(const char *dset)
-{
-    struct subset_t *s = NULL;
-    char *           brace;
-
-    if (!dump_opts.disable_compact_subset && ((brace = HDstrrchr(dset, '[')) != NULL)) {
-        *brace++ = '\0';
-
-        s = (struct subset_t *)HDcalloc(1, sizeof(struct subset_t));
-        parse_hsize_list(brace, &s->start);
-
-        while (*brace && *brace != ';')
-            brace++;
-
-        if (*brace)
-            brace++;
-
-        parse_hsize_list(brace, &s->stride);
-
-        while (*brace && *brace != ';')
-            brace++;
-
-        if (*brace)
-            brace++;
-
-        parse_hsize_list(brace, &s->count);
-
-        while (*brace && *brace != ';')
-            brace++;
-
-        if (*brace)
-            brace++;
-
-        parse_hsize_list(brace, &s->block);
-    }
-
-    return s;
-}
-
 /*-------------------------------------------------------------------------
  * Function:    parse_mask_list
  *
@@ -745,7 +557,7 @@ parse_mask_list(const char *h_list)
     int                slength_value;
     unsigned           length_value;
     unsigned long long temp_mask;
-    const char *       ptr = NULL;
+    const char        *ptr = NULL;
 
     /* sanity check */
     if (h_list) {
@@ -897,7 +709,7 @@ free_handler(struct handler_t *hand, int len)
  *-------------------------------------------------------------------------
  */
 static struct handler_t *
-parse_command_line(int argc, const char *argv[])
+parse_command_line(int argc, const char *const *argv)
 {
     struct handler_t *hand      = NULL;
     struct handler_t *last_dset = NULL;
@@ -1011,10 +823,11 @@ parse_start:
 
                 for (i = 0; i < argc; i++)
                     if (!hand[i].func) {
-                        hand[i].func        = handle_datasets;
-                        hand[i].obj         = HDstrdup(opt_arg);
-                        hand[i].subset_info = parse_subset_params(hand[i].obj);
-                        last_dset           = &hand[i];
+                        hand[i].func = handle_datasets;
+                        hand[i].obj  = HDstrdup(opt_arg);
+                        if (!dump_opts.disable_compact_subset)
+                            hand[i].subset_info = parse_subset_params(hand[i].obj);
+                        last_dset = &hand[i];
                         break;
                     }
 
@@ -1379,7 +1192,7 @@ error:
  *-------------------------------------------------------------------------
  */
 int
-main(int argc, const char *argv[])
+main(int argc, char *argv[])
 {
     hid_t             fid     = H5I_INVALID_HID;
     hid_t             gid     = H5I_INVALID_HID;
@@ -1388,7 +1201,7 @@ main(int argc, const char *argv[])
     struct handler_t *hand = NULL;
     int               i;
     unsigned          u;
-    char *            fname = NULL;
+    char             *fname = NULL;
 
     h5tools_setprogname(PROGRAMNAME);
     h5tools_setstatus(EXIT_SUCCESS);
@@ -1399,7 +1212,7 @@ main(int argc, const char *argv[])
     /* Initialize h5tools lib */
     h5tools_init();
 
-    if ((hand = parse_command_line(argc, argv)) == NULL) {
+    if ((hand = parse_command_line(argc, (const char *const *)argv)) == NULL) {
         goto done;
     }
 
@@ -1555,7 +1368,7 @@ main(int argc, const char *argv[])
         dset_table  = table_list.tables[0].dset_table;
         type_table  = table_list.tables[0].type_table;
 
-        /* does there exist unamed committed datatype */
+        /* does there exist unnamed committed datatype */
         for (u = 0; u < type_table->nobjs; u++)
             if (!type_table->objs[u].recorded) {
                 unamedtype = 1;
