@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -47,7 +46,7 @@ void
 dump_datatype(hid_t type)
 {
     h5tools_context_t ctx; /* print context  */
-    h5tool_format_t * outputformat = &h5tools_dataformat;
+    h5tool_format_t  *outputformat = &h5tools_dataformat;
 
     HDmemset(&ctx, 0, sizeof(ctx));
     ctx.indent_level = dump_indent / COL;
@@ -71,7 +70,7 @@ void
 dump_dataspace(hid_t space)
 {
     h5tools_context_t ctx; /* print context  */
-    h5tool_format_t * outputformat = &h5tools_dataformat;
+    h5tool_format_t  *outputformat = &h5tools_dataformat;
 
     HDmemset(&ctx, 0, sizeof(ctx));
     ctx.indent_level = dump_indent / COL;
@@ -94,7 +93,7 @@ dump_attr_cb(hid_t oid, const char *attr_name, const H5A_info_t H5_ATTR_UNUSED *
              void H5_ATTR_UNUSED *_op_data)
 {
     h5tools_context_t ctx; /* print context  */
-    h5tool_format_t * outputformat = &h5tools_dataformat;
+    h5tool_format_t  *outputformat = &h5tools_dataformat;
     h5tool_format_t   string_dataformat;
 
     hid_t  attr_id;
@@ -156,10 +155,10 @@ dump_all_cb(hid_t group, const char *name, const H5L_info2_t *linfo, void H5_ATT
     hid_t             obj;
     hid_t             dapl_id  = H5P_DEFAULT; /* dataset access property list ID */
     herr_t            ret      = SUCCEED;
-    char *            obj_path = NULL; /* Full path of object */
+    char             *obj_path = NULL; /* Full path of object */
     h5tools_str_t     buffer;          /* string into which to render   */
     h5tools_context_t ctx;             /* print context  */
-    h5tool_format_t * outputformat = &h5tools_dataformat;
+    h5tool_format_t  *outputformat = &h5tools_dataformat;
     h5tool_format_t   string_dataformat;
     hsize_t           curr_pos = 0; /* total data element position   */
 
@@ -631,7 +630,7 @@ dump_named_datatype(hid_t tid, const char *name)
     hsize_t           curr_pos = 0;               /* total data element position   */
     h5tools_str_t     buffer;                     /* string into which to render   */
     h5tools_context_t ctx;                        /* print context  */
-    h5tool_format_t * outputformat = &h5tools_dataformat;
+    h5tool_format_t  *outputformat = &h5tools_dataformat;
     h5tool_format_t   string_dataformat;
 
     /* setup */
@@ -764,7 +763,7 @@ dump_group(hid_t gid, const char *name)
     char              type_name[1024];
     h5tools_str_t     buffer; /* string into which to render   */
     h5tools_context_t ctx;    /* print context  */
-    h5tool_format_t * outputformat = &h5tools_dataformat;
+    h5tool_format_t  *outputformat = &h5tools_dataformat;
     h5tool_format_t   string_dataformat;
     hsize_t           curr_pos = 0; /* total data element position   */
 
@@ -829,7 +828,7 @@ dump_group(hid_t gid, const char *name)
     if (!HDstrcmp(name, "/") && unamedtype) {
         unsigned u; /* Local index variable */
 
-        /* dump unamed type in root group */
+        /* dump unnamed type in root group */
         for (u = 0; u < type_table->nobjs; u++)
             if (!type_table->objs[u].recorded) {
                 char *obj_tok_str = NULL;
@@ -838,7 +837,7 @@ dump_group(hid_t gid, const char *name)
                 type = H5Dget_type(dset);
 
                 H5Otoken_to_str(dset, &type_table->objs[u].obj_token, &obj_tok_str);
-                HDsprintf(type_name, "#%s", obj_tok_str);
+                HDsnprintf(type_name, sizeof(type_name), "#%s", obj_tok_str);
                 H5free_memory(obj_tok_str);
 
                 dump_function_table->dump_named_datatype_function(type, type_name);
@@ -854,10 +853,7 @@ dump_group(hid_t gid, const char *name)
 
     H5Oget_info3(gid, &oinfo, H5O_INFO_BASIC);
 
-    /* Must check for uniqueness of all objects if we've traversed an elink,
-     * otherwise only check if the reference count > 1.
-     */
-    if (oinfo.rc > 1 || hit_elink) {
+    {
         obj_t *found_obj; /* Found object */
 
         found_obj = search_obj(group_table, &oinfo.token);
@@ -881,10 +877,6 @@ dump_group(hid_t gid, const char *name)
             link_iteration(gid, crt_order_flags);
         }
     }
-    else {
-        attr_iteration(gid, attr_crt_order_flags);
-        link_iteration(gid, crt_order_flags);
-    }
 
     dump_indent -= COL;
     ctx.indent_level--;
@@ -918,7 +910,7 @@ void
 dump_dataset(hid_t did, const char *name, struct subset_t *sset)
 {
     h5tools_context_t ctx; /* print context  */
-    h5tool_format_t * outputformat = &h5tools_dataformat;
+    h5tool_format_t  *outputformat = &h5tools_dataformat;
     h5tool_format_t   string_dataformat;
     hid_t             type, space;
     unsigned          attr_crt_order_flags;
@@ -1092,7 +1084,7 @@ void
 dump_data(hid_t obj_id, int obj_data, struct subset_t *sset, int display_index)
 {
     h5tools_context_t ctx; /* print context  */
-    h5tool_format_t * outputformat = &h5tools_dataformat;
+    h5tool_format_t  *outputformat = &h5tools_dataformat;
     h5tool_format_t   string_dataformat;
     int               print_dataset = FALSE;
 
@@ -1283,7 +1275,7 @@ dump_fcontents(hid_t fid)
 {
     PRINTSTREAM(rawoutstream, "%s %s\n", FILE_CONTENTS, BEGIN);
 
-    /* special case of unamed types in root group */
+    /* special case of unnamed types in root group */
     if (unamedtype) {
         unsigned u;
 
@@ -1309,16 +1301,16 @@ attr_search(hid_t oid, const char *attr_name, const H5A_info_t H5_ATTR_UNUSED *a
 {
     herr_t             ret = SUCCEED;
     int                j;
-    char *             obj_op_name;
-    char *             obj_name;
+    char              *obj_op_name;
+    char              *obj_name;
     trav_attr_udata_t *attr_data = (trav_attr_udata_t *)_op_data;
-    const char *       buf       = attr_data->path;
-    const char *       op_name   = attr_data->op_name;
+    const char        *buf       = attr_data->path;
+    const char        *op_name   = attr_data->op_name;
 
     j = (int)HDstrlen(op_name) - 1;
     /* find the last / */
     while (j >= 0) {
-        if (op_name[j] == '/' && (j == 0 || (j > 0 && op_name[j - 1] != '\\')))
+        if (op_name[j] == '/' && (j == 0 || (op_name[j - 1] != '\\')))
             break;
         j--;
     }
@@ -1343,13 +1335,21 @@ attr_search(hid_t oid, const char *attr_name, const H5A_info_t H5_ATTR_UNUSED *a
                 ret = FAIL;
             }
             else {
+                size_t buffer_space = w - 1;
+
                 HDmemset(obj_name, '\0', w);
                 if (op_name[0] != '/') {
-                    HDstrncat(obj_name, buf, u + 1);
-                    if (buf[u - 1] != '/')
-                        HDstrncat(obj_name, "/", (size_t)2);
+                    HDstrncat(obj_name, buf, buffer_space);
+                    buffer_space -= MIN(buffer_space, u);
+
+                    if (buf[u - 1] != '/') {
+                        HDstrncat(obj_name, "/", buffer_space);
+                        buffer_space -= MIN(buffer_space, 2);
+                    }
                 }
-                HDstrncat(obj_name, op_name, v + 1);
+
+                HDstrncat(obj_name, op_name, buffer_space);
+                buffer_space -= MIN(buffer_space, v);
 
                 handle_attributes(oid, obj_name, NULL, 0, NULL);
                 HDfree(obj_name);
@@ -1365,7 +1365,7 @@ obj_search(const char *path, const H5O_info2_t *oi, const char H5_ATTR_UNUSED *a
            void *_op_data)
 {
     trav_handle_udata_t *handle_data = (trav_handle_udata_t *)_op_data;
-    const char *         op_name     = handle_data->op_name;
+    const char          *op_name     = handle_data->op_name;
     trav_attr_udata_t    attr_data;
 
     attr_data.path    = path;
@@ -1404,9 +1404,9 @@ lnk_search(const char *path, const H5L_info2_t *li, void *_op_data)
 {
     size_t               search_len;
     size_t               k;
-    char *               search_name;
+    char                *search_name;
     trav_handle_udata_t *handle_data = (trav_handle_udata_t *)_op_data;
-    const char *         op_name     = handle_data->op_name;
+    const char          *op_name     = handle_data->op_name;
 
     search_len = HDstrlen(op_name);
     if (search_len > 0 && op_name[0] != '/')
@@ -1421,10 +1421,10 @@ lnk_search(const char *path, const H5L_info2_t *li, void *_op_data)
     else {
         if (k == 2) {
             HDstrcpy(search_name, "/");
-            HDstrncat(search_name, op_name, search_len + 1);
+            HDstrcat(search_name, op_name);
         }
         else
-            HDstrncpy(search_name, op_name, search_len + 1);
+            HDstrcpy(search_name, op_name);
         search_name[search_len + k - 1] = '\0';
 
         if (HDstrcmp(path, search_name) == 0) {
@@ -1517,12 +1517,12 @@ handle_attributes(hid_t fid, const char *attr, void H5_ATTR_UNUSED *data, int H5
 {
     hid_t             oid       = H5I_INVALID_HID;
     hid_t             attr_id   = H5I_INVALID_HID;
-    char *            obj_name  = NULL;
-    char *            attr_name = NULL;
+    char             *obj_name  = NULL;
+    char             *attr_name = NULL;
     int               j;
     h5tools_str_t     buffer; /* string into which to render   */
     h5tools_context_t ctx;    /* print context  */
-    h5tool_format_t * outputformat = &h5tools_dataformat;
+    h5tool_format_t  *outputformat = &h5tools_dataformat;
     h5tool_format_t   string_dataformat;
     hsize_t           curr_pos = 0; /* total data element position   */
 
@@ -1533,7 +1533,7 @@ handle_attributes(hid_t fid, const char *attr, void H5_ATTR_UNUSED *data, int H5
 
     /* find the last / */
     while (j >= 0) {
-        if (attr[j] == '/' && (j == 0 || (j > 0 && attr[j - 1] != '\\')))
+        if (attr[j] == '/' && (j == 0 || (attr[j - 1] != '\\')))
             break;
         j--;
     }
@@ -1661,7 +1661,7 @@ handle_datasets(hid_t fid, const char *dset, void *data, int pe, const char *dis
     hid_t            dsetid;
     hid_t            dapl_id   = H5P_DEFAULT; /* dataset access property list ID */
     struct subset_t *sset      = (struct subset_t *)data;
-    const char *     real_name = display_name ? display_name : dset;
+    const char      *real_name = display_name ? display_name : dset;
 
     if (dump_opts.display_data) {
         if ((dapl_id = H5Pcreate(H5P_DATASET_ACCESS)) < 0) {
@@ -1951,7 +1951,7 @@ handle_datatypes(hid_t fid, const char *type, void H5_ATTR_UNUSED *data, int pe,
     const char *real_name = display_name ? display_name : type;
 
     if ((type_id = H5Topen2(fid, type, H5P_DEFAULT)) < 0) {
-        /* check if type is unamed datatype */
+        /* check if type is unnamed datatype */
         unsigned idx = 0;
 
         while (idx < type_table->nobjs) {
@@ -1960,9 +1960,9 @@ handle_datatypes(hid_t fid, const char *type, void H5_ATTR_UNUSED *data, int pe,
             if (!type_table->objs[idx].recorded) {
                 char *obj_tok_str = NULL;
 
-                /* unamed datatype */
+                /* unnamed datatype */
                 H5Otoken_to_str(fid, &type_table->objs[idx].obj_token, &obj_tok_str);
-                HDsprintf(name, "/#%s", obj_tok_str);
+                HDsnprintf(name, sizeof(name), "/#%s", obj_tok_str);
                 H5free_memory(obj_tok_str);
 
                 if (!HDstrcmp(name, real_name))
@@ -2023,9 +2023,9 @@ dump_extlink(hid_t group, const char *linkname, const char *objname)
 {
     hid_t       oid;
     H5O_info2_t oi;
-    table_t *   old_group_table = group_table;
-    table_t *   old_dset_table  = dset_table;
-    table_t *   old_type_table  = type_table;
+    table_t    *old_group_table = group_table;
+    table_t    *old_dset_table  = dset_table;
+    table_t    *old_type_table  = type_table;
     hbool_t     old_hit_elink;
     ssize_t     idx;
 
