@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -38,27 +37,10 @@ static int   verbose_g = 0;
  * Command-line options: The user can specify short or long-named
  * parameters.
  */
-static const char *        s_opts   = "hVvd:n";
-static struct long_options l_opts[] = {{"help", no_arg, 'h'},
-                                       {"hel", no_arg, 'h'},
-                                       {"he", no_arg, 'h'},
-                                       {"version", no_arg, 'V'},
-                                       {"version", no_arg, 'V'},
-                                       {"versio", no_arg, 'V'},
-                                       {"versi", no_arg, 'V'},
-                                       {"vers", no_arg, 'V'},
-                                       {"verbose", no_arg, 'v'},
-                                       {"verbos", no_arg, 'v'},
-                                       {"verbo", no_arg, 'v'},
-                                       {"verb", no_arg, 'v'},
-                                       {"dname", require_arg, 'd'},
-                                       {"dnam", require_arg, 'd'},
-                                       {"dna", require_arg, 'd'},
-                                       {"dn", require_arg, 'd'},
-                                       {"noop", no_arg, 'n'},
-                                       {"noo", no_arg, 'n'},
-                                       {"no", no_arg, 'n'},
-                                       {"enable-error-stack", no_arg, 'E'},
+static const char         *s_opts   = "hVvd:n";
+static struct long_options l_opts[] = {{"help", no_arg, 'h'},    {"version", no_arg, 'V'},
+                                       {"verbose", no_arg, 'v'}, {"dname", require_arg, 'd'},
+                                       {"noop", no_arg, 'n'},    {"enable-error-stack", no_arg, 'E'},
                                        {NULL, 0, '\0'}};
 
 /*-------------------------------------------------------------------------
@@ -111,7 +93,7 @@ usage(const char *prog)
  *-------------------------------------------------------------------------
  */
 static int
-parse_command_line(int argc, const char **argv)
+parse_command_line(int argc, const char *const *argv)
 {
     int opt;
 
@@ -176,10 +158,10 @@ parse_command_line(int argc, const char **argv)
 
     fname_g = HDstrdup(argv[opt_ind]);
 
-    return (0);
+    return 0;
 
 error:
-    return (-1);
+    return -1;
     ;
 } /* parse_command_line() */
 
@@ -400,7 +382,7 @@ error:
  *-------------------------------------------------------------------------
  */
 int
-main(int argc, const char *argv[])
+main(int argc, char *argv[])
 {
     hid_t fid = H5I_INVALID_HID;
 
@@ -411,7 +393,7 @@ main(int argc, const char *argv[])
     h5tools_init();
 
     /* Parse command line options */
-    if (parse_command_line(argc, argv) < 0)
+    if (parse_command_line(argc, (const char *const *)argv) < 0)
         goto done;
     else if (verbose_g)
         HDfprintf(stdout, "Process command line options\n");
