@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -117,7 +116,7 @@ h5repack_end(pack_opt_t *options)
 int
 h5repack_addfilter(const char *str, pack_opt_t *options)
 {
-    obj_list_t *  obj_list = NULL; /* one object list for the -f and -l option entry */
+    obj_list_t   *obj_list = NULL; /* one object list for the -f and -l option entry */
     filter_info_t filter;          /* filter info for the current -f option entry */
     unsigned      n_objs;          /* number of objects in the current -f or -l option entry */
     int           is_glb;          /* is the filter global */
@@ -221,13 +220,14 @@ h5repack_addlayout(const char *str, pack_opt_t *options)
  *          to free the stack.
  *-------------------------------------------------------------------------
  */
+
 hid_t
 copy_named_datatype(hid_t type_in, hid_t fidout, named_dt_t **named_dt_head_p, trav_table_t *travt,
                     pack_opt_t *options)
 {
-    named_dt_t *dt     = *named_dt_head_p; /* Stack pointer */
-    named_dt_t *dt_ret = NULL;             /* Datatype to return */
-    H5O_info2_t oinfo;                     /* Object info of input dtype */
+    named_dt_t *dt     = NULL; /* Stack pointer */
+    named_dt_t *dt_ret = NULL; /* Datatype to return */
+    H5O_info2_t oinfo;         /* Object info of input dtype */
     int         token_cmp;
     hid_t       ret_value = H5I_INVALID_HID;
 
@@ -235,15 +235,13 @@ copy_named_datatype(hid_t type_in, hid_t fidout, named_dt_t **named_dt_head_p, t
         H5TOOLS_GOTO_ERROR(H5I_INVALID_HID, "H5Oget_info failed");
 
     if (*named_dt_head_p) {
-        if (H5Otoken_cmp(type_in, &dt->obj_token, &oinfo.token, &token_cmp) < 0)
-            H5TOOLS_GOTO_ERROR(H5I_INVALID_HID, "failed to compare object tokens");
-
-        /* Stack already exists, search for the datatype */
-        while (dt && token_cmp) {
-            dt = dt->next;
-
+        /* Search the stack for the datatype. */
+        for (dt = *named_dt_head_p; dt != NULL; dt = dt->next) {
             if (H5Otoken_cmp(type_in, &dt->obj_token, &oinfo.token, &token_cmp) < 0)
                 H5TOOLS_GOTO_ERROR(H5I_INVALID_HID, "failed to compare object tokens");
+
+            if (token_cmp == 0)
+                break; // found it!
         }
 
         dt_ret = dt;
@@ -356,24 +354,28 @@ done:
 int
 copy_attr(hid_t loc_in, hid_t loc_out, named_dt_t **named_dt_head_p, trav_table_t *travt, pack_opt_t *options)
 {
-    hid_t       attr_id  = H5I_INVALID_HID; /* attr ID */
-    hid_t       attr_out = H5I_INVALID_HID; /* attr ID */
-    hid_t       space_id = H5I_INVALID_HID; /* space ID */
-    hid_t       ftype_id = H5I_INVALID_HID; /* file type ID */
-    hid_t       wtype_id = H5I_INVALID_HID; /* read/write type ID */
-    size_t      msize;                      /* size of type */
-    void *      buf = NULL;                 /* data buffer */
-    hsize_t     nelmts;                     /* number of elements in dataset */
-    int         rank;                       /* rank of dataset */
-    htri_t      is_named;                   /* Whether the datatype is named */
-    hsize_t     dims[H5S_MAX_RANK];         /* dimensions of dataset */
-    char        name[255];
-    H5O_info2_t oinfo; /* object info */
-    int         j;
-    unsigned    u;
-    hbool_t     is_ref     = 0;
-    H5T_class_t type_class = -1;
-    int         ret_value  = 0;
+    hid_t         attr_id  = H5I_INVALID_HID; /* attr ID */
+    hid_t         attr_out = H5I_INVALID_HID; /* attr ID */
+    hid_t         space_id = H5I_INVALID_HID; /* space ID */
+    hid_t         ftype_id = H5I_INVALID_HID; /* file type ID */
+    hid_t         wtype_id = H5I_INVALID_HID; /* read/write type ID */
+    size_t        msize;                      /* size of type */
+    void         *buf = NULL;                 /* data buffer */
+    hsize_t       nelmts;                     /* number of elements in dataset */
+    int           rank;                       /* rank of dataset */
+    htri_t        is_named;                   /* Whether the datatype is named */
+    hsize_t       dims[H5S_MAX_RANK];         /* dimensions of dataset */
+    H5_timer_t    timer;                      /* Timer for read/write operations */
+    H5_timevals_t times;                      /* Elapsed time for each operation */
+    static double read_time  = 0;
+    static double write_time = 0;
+    char          name[255];
+    H5O_info2_t   oinfo; /* object info */
+    int           j;
+    unsigned      u;
+    hbool_t       is_ref     = 0;
+    H5T_class_t   type_class = -1;
+    int           ret_value  = 0;
 
     if (H5Oget_info3(loc_in, &oinfo, H5O_INFO_NUM_ATTRS) < 0)
         H5TOOLS_GOTO_ERROR((-1), "H5Oget_info failed");
@@ -470,6 +472,9 @@ copy_attr(hid_t loc_in, hid_t loc_out, named_dt_t **named_dt_head_p, trav_table_
             } /* end for each member */
         }     /* end if type_class is H5T_COMPOUND */
 
+        read_time  = 0;
+        write_time = 0;
+
         if (!is_ref) {
             /*-----------------------------------------------------------------
              * read to memory
@@ -480,8 +485,17 @@ copy_attr(hid_t loc_in, hid_t loc_out, named_dt_t **named_dt_head_p, trav_table_
             if (buf == NULL) {
                 H5TOOLS_GOTO_ERROR((-1), "HDmalloc failed");
             } /* end if */
+            if (options->verbose == 2) {
+                H5_timer_init(&timer);
+                H5_timer_start(&timer);
+            }
             if (H5Aread(attr_id, wtype_id, buf) < 0)
                 H5TOOLS_GOTO_ERROR((-1), "H5Aread failed");
+            if (options->verbose == 2) {
+                H5_timer_stop(&timer);
+                H5_timer_get_times(timer, &times);
+                read_time += times.elapsed;
+            }
 
             /*-----------------------------------------------------------------
              * copy
@@ -490,8 +504,18 @@ copy_attr(hid_t loc_in, hid_t loc_out, named_dt_t **named_dt_head_p, trav_table_
 
             if ((attr_out = H5Acreate2(loc_out, name, wtype_id, space_id, H5P_DEFAULT, H5P_DEFAULT)) < 0)
                 H5TOOLS_GOTO_ERROR((-1), "H5Acreate2 failed on ,%s>", name);
+
+            if (options->verbose == 2) {
+                H5_timer_init(&timer);
+                H5_timer_start(&timer);
+            }
             if (H5Awrite(attr_out, wtype_id, buf) < 0)
                 H5TOOLS_GOTO_ERROR((-1), "H5Awrite failed");
+            if (options->verbose == 2) {
+                H5_timer_stop(&timer);
+                H5_timer_get_times(timer, &times);
+                write_time += times.elapsed;
+            }
 
             /*close*/
             if (H5Aclose(attr_out) < 0)
@@ -501,12 +525,17 @@ copy_attr(hid_t loc_in, hid_t loc_out, named_dt_t **named_dt_head_p, trav_table_
              * be reclaimed */
             if (TRUE == h5tools_detect_vlen(wtype_id))
                 H5Treclaim(wtype_id, space_id, H5P_DEFAULT, buf);
+
             HDfree(buf);
             buf = NULL;
         } /*H5T_REFERENCE*/
 
-        if (options->verbose)
-            HDprintf(FORMAT_OBJ_ATTR, "attr", name);
+        if (options->verbose > 0) {
+            if (options->verbose == 2)
+                HDprintf(FORMAT_OBJ_ATTR_TIME, "attr", read_time, write_time, name);
+            else
+                HDprintf(FORMAT_OBJ_ATTR, "attr", name);
+        }
 
         /*---------------------------------------------------------------------
          * close
@@ -571,7 +600,7 @@ check_options(pack_opt_t *options)
      * Objects to layout
      *-------------------------------------------------------------------------
      */
-    if (options->verbose && have_request(options)) {
+    if (options->verbose > 0 && have_request(options)) {
         if (options->all_layout == 1) {
             HDprintf("All objects to modify layout are...\n");
             switch (options->layout_g) {
@@ -612,7 +641,7 @@ check_options(pack_opt_t *options)
         char *name = options->op_tbl->objs[i].path;
 
         if (options->op_tbl->objs[i].chunk.rank > 0) {
-            if (options->verbose) {
+            if (options->verbose > 0) {
                 HDprintf(" <%s> with chunk size ", name);
                 for (k = 0; k < options->op_tbl->objs[i].chunk.rank; k++)
                     HDprintf("%d ", (int)options->op_tbl->objs[i].chunk.chunk_lengths[k]);
@@ -621,7 +650,7 @@ check_options(pack_opt_t *options)
             has_ck = 1;
         }
         else if (options->op_tbl->objs[i].chunk.rank == -2) { /* TODO: replace 'magic number' */
-            if (options->verbose)
+            if (options->verbose > 0)
                 HDprintf(" <%s> %s\n", name, "NONE (contiguous)");
             has_ck = 1;
         }
@@ -635,7 +664,7 @@ check_options(pack_opt_t *options)
      *-------------------------------------------------------------------------
      */
 
-    if (options->verbose && have_request(options)) {
+    if (options->verbose > 0 && have_request(options)) {
         if (options->all_filter == 1) {
             HDprintf("All objects to apply filter are...\n");
             for (k = 0; k < options->n_filter_g; k++) {
@@ -669,10 +698,10 @@ check_options(pack_opt_t *options)
 
     for (i = 0; i < options->op_tbl->nelems; i++) {
         pack_info_t pack = options->op_tbl->objs[i];
-        char *      name = pack.path;
+        char       *name = pack.path;
 
         for (j = 0; j < pack.nfilters; j++) {
-            if (options->verbose) {
+            if (options->verbose > 0) {
                 if (pack.filter[j].filtn >= 0) {
                     if (pack.filter[j].filtn > H5Z_FILTER_SCALEOFFSET) {
                         HDprintf(" <%s> with %s filter %d\n", name, get_sfilter(pack.filter[j].filtn),
@@ -710,7 +739,7 @@ check_options(pack_opt_t *options)
      *------------------------------------------------------------------------
      */
     if (options->ublock_filename != NULL && options->ublock_size == 0) {
-        if (options->verbose) {
+        if (options->verbose > 0) {
             HDprintf("Warning: user block size missing for file %s. Assigning a default size of 1024...\n",
                      options->ublock_filename);
             options->ublock_size = 1024;
@@ -783,21 +812,21 @@ check_objects(const char *fname, pack_opt_t *options)
      *-------------------------------------------------------------------------
      */
 
-    if (options->verbose)
+    if (options->verbose > 0)
         HDprintf("Opening file. Searching %zu objects to modify ...\n", travt->nobjs);
 
     for (i = 0; i < options->op_tbl->nelems; i++) {
         pack_info_t obj  = options->op_tbl->objs[i];
-        char *      name = obj.path;
+        char       *name = obj.path;
 
-        if (options->verbose)
+        if (options->verbose > 0)
             HDprintf(" <%s>", name);
 
         /* the input object names are present in the file and are valid */
         if (h5trav_getindext(name, travt) < 0)
             H5TOOLS_GOTO_ERROR((-1), "%s Could not find <%s> in file <%s>. Exiting...\n",
-                               (options->verbose ? "\n" : ""), name, fname);
-        if (options->verbose)
+                               (options->verbose > 0 ? "\n" : ""), name, fname);
+        if (options->verbose > 0)
             HDprintf("...Found\n");
 
         for (ifil = 0; ifil < obj.nfilters; ifil++) {
