@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -18,7 +17,7 @@
 /* Name of tool */
 #define PROGRAMNAME "h5repack"
 
-static int  parse_command_line(int argc, const char **argv, pack_opt_t *options);
+static int  parse_command_line(int argc, const char *const *argv, pack_opt_t *options);
 static void leave(int ret) H5_ATTR_NORETURN;
 
 /* module-scoped variables */
@@ -31,7 +30,7 @@ const char *outfile = NULL;
  * Command-line options: The user can specify short or long-named
  * parameters.
  */
-static const char *        s_opts   = "a:b:c:d:e:f:hi:j:k:l:m:no:q:s:t:u:vz:EG:LM:P:S:T:VXW1:2:3:4:5:6:";
+static const char         *s_opts   = "a:b:c:d:e:f:hi:j:k:l:m:no:q:s:t:u:v*z:E*G:LM:P:S:T:VXW";
 static struct long_options l_opts[] = {{"alignment", require_arg, 'a'},
                                        {"block", require_arg, 'b'},
                                        {"compact", require_arg, 'c'},
@@ -39,20 +38,20 @@ static struct long_options l_opts[] = {{"alignment", require_arg, 'a'},
                                        {"file", require_arg, 'e'},
                                        {"filter", require_arg, 'f'},
                                        {"help", no_arg, 'h'},
-                                       {"infile", require_arg, 'i'}, /* for backward compability */
+                                       {"infile", require_arg, 'i'}, /* for backward compatibility */
                                        {"low", require_arg, 'j'},
                                        {"high", require_arg, 'k'},
                                        {"layout", require_arg, 'l'},
                                        {"minimum", require_arg, 'm'},
                                        {"native", no_arg, 'n'},
-                                       {"outfile", require_arg, 'o'}, /* for backward compability */
+                                       {"outfile", require_arg, 'o'}, /* for backward compatibility */
                                        {"sort_by", require_arg, 'q'},
                                        {"ssize", require_arg, 's'},
                                        {"threshold", require_arg, 't'},
                                        {"ublock", require_arg, 'u'},
-                                       {"verbose", no_arg, 'v'},
+                                       {"verbose", optional_arg, 'v'},
                                        {"sort_order", require_arg, 'z'},
-                                       {"enable-error-stack", no_arg, 'E'},
+                                       {"enable-error-stack", optional_arg, 'E'},
                                        {"fs_pagesize", require_arg, 'G'},
                                        {"latest", no_arg, 'L'},
                                        {"metadata_block_size", require_arg, 'M'},
@@ -86,14 +85,17 @@ usage(const char *prog)
     PRINTSTREAM(rawoutstream, "usage: %s [OPTIONS] file1 file2\n", prog);
     PRINTVALSTREAM(rawoutstream, "  file1                    Input HDF5 File\n");
     PRINTVALSTREAM(rawoutstream, "  file2                    Output HDF5 File\n");
+    PRINTVALSTREAM(rawoutstream, "  ERROR\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "   --enable-error-stack    Prints messages from the HDF5 error stack as they occur.\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "                           Optional value 2 also prints file open errors.\n");
     PRINTVALSTREAM(rawoutstream, "  OPTIONS\n");
     PRINTVALSTREAM(rawoutstream, "   -h, --help              Print a usage message and exit\n");
-    PRINTVALSTREAM(rawoutstream, "   -v, --verbose           Verbose mode, print object information\n");
+    PRINTVALSTREAM(rawoutstream, "   -v N, --verbose=N       Verbose mode, print object information.\n");
+    PRINTVALSTREAM(rawoutstream, "      N - is an integer greater than 1, 2 displays read/write timing\n");
     PRINTVALSTREAM(rawoutstream, "   -V, --version           Print version number and exit\n");
     PRINTVALSTREAM(rawoutstream, "   -n, --native            Use a native HDF5 type when repacking\n");
-    PRINTVALSTREAM(rawoutstream,
-                   "   --enable-error-stack    Prints messages from the HDF5 error stack as they\n");
-    PRINTVALSTREAM(rawoutstream, "                           occur\n");
     PRINTVALSTREAM(rawoutstream,
                    "   --src-vol-value         Value (ID) of the VOL connector to use for opening the\n");
     PRINTVALSTREAM(rawoutstream, "                           input HDF5 file specified\n");
@@ -363,7 +365,7 @@ read_info(const char *filename, pack_opt_t *options)
 
     /* cycle until end of file reached */
     while (1) {
-        if (EOF == fscanf(fp, "%9s", stype))
+        if (EOF == HDfscanf(fp, "%9s", stype))
             break;
 
         /* Info indicator must be for layout or filter */
@@ -374,11 +376,11 @@ read_info(const char *filename, pack_opt_t *options)
             goto done;
         }
 
-        /* find begining of info */
+        /* find beginning of info */
         i = 0;
         c = '0';
         while (c != ' ') {
-            if (fscanf(fp, "%c", &c) < 0 && HDferror(fp)) {
+            if (HDfscanf(fp, "%c", &c) < 0 && HDferror(fp)) {
                 error_msg("fscanf error\n");
                 h5tools_setstatus(EXIT_FAILURE);
                 ret_value = EXIT_FAILURE;
@@ -390,7 +392,7 @@ read_info(const char *filename, pack_opt_t *options)
         c = '0';
         /* go until end */
         while (c != ' ') {
-            if (fscanf(fp, "%c", &c) < 0 && HDferror(fp)) {
+            if (HDfscanf(fp, "%c", &c) < 0 && HDferror(fp)) {
                 error_msg("fscanf error\n");
                 h5tools_setstatus(EXIT_FAILURE);
                 ret_value = EXIT_FAILURE;
@@ -482,7 +484,7 @@ set_sort_order(const char *form)
  *-------------------------------------------------------------------------
  */
 static int
-parse_command_line(int argc, const char **argv, pack_opt_t *options)
+parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
 {
     h5tools_vol_info_t in_vol_info;
     h5tools_vol_info_t out_vol_info;
@@ -525,7 +527,12 @@ parse_command_line(int argc, const char **argv, pack_opt_t *options)
                 goto done;
 
             case 'v':
-                options->verbose = 1;
+                if (opt_arg != NULL) {
+                    if (2 == HDatoi(opt_arg))
+                        options->verbose = 2;
+                }
+                else
+                    options->verbose = 1;
                 break;
 
             case 'f':
@@ -735,7 +742,10 @@ parse_command_line(int argc, const char **argv, pack_opt_t *options)
                 break;
 
             case 'E':
-                enable_error_stack = 1;
+                if (opt_arg != NULL)
+                    enable_error_stack = HDatoi(opt_arg);
+                else
+                    enable_error_stack = 1;
                 break;
 
             case '1':
@@ -858,7 +868,7 @@ done:
  *-------------------------------------------------------------------------
  */
 int
-main(int argc, const char **argv)
+main(int argc, char **argv)
 {
     pack_opt_t options; /*the global options */
     int        parse_ret;
@@ -888,7 +898,7 @@ main(int argc, const char **argv)
     /* Initialize default indexing options */
     sort_by = H5_INDEX_CRT_ORDER;
 
-    parse_ret = parse_command_line(argc, argv, &options);
+    parse_ret = parse_command_line(argc, (const char *const *)argv, &options);
     if (parse_ret < 0) {
         HDprintf("Error occurred while parsing command-line options\n");
         h5tools_setstatus(EXIT_FAILURE);
