@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -33,7 +32,7 @@
 #define H5_NFILTERS_IMPL                                                                                     \
     8 /* Number of currently implemented filters + one to                                                    \
          accommodate for user-define filters + one                                                           \
-         to accomodate datasets whithout any filters */
+         to accommodate datasets without any filters */
 
 /* File space management strategies: see H5Fpublic.h for declarations */
 const char *FS_STRATEGY_NAME[] = {"H5F_FSPACE_STRATEGY_FSM_AGGR",
@@ -84,7 +83,7 @@ typedef struct iter_t {
     unsigned long  dset_layouts[H5D_NLAYOUTS];      /* Type of storage for each dataset */
     unsigned long  dset_comptype[H5_NFILTERS_IMPL]; /* Number of currently implemented filters */
     unsigned long  dset_ntypes;                     /* Number of diff. dataset datatypes found */
-    dtype_info_t * dset_type_info;                  /* Pointer to dataset datatype information found */
+    dtype_info_t  *dset_type_info;                  /* Pointer to dataset datatype information found */
     unsigned       dset_dim_nbins;                  /* Number of bins for dataset dimensions */
     unsigned long *dset_dim_bins;                   /* Pointer to array of bins for dataset dimensions */
     ohdr_info_t    dset_ohdr_info;                  /* Object header information for datasets */
@@ -109,7 +108,7 @@ typedef struct iter_t {
     hsize_t               free_hdr;                 /* Size of free space manager metadata in the file */
     unsigned long         num_small_sects[SIZE_SMALL_SECTS]; /* Size of small free-space sections */
     unsigned              sect_nbins;                        /* Number of bins for free-space section sizes */
-    unsigned long *       sect_bins; /* Pointer to array of bins for free-space section sizes */
+    unsigned long        *sect_bins; /* Pointer to array of bins for free-space section sizes */
     hsize_t               datasets_index_storage_size; /* meta size for chunked dataset's indexing type */
     hsize_t               datasets_heap_storage_size;  /* heap size for dataset with external storage */
     unsigned long         nexternal;                   /* Number of external files for a dataset */
@@ -169,105 +168,22 @@ struct handler_t {
     char **obj;
 };
 
-static const char *s_opts = "Aa:Ddm:EFfhGgl:sSTO:Vw:H:";
+static const char *s_opts = "Aa:Ddm:E*FfhGgl:sSTO:Vw:H:";
 /* e.g. "filemetadata" has to precede "file"; "groupmetadata" has to precede "group" etc. */
 static struct long_options l_opts[] = {{"help", no_arg, 'h'},
-                                       {"hel", no_arg, 'h'},
-                                       {"he", no_arg, 'h'},
                                        {"filemetadata", no_arg, 'F'},
-                                       {"filemetadat", no_arg, 'F'},
-                                       {"filemetada", no_arg, 'F'},
-                                       {"filemetad", no_arg, 'F'},
-                                       {"filemeta", no_arg, 'F'},
-                                       {"filemet", no_arg, 'F'},
-                                       {"fileme", no_arg, 'F'},
-                                       {"filem", no_arg, 'F'},
-                                       {"file", no_arg, 'f'},
-                                       {"fil", no_arg, 'f'},
-                                       {"fi", no_arg, 'f'},
                                        {"groupmetadata", no_arg, 'G'},
-                                       {"groupmetadat", no_arg, 'G'},
-                                       {"groupmetada", no_arg, 'G'},
-                                       {"groupmetad", no_arg, 'G'},
-                                       {"groupmeta", no_arg, 'G'},
-                                       {"groupmet", no_arg, 'G'},
-                                       {"groupme", no_arg, 'G'},
-                                       {"groupm", no_arg, 'G'},
-                                       {"group", no_arg, 'g'},
-                                       {"grou", no_arg, 'g'},
-                                       {"gro", no_arg, 'g'},
-                                       {"gr", no_arg, 'g'},
                                        {"links", require_arg, 'l'},
-                                       {"link", require_arg, 'l'},
-                                       {"lin", require_arg, 'l'},
-                                       {"li", require_arg, 'l'},
                                        {"dsetmetadata", no_arg, 'D'},
-                                       {"dsetmetadat", no_arg, 'D'},
-                                       {"dsetmetada", no_arg, 'D'},
-                                       {"dsetmetad", no_arg, 'D'},
-                                       {"dsetmeta", no_arg, 'D'},
-                                       {"dsetmet", no_arg, 'D'},
-                                       {"dsetme", no_arg, 'D'},
-                                       {"dsetm", no_arg, 'D'},
-                                       {"dset", no_arg, 'd'},
-                                       {"dse", no_arg, 'd'},
-                                       {"ds", no_arg, 'd'},
                                        {"dims", require_arg, 'm'},
-                                       {"dim", require_arg, 'm'},
-                                       {"di", require_arg, 'm'},
                                        {"dtypemetadata", no_arg, 'T'},
-                                       {"dtypemetadat", no_arg, 'T'},
-                                       {"dtypemetada", no_arg, 'T'},
-                                       {"dtypemetad", no_arg, 'T'},
-                                       {"dtypemeta", no_arg, 'T'},
-                                       {"dtypemet", no_arg, 'T'},
-                                       {"dtypeme", no_arg, 'T'},
-                                       {"dtypem", no_arg, 'T'},
-                                       {"dtype", no_arg, 'T'},
-                                       {"dtyp", no_arg, 'T'},
-                                       {"dty", no_arg, 'T'},
-                                       {"dt", no_arg, 'T'},
                                        {"object", require_arg, 'O'},
-                                       {"objec", require_arg, 'O'},
-                                       {"obje", require_arg, 'O'},
-                                       {"obj", require_arg, 'O'},
-                                       {"ob", require_arg, 'O'},
                                        {"version", no_arg, 'V'},
-                                       {"versio", no_arg, 'V'},
-                                       {"versi", no_arg, 'V'},
-                                       {"vers", no_arg, 'V'},
-                                       {"ver", no_arg, 'V'},
-                                       {"ve", no_arg, 'V'},
                                        {"attribute", no_arg, 'A'},
-                                       {"attribut", no_arg, 'A'},
-                                       {"attribu", no_arg, 'A'},
-                                       {"attrib", no_arg, 'A'},
-                                       {"attri", no_arg, 'A'},
-                                       {"attr", no_arg, 'A'},
-                                       {"att", no_arg, 'A'},
-                                       {"at", no_arg, 'A'},
-                                       {"enable-error-stack", no_arg, 'E'},
+                                       {"enable-error-stack", optional_arg, 'E'},
                                        {"numattrs", require_arg, 'a'},
-                                       {"numattr", require_arg, 'a'},
-                                       {"numatt", require_arg, 'a'},
-                                       {"numat", require_arg, 'a'},
-                                       {"numa", require_arg, 'a'},
-                                       {"num", require_arg, 'a'},
-                                       {"nu", require_arg, 'a'},
                                        {"freespace", no_arg, 's'},
-                                       {"freespac", no_arg, 's'},
-                                       {"freespa", no_arg, 's'},
-                                       {"freesp", no_arg, 's'},
-                                       {"frees", no_arg, 's'},
-                                       {"free", no_arg, 's'},
-                                       {"fre", no_arg, 's'},
-                                       {"fr", no_arg, 's'},
                                        {"summary", no_arg, 'S'},
-                                       {"summar", no_arg, 'S'},
-                                       {"summa", no_arg, 'S'},
-                                       {"summ", no_arg, 'S'},
-                                       {"sum", no_arg, 'S'},
-                                       {"su", no_arg, 'S'},
                                        {"s3-cred", require_arg, 'w'},
                                        {"hdfs-attrs", require_arg, 'H'},
                                        {NULL, 0, '\0'}};
@@ -292,8 +208,11 @@ static void
 usage(const char *prog)
 {
     HDfflush(stdout);
-    HDfprintf(stdout, "Usage: %s [OPTIONS] file\n", prog);
+    HDfprintf(stdout, "usage: %s [OPTIONS] file\n", prog);
     HDfprintf(stdout, "\n");
+    HDfprintf(stdout, "      ERROR\n");
+    HDfprintf(stdout, "     --enable-error-stack  Prints messages from the HDF5 error stack as they occur\n");
+    HDfprintf(stdout, "                           Optional value 2 also prints file open errors\n");
     HDfprintf(stdout, "      OPTIONS\n");
     HDfprintf(stdout, "     -h, --help            Print a usage message and exit\n");
     HDfprintf(stdout, "     -V, --version         Print version number and exit\n");
@@ -318,7 +237,6 @@ usage(const char *prog)
     HDfprintf(stdout, "                           than 0.  The default threshold is 10.\n");
     HDfprintf(stdout, "     -s, --freespace       Print free space information\n");
     HDfprintf(stdout, "     -S, --summary         Print summary of file space information\n");
-    HDfprintf(stdout, "     --enable-error-stack  Prints messages from the HDF5 error stack as they occur\n");
     HDfprintf(stdout, "     --s3-cred=<cred>      Access file on S3, using provided credential\n");
     HDfprintf(stdout, "                           <cred> :: (region,id,key)\n");
     HDfprintf(stdout, "                           If <cred> == \"(,,)\", no authentication is used.\n");
@@ -417,18 +335,6 @@ attribute_stats(iter_t *iter, const H5O_info2_t *oi, const H5O_native_info_t *na
  * Programmer: Quincey Koziol
  *             Tuesday, August 16, 2005
  *
- * Modifications: Refactored code from the walk_function
- *                EIP, Wednesday, August 16, 2006
- *
- *      Vailin Choi 12 July 2007
- *      1. Gathered storage info for btree and heap
- *         (groups and attributes)
- *      2. Gathered info for attributes
- *
- *      Vailin Choi 14 July 2007
- *      Cast "num_objs" and "num_attrs" to size_t
- *      Due to the -Mbounds problem for the pgi-32 bit compiler on indexing
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -730,7 +636,7 @@ static herr_t
 obj_stats(const char *path, const H5O_info2_t *oi, const char *already_visited, void *_iter)
 {
     H5O_native_info_t native_info;
-    iter_t *          iter      = (iter_t *)_iter;
+    iter_t           *iter      = (iter_t *)_iter;
     herr_t            ret_value = SUCCEED;
 
     /* If the object has already been seen then just return */
@@ -913,7 +819,7 @@ hand_free(struct handler_t *hand)
  *-------------------------------------------------------------------------
  */
 static int
-parse_command_line(int argc, const char *argv[], struct handler_t **hand_ret)
+parse_command_line(int argc, const char *const *argv, struct handler_t **hand_ret)
 {
     int               opt;
     unsigned          u;
@@ -935,7 +841,10 @@ parse_command_line(int argc, const char *argv[], struct handler_t **hand_ret)
                 break;
 
             case 'E':
-                enable_error_stack = 1;
+                if (opt_arg != NULL)
+                    enable_error_stack = HDatoi(opt_arg);
+                else
+                    enable_error_stack = 1;
                 break;
 
             case 'F':
@@ -1182,8 +1091,6 @@ iter_free(iter_t *iter)
  * Programmer: Elena Pourmal
  *             Saturday, August 12, 2006
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -1269,11 +1176,6 @@ print_file_metadata(const iter_t *iter)
  * Programmer: Elena Pourmal
  *             Saturday, August 12, 2006
  *
- * Modifications:
- *  bug #1253; Oct 6th 2008; Vailin Choi
- *  Fixed segmentation fault: print iter->group_bins[0] when
- *  there is iter->group_nbins
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -1715,8 +1617,6 @@ print_file_statistics(const iter_t *iter)
  * Programmer: Elena Pourmal
  *             Thursday, August 17, 2006
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static void
@@ -1737,8 +1637,6 @@ print_object_statistics(const char *name)
  * Programmer: Elena Pourmal
  *             Thursday, August 17, 2006
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static void
@@ -1753,17 +1651,13 @@ print_statistics(const char *name, const iter_t *iter)
 /*-------------------------------------------------------------------------
  * Function: main
  *
- * Modifications:
- *      2/2010; Vailin Choi
- *      Get the size of user block
- *
  *-------------------------------------------------------------------------
  */
 int
-main(int argc, const char *argv[])
+main(int argc, char *argv[])
 {
     iter_t            iter;
-    const char *      fname   = NULL;
+    const char       *fname   = NULL;
     hid_t             fid     = H5I_INVALID_HID;
     struct handler_t *hand    = NULL;
     hid_t             fapl_id = H5P_DEFAULT;
@@ -1776,7 +1670,7 @@ main(int argc, const char *argv[])
 
     HDmemset(&iter, 0, sizeof(iter));
 
-    if (parse_command_line(argc, argv, &hand) < 0)
+    if (parse_command_line(argc, (const char *const *)argv, &hand) < 0)
         goto done;
 
     /* enable error reporting if command line option */
@@ -1835,7 +1729,7 @@ main(int argc, const char *argv[])
             warn_msg("Unable to retrieve file size\n");
         HDassert(iter.filesize != 0);
 
-        /* Get storge info for file-level structures */
+        /* Get storage info for file-level structures */
         if (H5Fget_info2(fid, &finfo) < 0)
             warn_msg("Unable to retrieve file info\n");
         else {
